<?php

namespace WPSocialReviews\Classes;

use WPSocialReviews\Classes\Helper;

if (!defined('ABSPATH')) {
    exit;
}

class AdminAjaxChatHandler
{
    /**
     *
     * Register end points
     *
     * @since 1.1.0
     *
     **/
    public function registerEndpoints()
    {
        add_action('wp_ajax_wpsocial_review_admin_ajax_chat', array($this, 'handeEndPoint'));
    }

    /**
     *
     * validate route
     *
     * @return method name
     * @since 1.1.0
     *
     **/
    public function handeEndPoint()
    {
        $route = sanitize_text_field($_REQUEST['route']);
        $validRoutes = array(

            'save_chat_settings' => 'handleCredentialSave',
            'get_chat_settings' => 'getChatCredential',
            'disconnect_chat_settings' => 'deleteChatCredential',
            'save_updated_chat_config' => 'updateChatCredential',
            'wpsr_upload_image' => 'handleFileUpload',

        );
        if (isset($validRoutes[$route])) {
            do_action('wpsocialreviews/doing_ajax_chat_action_' . $route);
            return $this->{$validRoutes[$route]}();
        }
        do_action('wpsocialreviews/admin_ajax_chat_handler_catch', $route);
    }

    /**
     *
     * Get a valid platform name from wp social reviews table
     *
     * @return string
     * @since 1.0.0
     *
     **/
    public function handleCredentialSave()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/save_chat_credential_' . $platform);
    }

    public function getChatCredential()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/get_chat_credential_' . $platform);
    }

    public function updateChatCredential()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/update_chat_credential_' . $platform);
    }

    public function deleteChatCredential()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/delete_chat_credential_' . $platform);
    }

    protected function handleFileUpload()
    {
        if (!function_exists('wp_handle_upload')) {
            require_once(ABSPATH . 'wp-admin/includes/file.php');
        }
        $uploadedfile = $_FILES['file'];

        $acceptedFilles = array(
            'image/png',
            'image/jpeg'
        );

        if (!in_array($uploadedfile['type'], $acceptedFilles)) {
            wp_send_json(__('Please upload only jpg/png format files', 'wpsocialreviews'), 423);
        }

        $upload_overrides = array('test_form' => false);

        $movefile = wp_handle_upload($uploadedfile, $upload_overrides);

        if ($movefile && !isset($movefile['error'])) {
            wp_send_json_success(array(
                'file' => $movefile
            ), 200);
        } else {
            wp_send_json(__('Something is wrong when uploading the file', 'wpsocialreviews'), 423);
        }
    }

}
