<?php

namespace WPSocialReviews\Classes;

use WPSocialReviews\Classes\Helper;
use WPSocialReviews\Classes\ArrayHelper;
use WPSocialReviewsPro\Classes\Feeds\Twitter\TwitterCard;
use WPSocialReviewsPro\Classes\Feeds\Twitter\ManageCard;

if (!defined('ABSPATH')) {
    exit;
}

class AdminAjaxFeedHandler
{
    /**
     *
     * Register end points
     *
     * @since 1.1.0
     *
     **/
    public function registerEndpoints()
    {
        add_action('wp_ajax_wpsocial_review_admin_ajax_feed', array($this, 'handeEndPoint'));
    }

    /**
     *
     * validate route
     *
     * @return method name
     * @since 1.1.0
     *
     **/
    public function handeEndPoint()
    {
        $route = sanitize_text_field($_REQUEST['route']);
        $validRoutes = array(
            //'save_feed_settings'    => 'handleCredentialSave',
            'get_feed_settings' => 'getFeedSettings',

            //create new template
            'add_new_template' => 'addNewTemplate',

            //login route
            'twitter_verification_login' => 'twitterVerificationLogin',
            'get_verification_configs' => 'getVerificationConfigs',
            'disconnect_verification_configs' => 'disconnectVerificationConfigs',

            //editor route
            'update_feed_editor_settings' => 'updateFeedEditorSettings',
            'save_updated_feed_editor_settings' => 'saveUpdatedFeedSettings',

            //clear twitter cache
            'clear_feed_cache' => 'clearFeedCache',
            'clear_twitter_card' => 'clearTwitterCard',

            // global settings
            'save_global_settings' => 'saveGlobalSettings',
            'get_global_settings' => 'getGlobalSettings',


            'set_youtube_account_data' => 'setYoutubeAccountData',
            'set_account_data' => 'setAccountData',

            'save_twitter_cards' => 'saveTwitterCards'
        );
        if (isset($validRoutes[$route])) {
            do_action('wpsocialreviews/doing_ajax_chat_action_' . $route);
            return $this->{$validRoutes[$route]}();
        }
        do_action('wpsocialreviews/admin_ajax_chat_handler_catch', $route);
    }

    public function addNewTemplate()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);

        $templateData = array(
            'post_title' => $platform . ' template',
            'post_content' => 'empty_' . $platform,
            'post_type' => PostType::$CPTName,
            'post_status' => 'publish'
        );

        $templateId = wp_insert_post($templateData);

        if ($platform === 'twitter') {
            $templateMeta = self::saveTwitterTemplateMeta();
            update_post_meta($templateId, '_wpsr_twitter_template_config', $templateMeta);
        }

        if ($platform === 'youtube') {
            $templateMeta = self::saveYoutubeTemplateMeta();
            update_post_meta($templateId, '_wpsr_youtube_template_config', $templateMeta);
        }

        if ($platform === 'instagram') {
            $templateMeta = self::saveInstagramTemplateMeta();
            update_post_meta($templateId, '_wpsr_instagram_template_config', $templateMeta);
        }
        do_action('wpsocialreviews/before_create_template', $platform, $templateData);

        wp_update_post([
            'ID' => $templateId,
            'post_title' => $platform . ' template' . ' (#' . $templateId . ')'
        ]);

        if (is_wp_error($templateId)) {
            wp_send_json_error(array(
                'message' => $templateId->get_error_message()
            ), 423);
        }

        do_action('wpsocialreviews/after_create_template', $templateId, $platform, $templateData);

        wp_send_json_success(array(
            'message' => __('Template Successfully created', 'wpsocialreviews'),
            'template_id' => $templateId
        ), 200);
    }

    public static function saveTwitterTemplateMeta()
    {
        $configs = get_option('twitter_verification_configs', false);

        if (!$configs) {
            $configs = get_option('wpsr_twitter_verification_configs');
        }

        return array(
            'feed_settings' => array(
                'platform' => 'twitter',
                'additional_settings' => array(
                    'feed_type' => 'user_timeline',
                    'screen_name' => isset($configs['dynamic']->screen_name) ? $configs['dynamic']->screen_name : '',
                    'feed_count' => 10,
                ),
                'pagination_settings' => array(
                    'pagination_type' => 'none',
                    'paginate' => 6,
                )
            ),
            'dynamic' => []//$response
        );
    }

    public static function saveYoutubeTemplateMeta()
    {
        $configs = get_option('wpsr_youtube_verification_configs');

        return array(
            'feed_settings' => array(
                'platform' => 'youtube',
                'source_settings' => array(
                    'feed_type' => 'channel_feed',
                    'channel_id' => isset($configs['channel_id']) ? $configs['channel_id'] : '',
                    'user_name' => isset($configs['user_name']) ? $configs['user_name'] : '',
                    'feed_count' => 10,
                )
            ),
            'dynamic' => []//$response
        );
    }

    public static function saveInstagramTemplateMeta()
    {
        $configs = get_option('wpsr_instagram_verification_configs');

        return array(
            'feed_settings' => array(
                'platform' => 'instagram',
                'source_settings' => array(
                    'feed_type' => 'user_account',
                    'account_id' => isset($configs['account_id']) ? $configs['account_id'] : '',
                ),
                'filters' => array(
                    'total_posts' => 50
                )
            ),
            'dynamic' => []
        );
    }

    public function getFeedSettings()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/get_feed_settings_' . $platform);
    }

    //login
    public function twitterVerificationLogin()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/verification_login_' . $platform);
    }

    public function getVerificationConfigs()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/get_verification_configs_' . $platform);
    }

    public function disconnectVerificationConfigs()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/disconnect_verification_configs_' . $platform);
    }

    // editor
    public function updateFeedEditorSettings()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/update_feed_editor_settings_' . $platform);
    }

    public function saveUpdatedFeedSettings()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/save_updated_feed_editor_settings_' . $platform);
    }

    //twitter cache clear
    public function clearFeedCache()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/clear_cache_' . $platform);
    }

    public function clearTwitterCard()
    {
        delete_option('wpsr_twitter_cards_data', true);
        wp_send_json_success([
            'success' => 'success',
            'message' => __('Card Data Deleted Successfully!', 'wpsocialreviews')
        ]);
    }

    public function saveGlobalSettings()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/save_global_settings_' . $platform);
    }

    public function getGlobalSettings()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/get_global_settings_' . $platform);
    }

    public function setYoutubeAccountData()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/set_youtube_account_data' . $platform);
    }

    public function setAccountData()
    {
        $platform = sanitize_text_field($_REQUEST['platform']);
        do_action('wpsocialreviews/set_account_data_' . $platform);
    }

    public function saveTwitterCards()
    {
        $card_items = array();

        foreach ($_POST['urls'] as $url) {
            $card_items[] = array(
                'id' => sanitize_text_field($url['id']),
                'url' => esc_url_raw($url['url'])
            );
        }


        $cards = (new ManageCard())->processUrl($card_items);

        $twitter_card = array();

        foreach ($cards as $card) {
            $url = $card['url'];
            // $twitter_card = $card['twitter_card'];

            $twitter_card[$card['id']] = array(
                'url' => $url,
                'twitter_card' => $card['twitter_card'],
                'is_new' => $card['is_new']
            );
        }

        echo wp_json_encode($twitter_card);

        die();
    }

}
