<?php
namespace WPSocialReviews\Classes\Builder;

class Chat
{

    public function chatRegister()
    {
        add_action('wp_footer', array($this, 'render'));
    }

    /**
     *  Render messenger template
     *
     * @return string
     * @throws /Exception
     */
    public function render()
    {

        $messengerSettings = get_option('wpsr_messenger_settings', false);

        if (!$messengerSettings) {
            $messengerSettings = get_option('messenger_settings', false);
        }
        $whatsappSettings = get_option('wpsr_whatsapp_settings', false);
        $telegramSettings = get_option('wpsr_telegram_settings', false);

        $count = 0;
        $messengerSettings ? $count++ : $count;
        $whatsappSettings ? $count++ : $count;
        $telegramSettings ? $count++ : $count;

        $check_has_multiplatform = $count > 1 ? 'wpsr-multiplatform-chat' : '';

        if ($whatsappSettings) {
            $html = '';

            $html .= $this->loadView('chat-templates/template1', array(
                'messenger_settings' => $whatsappSettings,
                'check_has_multiplatform' => $check_has_multiplatform
            ));

            echo $html;
        }

        if ($messengerSettings) {
            $html = '';

            $html .= $this->loadView('chat-templates/template1', array(
                'messenger_settings' => $messengerSettings,
                'check_has_multiplatform' => $check_has_multiplatform
            ));

            echo $html;
        }

        if ($telegramSettings) {
            $html = '';

            $html .= $this->loadView('chat-templates/template1', array(
                'messenger_settings' => $telegramSettings,
                'check_has_multiplatform' => $check_has_multiplatform
            ));

            echo $html;
        }

        $page_id = get_the_ID();
        $settings = array();
        $messenger_has_chat = false;
        $wahtsapp_has_chat = false;
        $telegram_has_chat = false;
        $page_list = array();


        if (isset($messengerSettings['chat_settings'])) {
            $settings = $messengerSettings['chat_settings'];
            $settings = $settings[$settings['template']];

            $page_list = isset($settings['additional_settings']['page_list']) ? $settings['additional_settings']['page_list'] : array('-1');
            $all_page = in_array('-1', $page_list);
            $messenger_has_chat = $all_page ? $all_page : in_array($page_id, $page_list);
        }

        if (isset($whatsappSettings['chat_settings'])) {
            $settings = $whatsappSettings['chat_settings'];
            $settings = $settings[$settings['template']];

            $page_list = isset($settings['additional_settings']['page_list']) ? $settings['additional_settings']['page_list'] : array('-1');
            $all_page = in_array('-1', $page_list);
            $wahtsapp_has_chat = $all_page ? $all_page : in_array($page_id, $page_list);
        }

        if (isset($telegramSettings['chat_settings'])) {
            $settings = $telegramSettings['chat_settings'];
            $settings = $settings[$settings['template']];

            $page_list = isset($settings['additional_settings']['page_list']) ? $settings['additional_settings']['page_list'] : array('-1');
            $all_page = in_array('-1', $page_list);
            $telegram_has_chat = $all_page ? $all_page : in_array($page_id, $page_list);
        }

        if ($messenger_has_chat || $wahtsapp_has_chat || $telegram_has_chat) {
            $this->addAssets();
        }

    }

    /**
     *  Load template file
     *
     * @param $fileName
     * @param $data
     *
     * @return string
     */
    public function loadView($fileName, $data)
    {
        // normalize the filename
        $fileName = str_replace(array('../', './'), '', $fileName);
        $basePath = apply_filters(
            'wpsocialreviews/chat_template_base_path',
            WPSOCIALREVIEWS_DIR . 'includes/views/',
            $fileName,
            $data
        );
        $filePath = $basePath . $fileName . '.php';
        extract($data);
        ob_start();
        include $filePath;
        return ob_get_clean();
    }

    /**
     *  Enqueue All Front-End Assets
     *
     * @param
     */
    public function addAssets()
    {
        wp_enqueue_style(
            'wpsocialreviews_chat',
            WPSOCIALREVIEWS_URL . 'assets/css/social-review-chat.css',
            array(),
            WPSOCIALREVIEWS_VERSION
        );
        wp_enqueue_script('wpsocialreviews_chat', WPSOCIALREVIEWS_URL . 'assets/js/chat.js', array('jquery'), WPSOCIALREVIEWS_VERSION, true);
    }

}

