<?php

namespace WPSocialReviews\Classes\Builder;

use WPSocialReviews\Classes\Helper;
use WPSocialReviews\Classes\ArrayHelper;
use WPSocialReviews\Classes\Models\ReviewsModel;
use WPSocialReviews\Classes\Feeds\Twitter\TwitterFeed;
use WPSocialReviews\Classes\Feeds\Youtube\YoutubeFeed;

//for instagram configs
use WPSocialReviews\Classes\Feeds\Instagram\InstagramFeed;
use WPSocialReviews\Classes\Feeds\Common\FeedFilters;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Render Class
 * @since 1.0.0
 */
class Render
{

    public $feedJson;
    public $popupSettings;
    public $additionalSettings;
    public $uniqueId;

    /**
     *  Render template by template id
     *
     * @param $templateId
     *
     * @return string
     * @throws /Exception
     */
    public function render($templateId, $platform)
    {
        if (empty($platform) && $templateId) {
            return __('Please, set a template platform on your shortcode', 'wpsocialreviews');
        } else {
            $methodName = str_replace('_', ucfirst($platform), 'render_Templates');
            return self::$methodName($templateId);
        }
    }

    public static function renderReviewsTemplates($templateId, $page = 1)
    {

        $template_meta = get_post_meta($templateId, '_wpsr_template_config', true);
        if (!$template_meta || empty($template_meta)) {
            $template_meta = array();
        }
        $template_meta = ReviewsModel::formattedTemplateMeta($template_meta);

        if ($template_meta) {
            if (empty($template_meta['platform'])) {
                return __('Sorry! We could not get any reviews', 'wpsocialreviews');
            }

            //$business_info = isset($template_meta['platform']) ? get_option('social_review_'.$template_meta['platform'][0].'_business_info') : [];
            $validTemplatePlatforms = isset($template_meta['platform']) ? $template_meta['platform'] : array();
            $key = array_keys($validTemplatePlatforms)[0];
            $business_info = array();
            if (isset($validTemplatePlatforms[$key])) {
                $business_info = get_option('social_review_' . $validTemplatePlatforms[$key] . '_business_info');
            }

            $multi_business_info = Helper::getMultiBusinessInfo($template_meta['platform']);

            $business_info = sizeof($template_meta['platform']) > 1 ? $multi_business_info : $business_info;

            $reviews = array();
            $totalReviews = 0;

            $platforms = isset($template_meta['platform']) ? $template_meta['platform'] : [];
            $activePlatforms = apply_filters('wpsocialreviews/available_valid_platforms', []);
            $validTemplatePlatforms = array_intersect($platforms, array_keys($activePlatforms));

            //add custom with platforms if custom reviews exists
            $isCustomReviewsExists = ReviewsModel::isCustomFound();

            if ($isCustomReviewsExists && in_array('custom', $platforms)) {
                $validTemplatePlatforms['custom'] = __('Custom', 'wpsocialreviews');
            }

            if (!empty($validTemplatePlatforms)) {
                $data = ReviewsModel::getPaginatedFilteredReviewsByPlatforms($validTemplatePlatforms, $template_meta);
                $reviews = $data['reviews'];
                $totalReviews = $data['total_reviews'];
            }

            $templateMapping = apply_filters(
                'wpsocialreviews/add_reviews_template',
                [
                    'grid1' => 'reviews-templates/template1',
                    'grid2' => 'reviews-templates/template2',
                    'grid3' => 'reviews-templates/template3',
                    'grid4' => 'reviews-templates/template4',
                    'grid5' => 'reviews-templates/template5',
                ]
            );

            if (empty($template_meta['template']) || empty($reviews)) {
                return __('Sorry! We could not get any reviews', 'wpsocialreviews');
            }

            $template = $template_meta['template'];

            if (!isset($templateMapping[$template])) {
                return __('No Templates found!! Please save and try again', 'wpsocialreviews');
            }

            $file = $templateMapping[$template];

            $html = '';
            $sliderData = [];
            if ($template_meta['templateType'] === 'slider') {
                $sliderData = array(
                    'autoplay' => $template_meta['autoplay'],
                    'autoplay_speed' => $template_meta['autoplay_speed'],
                    'slides_to_show' => $template_meta['slides_to_show'],
                    'slides_to_scroll' => $template_meta['slides_to_scroll'],
                    'slider_navigation_type' => $template_meta['slider_navigation_type'],
                );
            }

            $masonry = $template_meta['templateType'] === 'masonry' ? 'wpsr-active-masonry-layout' : '';

            $fixed_height = isset($template_meta['show_header']) && $template_meta['show_header'] === 'true' ? 'wpsr-fixed-height' : '';
            $html .= '<div class="wpsr-reviews-wrapper">';
            $html .= '<div class="wpsr-container ' . esc_attr($fixed_height) . '" style="max-width:' . esc_attr($template_meta['template_width']) . '" >';

            if ((isset($template_meta['show_header']) && $template_meta['show_header'] === 'true') && !empty($business_info) && defined('WPSOCIALREVIEWS_PRO')) {
                $html .= self::loadView('reviews-templates/header', array(
                    'reviews' => $reviews,
                    'business_info' => $business_info,
                    'template_meta' => $template_meta
                ));
            }

            $html .= isset($template_meta['show_header']) && $template_meta['show_header'] === 'true' ? '<div class="wpsr-row" style="height:' . esc_attr($template_meta['template_height']) . '">' : '';

            do_action('wpsocialreviews/reviews_template_wrapper_start');

            $has_header = isset($template_meta['show_header']) && $template_meta['show_header'] === 'true' ? 'wpsr-review-fixed-height-wrap' : 'wpsr-row';

            $html .= ($template_meta['templateType'] === 'slider') ? '<div class="wpsr-reviews-slider" id="wpsr-reviews-slider' . esc_attr($templateId) . '" data-slider_settings=' . json_encode($sliderData) . ' >'
                : '<div class="' . esc_attr($has_header) . ' ' . esc_attr($masonry) . '" id="wpsr-reviews-grid-' . esc_attr($templateId) . '" data-column="' . esc_attr($template_meta['column']) . '">';

            $html .= self::loadView($file, array(
                'reviews' => $reviews,
                'template_meta' => $template_meta
            ));

            $html .= '</div>';

            do_action('wpsocialreviews/reviews_template_wrapper_end');

            $totalReviews = ( $template_meta['totalReviewsVal'] && $template_meta['totalReviewsVal'] === -1 ) ? $totalReviews : (int)$template_meta['totalReviewsVal'] ; 
            if (($template_meta['templateType'] !== 'slider' && $template_meta['pagination_type'] === 'load_more') && ($totalReviews > $template_meta['paginate'])) {
                $html .= '<div class="wpsr-reviews-loadmore" id="wpsr-reviews-load-more-btn' . esc_attr($templateId) . '" data-paginate="' . esc_attr($template_meta['paginate']) . '" data-template-id="' . esc_attr($templateId) . '" data-template-type="' . $template_meta['templateType'] . '" data-total="' . $totalReviews . '"><span>' . __('More Reviews', 'wpsocialreviews') . '</span></div>';
            }

            $html .= $template_meta['show_header'] === 'true' ? '</div>' : '';

            $html .= '</div>';
            $html .= '</div>';

            return apply_filters('wpsocialreviews/rendered_reviews_template_html', $html, $reviews, $template_meta);
        } else {
            $html = '<p>' . __('No template is available for this shortcode!!', 'wpsocialreviews') . '</p>';
            return $html;
        }

    }

    public function renderYoutubeTemplates($templateId)
    {

        $feed_template_meta = get_post_meta($templateId, '_wpsr_youtube_template_config', true);

        if ($feed_template_meta) {

            $obj = new YoutubeFeed();

            //get formatted data
            $configs = isset($feed_template_meta['feed_settings']) ? $feed_template_meta['feed_settings'] : array();
            $formatted_feed_template_meta = $obj->formatYoutubeConfig($configs, array());

            //feed settings to simplify repetitive use
            $feed_settings = isset($formatted_feed_template_meta['feed_settings']) ? $formatted_feed_template_meta['feed_settings'] : array();

            //get dynamic response
            $apiSettings = isset($feed_settings['source_settings']) ? $feed_settings['source_settings'] : array();
            $response = $obj->apiConnection($apiSettings, $templateId);

            //filter the feeds
            $filterSettings = isset($feed_settings['filters']) ? $feed_settings['filters'] : array();
            $filterResponse = array();

            if (isset($response['error_message'])) {
                $filterResponse = $response;
            } else {
                $filterResponse = (new FeedFilters)->filterFeedResponse('youtube', $filterSettings, $response);
            }

            //template mapping
            $templateMapping = apply_filters(
                'wpsocialreviews/add_youtube_template',
                [
                    'template1' => 'feed-templates/youtube/template1',
                    'template2' => 'feed-templates/youtube/template1',
                    'template3' => 'feed-templates/youtube/template1',
                ]
            );

            $template = isset($feed_settings['template']) ? $feed_settings['template'] : '';
            // render template 1, template 2, template 3 from template 1
            $template = !defined('WPSOCIALREVIEWS_PRO') && ($template === 'template2' || $template === 'template3') ? 'template1' : $template;

            if (!isset($templateMapping[$template])) {
                return __('No Templates found!! Please save and try again', 'wpsocialreviews');
            }

            if (isset($filterResponse['error_message'])) {
                return '<p>' . __($filterResponse['error_message'], 'wpsocialreviews') . '</p>';
            }

            $file = $templateMapping[$template];

            //carousel
            $layout_type = isset($feed_settings['layout_type']) ? $feed_settings['layout_type'] : 'grid';

            $dataAttrs = array();
            $sliderData = array();
            if ($layout_type === 'carousel') {
                $sliderData = array(
                    'autoplay' => $feed_settings['carousel_settings']['autoplay'],
                    'autoplay_speed' => $feed_settings['carousel_settings']['autoplay_speed'],
                    'rows' => $feed_settings['carousel_settings']['rows'],
                    'slides_to_show' => $feed_settings['carousel_settings']['slides_to_show'],
                    'slides_to_scroll' => $feed_settings['carousel_settings']['slides_to_scroll'],
                    'slider_navigation_type' => $feed_settings['carousel_settings']['navigation'],
                    'vertical' => $feed_settings['carousel_settings']['vertical'],
                );
            }
            $dataAttrs[] = $layout_type === 'carousel' ? 'data-slider_settings="' . esc_attr(json_encode($sliderData)) . '"' : '';

            //header and feeds 
            $header = isset($filterResponse['channel_info']) ? $filterResponse['channel_info'] : array();
            $feeds = isset($filterResponse['items']) ? $filterResponse['items'] : array();

            //pagination settings
            $sinceId = 0;
            $paginate = isset($feed_settings['pagination_settings']) ? intval($feed_settings['pagination_settings']['paginate']) : 6;
            $maxId = ($sinceId + $paginate) - 1;

            $totalFeed = is_array($feeds) ? count($feeds) : 0;
            $totalFilterFeed = isset($filterSettings['total_posts']) ? (int)$filterSettings['total_posts'] : 0;

            $total = ( $totalFeed < $totalFilterFeed ) ? $totalFeed : $totalFilterFeed;

            $pagination_type = isset($feed_settings['pagination_settings']) ? $feed_settings['pagination_settings']['pagination_type'] : 'none';
            if ($layout_type === 'carousel' || $pagination_type === 'none') {
                $sinceId = 0;
                $maxId = count($feeds);
            }

            // wrapper classes
            $classes = array('wpsr-yt-feed-wrapper');
            $classes[] = 'wpsr-yt-feed-' . esc_attr($template) . '';
            $classes[] = $layout_type === 'carousel' ? 'wpsr-youtube-slider-activate' : '';
            $column_gaps = isset($feed_settings['column_gaps']) ? $feed_settings['column_gaps'] : 'default';

            //specific for youtube
            $feed_info = isset($formatted_feed_template_meta['feed_info']) ? $formatted_feed_template_meta['feed_info'] : array();

            //render html
            $html = '';
            do_action('wpsocialreviews/youtube_template_wrapper_start');

            $html .= '<div id="wpsr-yt-feed-' . esc_attr($templateId) . '" class="' . implode(' ', $classes) . '" ' . implode(' ', $dataAttrs) . '>';
            $html .= '<div class="wpsr-container">';

            //render header
            if ((isset($feed_settings['header_settings']) && $feed_settings['header_settings']['display_header'] === 'true')) {

                if (!empty($header)) {
                    $html .= self::loadView('feed-templates/youtube/header', array(
                        'header' => $header,
                        'template_header_meta' => $feed_settings,
                    ));
                }

            }

            if (isset($feed_settings['video_settings']) && $feed_settings['video_settings']['play_mode'] === 'gallery') {
                $videoId = null;

                if (!empty($feeds[0]) && isset($feeds[0]['snippet']['resourceId'])) {
                    $videoId = $feeds[0]['snippet']['resourceId']['videoId'];
                } elseif (!empty($feeds[0]) && isset($feeds[0]['video_statistics'])) {
                    $videoId = $feeds[0]['video_statistics']['items'][0]['id'];
                }

                $html .= '<div class="wpsr-row">';
                $html .= '<div class="wpsr-col-12">';
                $html .= '<div class="wpsr-yt-video wpsr-yt-video-player-gallery">';
                $html .= '<iframe src="https://www.youtube.com/embed/' . esc_attr($videoId) . '?autoplay=0" frameborder="0" allowfullscreen></iframe>';
                $html .= '</div>';
                $html .= '</div>';
                $html .= '</div>';
            }

            if (($layout_type !== 'carousel' && $pagination_type === 'prev_next') && (isset($feed_settings['video_settings']) && $feed_settings['video_settings']['play_mode'] === 'gallery')) {
                $html .= apply_filters('wpsocialreviews/render_youtube_prev_next_pagination', $templateId, $paginate, $total, 'gallery');
            }

            $html .= '<div class="wpsr-row wpsr-yt-all-feed wpsr-column-gap-' . esc_attr($column_gaps) . '">';

            //render feeds
            $html .= self::loadView($file, array(
                'templateId' => $templateId,
                'feeds' => $feeds,
                'template_meta' => $feed_settings,
                'total' => $total,
                'sinceId' => $sinceId,
                'maxId' => $maxId,
                'feed_info' => $feed_info
            ));

            $html .= '</div>'; // row end

            //pagination
            if ( $total > $paginate && $layout_type !== 'carousel' && $pagination_type === 'load_more') {
                $html .= '<div class="wpsr-row"><div class="wpsr-yt-load-more wpsr-load-more-default"
                id="wpsr-yt-load-more-btn-' . esc_attr($templateId) . '"
                data-paginate="' . esc_attr($paginate) . '"
                data-template-id="' . esc_attr($templateId) . '"
                data-total="' . esc_attr($total) . '">
                ' . __('Load More', 'wpsocialreviews') . '
                <div class="wpsr-load-icon-wrapper"><span></span></div>
            </div></div>';
            }

            if (($layout_type !== 'carousel' && $pagination_type === 'prev_next' && defined('WPSOCIALREVIEWS_PRO')) && (isset($feed_settings['video_settings']) && $feed_settings['video_settings']['play_mode'] !== 'gallery')) {
                $html .= apply_filters('wpsocialreviews/render_youtube_prev_next_pagination', $templateId, $paginate, $total, '');
            }

            $html .= '</div>';

            $html .= '</div>';

            do_action('wpsocialreviews/youtube_template_wrapper_end');

            return apply_filters('wpsocialreviews/rendered_youtube_template_html', $html, $feeds, $feed_settings);

        } else {
            $html = '<p>' . __('No template is available for this shortcode!!', 'wpsocialreviews') . '</p>';
            return $html;
        }

    }

    public function renderInstagramTemplates($templateId)
    {
        $feed_template_meta = get_post_meta($templateId, '_wpsr_instagram_template_config', true);

        if ($feed_template_meta) {

            $obj = new InstagramFeed();

            //get formatted data
            $configs = isset($feed_template_meta['feed_settings']) ? $feed_template_meta['feed_settings'] : array();
            $formatted_feed_template_meta = $obj->formatInstagramConfig($configs, array());

            //feed settings to simplify repetitive use
            $feed_settings = isset($formatted_feed_template_meta['feed_settings']) ? $formatted_feed_template_meta['feed_settings'] : array();

            //get dynamic response
            // $apiSettings 	 = isset($feed_settings['source_settings']) ? $feed_settings['source_settings'] : array();
            $response = $obj->templateApiHandler($feed_settings);

            //filter the feeds
            $filterSettings = isset($feed_settings['filters']) ? $feed_settings['filters'] : array();

            $filterResponse = array();
            if (isset($response['error_message'])) {
                $filterResponse = $response;
            } else {
                $filterResponse = (new FeedFilters)->filterFeedResponse('instagram', $filterSettings, $response);
            }

            //template mapping
            $templateMapping = apply_filters(
                'wpsocialreviews/add_instagram_template',
                [
                    'template1' => 'feed-templates/instagram/template1',
                    'template2' => 'feed-templates/instagram/template2',
                ]
            );
            $template = isset($feed_settings['template']) ? $feed_settings['template'] : '';

            if (!isset($templateMapping[$template])) {
                return '<p>' . __('No Templates found!! Please save and try again', 'wpsocialreviews') . '</p>';
            }
            if (isset($filterResponse['error_message'])) {
                return '<p>' . __($filterResponse['error_message'], 'wpsocialreviews') . '</p>';
            }
            $file = $templateMapping[$template];

            //carousel 
            $layout_type = isset($feed_settings['layout_type']) ? $feed_settings['layout_type'] : 'grid';
            $dataAttrs = array();
            $sliderData = array();
            if ($layout_type === 'carousel') {
                $sliderData = array(
                    'autoplay' => $feed_settings['carousel_settings']['autoplay'],
                    'autoplay_speed' => $feed_settings['carousel_settings']['autoplay_speed'],
                    'slides_to_show' => $feed_settings['carousel_settings']['slides_to_show'],
                    'slides_to_scroll' => $feed_settings['carousel_settings']['slides_to_scroll'],
                    'slider_navigation_type' => $feed_settings['carousel_settings']['navigation'],
                );
            }
            $dataAttrs[] = $layout_type === 'carousel' ? 'data-slider_settings="' . esc_attr(json_encode($sliderData)) . '"' : '';

            // wrapper classes
            $classes = array('wpsr-ig-feed-wrapper');
            $classes[] = 'wpsr-ig-feed-' . esc_attr($template) . '';
            $classes[] = $layout_type === 'carousel' ? 'wpsr-instagram-slider-activate' : '';
            $classes[] = $layout_type === 'masonry' ? 'wpsr-instagram-masonry-activate' : '';
            $column_gaps = isset($feed_settings['column_gaps']) ? $feed_settings['column_gaps'] : 'default';

            //header and feeds
            $connected_ids = get_option('wpsr_instagram_configs', array());
            $connected_ids = isset($connected_ids['connected_accounts']) ? $connected_ids['connected_accounts'] : array();
            $connected_ids = json_decode(json_encode($connected_ids), true);
            $connectedId = isset($feed_settings['header_settings']['account_to_show']) ? $feed_settings['header_settings']['account_to_show'] : null;
            $connectedIdDetails = isset($connected_ids[$connectedId]) ? $connected_ids[$connectedId] : null;

            $feeds = $filterResponse['items'];

            //pagination settings
            $sinceId = 0;
            $paginate = isset($feed_settings['pagination_settings']) ? intval($feed_settings['pagination_settings']['paginate']) : 6;
            $maxId = ($sinceId + $paginate) - 1;
            $total = count($feeds);
            $pagination_type = isset($feed_settings['pagination_settings']) ? $feed_settings['pagination_settings']['pagination_type'] : 'none';
            if ($layout_type === 'carousel' || $pagination_type === 'none') {
                $sinceId = 0;
                $maxId = count($feeds);
            }

            $popupSettings = isset($feed_settings['popup_settings']) ? $feed_settings['popup_settings'] : array();
            $headerSettings = isset($feed_settings['header_settings']) ? $feed_settings['header_settings'] : array();

            //set all data, settings for popup
            $additionalSettings = array(
                'assets_url' => WPSOCIALREVIEWS_URL . 'assets',
                'connected_id' => $connectedIdDetails['user_avatar'],
                'header_settings' => $headerSettings
            );

            $this->feedJson = json_encode($feeds);
            $this->popupSettings = json_encode($popupSettings);
            $this->additionalSettings = json_encode($additionalSettings);
            $this->uniqueId = $templateId;

            if (isset($feed_settings['post_settings']['display_mode'])) {
                add_action('wp_footer', array($this, 'igPopupMetaSettings'));
            }

            // render html
            $html = '';
            $html .= '<div id="wpsr-ig-feed-' . esc_attr($templateId) . '" class="' . implode(' ', $classes) . '" ' . implode(' ', $dataAttrs) . '  data-column="' . esc_attr($feed_settings['column_number']) . '">';
            $html .= '<div class="wpsr-container">';

            //render header
            if ((isset($feed_settings['header_settings']) && $feed_settings['header_settings']['display_header'] === 'true')) {

                if (!empty($connectedIdDetails)) {
                    $html .= self::loadView('feed-templates/instagram/header', array(
                        'connected_id_details' => $connectedIdDetails,
                        'header' => $filterResponse['header'],
                        'header_settings' => $feed_settings['header_settings'],
                        'follow_button_settings' => $feed_settings['follow_button_settings'],
                        'column_gaps' => $column_gaps
                    ));
                }

            }

            $html .= '<div class="wpsr-row wpsr-ig-all-feed wpsr-column-gap-' . esc_attr($column_gaps) . '"">';

            //render feeds
            $html .= self::loadView($file, array(
                'templateId' => $templateId,
                'feeds' => $feeds,
                'template_meta' => $feed_settings,
                'sinceId' => $sinceId,
                'maxId' => $maxId,
            ));

            $html .= '</div>';

            $mt_30 = $column_gaps === 'no_gap' ? 'wpsr-mt-20' : '';
            $html .= '<div class="wpsr-ig-footer wpsr-row ' . esc_attr($mt_30) . '">';

            //pagination
            if ( count($feeds) > $paginate && $layout_type !== 'carousel' && $pagination_type === 'load_more' && defined('WPSOCIALREVIEWS_PRO')) {
                $html .= '<div class="wpsr-ig-load-more wpsr-load-more-default"
                    id="wpsr-ig-load-more-btn-' . esc_attr($templateId) . '"
                    data-paginate="' . esc_attr($paginate) . '"
                    data-template-id="' . esc_attr($templateId) . '"
                    data-template-type="' . esc_attr($layout_type) . '"
                    data-total="' . esc_attr($total) . '">
                    ' . __('Load More', 'wpsocialreviews') . '
                <div class="wpsr-load-icon-wrapper"><span></span></div>
                </div>';
            }

            if (!empty($connectedIdDetails) && isset($feed_settings['follow_button_settings']['follow_button_position']) && $feed_settings['follow_button_settings']['follow_button_position'] !== 'header') {
                $html .= self::loadView('feed-templates/instagram/footer', array(
                    'connected_id_details' => $connectedIdDetails,
                    'follow_button_settings' => $feed_settings['follow_button_settings']
                ));
            }

            $html .= '</div>';

            $html .= '</div>';
            $html .= '</div>';

            return apply_filters('wpsocialreviews/rendered_instagram_template_html', $html, $feeds, $feed_settings);

        } else {
            $html = '<p>' . __('No template is available for this shortcode!!', 'wpsocialreviews') . '</p>';
            return $html;
        }
    }

    public function igPopupMetaSettings()
    {
        ?>
        <script type="text/javascript">

            if (!window.InstagramFrontEndJson) {
                window.InstagramFrontEndJson = {};
            }
            if (!window.InstagramPopupSettings) {
                window.InstagramPopupSettings = {};
            }
            if (!window.InstagramAdditionalSettings) {
                window.InstagramAdditionalSettings = {};
            }

            window.InstagramFrontEndJson["<?= $this->uniqueId ?>"] = <?= $this->feedJson ?>;
            window.InstagramPopupSettings["<?= $this->uniqueId ?>"] = <?= $this->popupSettings ?>;
            window.InstagramAdditionalSettings["<?= $this->uniqueId ?>"] = <?= $this->additionalSettings ?>;

        </script>
        <?php
    }

    public function renderTwitterTemplates($templateId)
    {

        $feed_template_meta = get_post_meta($templateId, '_wpsr_twitter_template_config', true);

        if ($feed_template_meta) {

            $obj = new TwitterFeed();

            //get formatted data
            $configs = isset($feed_template_meta['feed_settings']) ? $feed_template_meta['feed_settings'] : array();
            $formatted_feed_template_meta = $obj->formatTwitterConfig($configs, array());

            //feed settings to simplify repetitive use
            $feed_settings = isset($formatted_feed_template_meta['feed_settings']) ? $formatted_feed_template_meta['feed_settings'] : array();

            //get dynamic response
            $apiSettings = isset($feed_settings['additional_settings']) ? $feed_settings['additional_settings'] : array();
            $response = $obj->apiConnectionResponse($apiSettings['feed_type'], $apiSettings['feed_count'], $formatted_feed_template_meta);

            //filter the feeds
            $filterSettings = isset($feed_settings['filters']) ? $feed_settings['filters'] : array();

            $filterResponse = array();
            if (isset($response['error_message'])) {
                $filterResponse = $response;
            } else {
                $filterResponse = (new FeedFilters)->filterFeedResponse('twitter', $filterSettings, $response);
            }

            //header and feeds 
            $feeds = isset($filterResponse['feed']) ? $filterResponse['feed'] : $filterResponse;
            $header = isset($filterResponse['header']) ? $filterResponse['header'] : $filterResponse;

            //pagination settings
            $sinceId = 0;
            $paginate = intval($feed_settings['pagination_settings']['paginate']);
            $maxId = ($sinceId + $paginate) - 1;

            $totalFeed = is_array($feeds) ? count($feeds) : 0;
            $totalFilterFeed = isset($filterSettings['total_posts']) ? (int)$filterSettings['total_posts'] : 0;

            $total = ( $filterSettings['total_posts'] && $totalFeed < $totalFilterFeed ) ? $totalFeed : $totalFilterFeed; 


            $pagination_type = isset($feed_settings['pagination_settings']['pagination_type']) ? $feed_settings['pagination_settings']['pagination_type'] : 'none';
            $column_gaps = isset($feed_settings['column_gaps']) ? $feed_settings['column_gaps'] : 'default';

            $layout_type = isset($feed_settings['layout_type']) ? $feed_settings['layout_type'] : 'standard';
            if ($layout_type === 'carousel' || $pagination_type === 'none') {
                $sinceId = 0;
                $maxId = is_array($feeds) ? count($feeds) : 0;
            }

            //carousel 
            $sliderData = array();
            if ($layout_type === 'carousel') {
                $sliderData = array(
                    'autoplay' => $feed_settings['carousel_settings']['autoplay'],
                    'autoplay_speed' => $feed_settings['carousel_settings']['autoplay_speed'],
                    'slides_to_show' => $feed_settings['carousel_settings']['slides_to_show'],
                    'slides_to_scroll' => $feed_settings['carousel_settings']['slides_to_scroll'],
                    'slider_navigation_type' => $feed_settings['carousel_settings']['navigation'],
                );
            }
            $row = $layout_type === 'masonry' ? 'wpsr-row' : '';

            // wrapper classes
            $classes = array();
            $classes[] = $layout_type ? 'wpsr-twitter-' . $layout_type : '';
            $classes[] = $layout_type !== 'standard' ? 'wpsr-container' : 'wpsr-twitter-tweets-wrapper';
            $classes[] = $pagination_type === 'infinite' ? 'wpsr-twitter-infinite-scroll-active' : '';

            $classes[] = (isset($feed_settings['advance_settings']) && $feed_settings['advance_settings']['show_twitter_card'] === 'true') && defined('WPSOCIALREVIEWS_PRO') ? 'wpsr-twitter-card-wrapper' : '';

            $dataAttrs = array();
            $dataAttrs[] = isset($feed_settings['column_number']) && $layout_type === 'masonry' ? 'data-column="' . $feed_settings['column_number'] . '"' : '';
            $dataAttrs[] = $layout_type === 'carousel' ? 'data-slider_settings="' . esc_attr(json_encode($sliderData)) . '"' : '';


            // render html
            $html = '';
            $html .= '<div id="wpsr-twitter-tweet-' . esc_attr($templateId) . '" class="' . implode(' ', $classes) . '" ' . implode(' ', $dataAttrs) . '>';

            //render header
            if ((isset($feed_settings['header_settings']) && $feed_settings['header_settings']['show_header'] === 'true') && defined('WPSOCIALREVIEWS_PRO')) {
                $html .= self::loadView('feed-templates/twitter/header', array(
                    'header' => $header,
                    'template_meta' => $feed_settings
                ));
            }

            $html .= '<div class="wpsr-twitter-all-tweets ' . $row . ' wpsr-column-gap-' . esc_attr($column_gaps) . '">';

            $template = 'template1';

            $template = apply_filters('wpsocialreviews/add_twitter_template', $template, $layout_type);

            //render feeds
            $html .= self::loadView('feed-templates/twitter/' . $template . '', array(
                'feeds' => $feeds,
                'templateId' => $templateId,
                'template_meta' => $feed_settings,
                'paginate' => $paginate,
                'total' => $total,
                'sinceId' => $sinceId,
                'maxId' => $maxId,
            ));

            $html .= '</div>';

            //render pagination
            if ( $total > $paginate && $layout_type !== 'carousel' && $pagination_type !== 'none') {
                $html .= '<div class="wpsr-twitter-loadmore wpsr-load-more-default" id="wpsr-twitter-load-more-btn' . esc_attr($templateId) . '" data-template-id="' . esc_attr($templateId) . '" data-template-type="' . esc_attr($layout_type) . '" data-total="' . esc_attr($total) . '" data-paginate="' . esc_attr($paginate) . '" >' . __('Load More', 'wpsocialreviews') . '<div class="wpsr-load-icon-wrapper"><span></span></div></div>';
            }

            $html .= '</div>';

            return $html;
        } else {
            $html = '<p>' . __('No template is available for this shortcode!!', 'wpsocialreviews') . '</p>';
            return $html;
        }

    }

    /**
     *  Load template file
     *
     * @param $fileName
     * @param $data
     *
     * @return string
     */
    public static function loadView($fileName, $data)
    {
        // normalize the filename
        $fileName = str_replace(array('../', './'), '', $fileName);

        $basePath = apply_filters(
            'wpsocialreviews/reviews_template_base_path',
            WPSOCIALREVIEWS_DIR . 'includes/views/',
            $fileName,
            $data
        );

        $filePath = $basePath . $fileName . '.php';
        extract($data);
        ob_start();
        include $filePath;
        return ob_get_clean();
    }

}
