<?php

namespace WPSocialReviews\Classes\Chats;

use WPSocialReviews\Classes\Helper;

if (!defined('ABSPATH')) {
    exit;
}

class MessengerChat extends BaseChat
{

    public function __construct()
    {
        parent::__construct('messenger');
    }

    /**
     *
     * Save Credential
     *
     * @return json response
     * @since 1.0.0
     *
     **/
    public function saveChatCredential()
    {
        $args = wp_unslash($_REQUEST['args']);
        $messengerPage = json_decode($args);
        $pageId = $messengerPage->page_id;
        $messengerSettings = get_option('wpsr_messenger_settings', true);
        if (!$messengerSettings) {
            $messengerSettings = get_option('messenger_settings', true);
        }
        if (!$messengerSettings) {
            $messengerSettings = array();
        }
        $messengerConfig = self::getFormattedMessengerConfig($messengerSettings, false, $pageId);
        update_option('wpsr_messenger_settings', $messengerConfig, 'no');
        $messengerSettings = get_option('wpsr_messenger_settings', false);
        if (!$messengerSettings) {
            $messengerSettings = get_option('messenger_settings', true);
        }
        Helper::sendSuccess([
            'message' => __('Messenger Successfully Connected!', 'wpsocialreviews'),
            'connection_details' => $messengerSettings,
        ]);
    }

    /**
     *
     * Get Credential
     *
     * @return json response
     * @since 1.0.0
     */
    public function getChatCredential()
    {
        $messengerSettings = get_option('wpsr_messenger_settings', false);
        if (!$messengerSettings) {
            $messengerSettings = get_option('messenger_settings', true);
        }
        $formattedSettings = self::getFormattedMessengerConfig($messengerSettings, false);
        $pages = Helper::getPagesList();
        Helper::sendSuccess([
            'formatted' => true,
            'message' => 'success',
            'connection_details' => $formattedSettings,
            'pages' => $pages
        ]);
    }

    /**
     *
     * Get Credential
     *
     * @return array
     * @since 1.0.0
     */
    public static function getFormattedMessengerConfig($settings, $empty, $pageId = '')
    {
        if ($pageId) {
            $pageId = $pageId;
        }
        if (isset($settings['chat_settings']['page_id']) && !empty($settings['chat_settings']['page_id'])) {
            $pageId = $settings['chat_settings']['page_id'];
        }
        if ($empty) {
            $pageId = '';
        }
        $data = array(

            'chat_settings' => array(

                'template' => isset($settings['chat_settings']['template']) ? $settings['chat_settings']['template'] : 'template1',
                'page_id' => $pageId, //isset( $settings['chat_settings']['page_id'] ) ? $settings['chat_settings']['page_id'] : $pageId,
                'template1' => array(
                    'template' => 'template1',
                    'platform' => 'messenger',
                    'chat_header' => array(
                        'name' => isset($settings['chat_settings']['template1']['chat_header']['name']) ? $settings['chat_settings']['template1']['chat_header']['name'] : __('GutenDev', 'wpsocialreviews'),
                        'caption' => isset($settings['chat_settings']['template1']['chat_header']['caption']) ? $settings['chat_settings']['template1']['chat_header']['caption'] : __('Typically replies within an hour', 'wpsocialreviews'),
                        'picture' => isset($settings['chat_settings']['template1']['chat_header']['picture']) ? $settings['chat_settings']['template1']['chat_header']['picture'] : WPSOCIALREVIEWS_URL . 'assets/images/chat-imgs/user-profile.png'
                    ),
                    'chat_body' => array(
                        'greeting_msg' => isset($settings['chat_settings']['template1']['chat_body']['greeting_msg']) ? $settings['chat_settings']['template1']['chat_body']['greeting_msg'] : __('Hi! How can we help you?
                        ', 'wpsocialreviews')
                    ),
                    'chat_button' => array(
                        'button_text' => isset($settings['chat_settings']['template1']['chat_button']['button_text']) ? $settings['chat_settings']['template1']['chat_button']['button_text'] : __('Start Chat', 'wpsocialreviews'),
                        'button_base_url' => 'https://www.messenger.com/t/',
                        'button_url' => $pageId, //isset( $settings['chat_settings']['template1']['chat_button']['button_url'] ) ? $settings['chat_settings']['template1']['chat_button']['button_url'] : $pageId,
                        'display_icon' => isset($settings['chat_settings']['template1']['chat_button']['display_icon']) ? $settings['chat_settings']['template1']['chat_button']['display_icon'] : 'true'
                    ),
                    'chat_bubble' => array(
                        'cb_button_text' => isset($settings['chat_settings']['template1']['chat_bubble']['cb_button_text']) ? $settings['chat_settings']['template1']['chat_bubble']['cb_button_text'] : __('', 'wpsocialreviews'),
                        'cb_button_icon' => isset($settings['chat_settings']['template1']['chat_bubble']['cb_button_icon']) ? $settings['chat_settings']['template1']['chat_bubble']['cb_button_icon'] : 'icon7',
                    ),
                    'additional_settings' => array(
                        'chat_bubble_position' => isset($settings['chat_settings']['template1']['additional_settings']['chat_bubble_position']) ? $settings['chat_settings']['template1']['additional_settings']['chat_bubble_position'] : 'bottom-right',
                        'page_list' => isset($settings['chat_settings']['template1']['additional_settings']['page_list']) ? $settings['chat_settings']['template1']['additional_settings']['page_list'] : array('-1'),
                        'display_greeting' => isset($settings['chat_settings']['template1']['additional_settings']['display_greeting']) ? $settings['chat_settings']['template1']['additional_settings']['display_greeting'] : 'false',

                        //schedule time for chat to show
                        'day_time_schedule' => isset($settings['chat_settings']['template1']['additional_settings']['day_time_schedule']) && defined('WPSOCIALREVIEWS_PRO') ? $settings['chat_settings']['template1']['additional_settings']['day_time_schedule'] : 'false',
                        'day_list' => array(
                            __('Saturday', 'wpsocialreviews'),
                            __('Sunday', 'wpsocialreviews'),
                            __('Monday', 'wpsocialreviews'),
                            __('Tuesday', 'wpsocialreviews'),
                            __('Wednesday', 'wpsocialreviews'),
                            __('Thursday', 'wpsocialreviews'),
                            __('Friday', 'wpsocialreviews')
                        ),
                        'time_schedule' => isset($settings['chat_settings']['template1']['additional_settings']['time_schedule']) ? $settings['chat_settings']['template1']['additional_settings']['time_schedule'] : 'false',
                        'start_time' => isset($settings['chat_settings']['template1']['additional_settings']['start_time']) ? $settings['chat_settings']['template1']['additional_settings']['start_time'] : "03:07:26 PM",
                        'end_time' => isset($settings['chat_settings']['template1']['additional_settings']['end_time']) ? $settings['chat_settings']['template1']['additional_settings']['end_time'] : "03:07:26 PM",
                        'caption_when_offline' => isset($settings['chat_settings']['template1']['additional_settings']['caption_when_offline']) ? $settings['chat_settings']['template1']['additional_settings']['caption_when_offline'] : __('I will be back soon', 'wpsocialreviews')
                    ),
                    'styles' => array(
                        'button_color' => isset($settings['chat_settings']['template1']['styles']['button_color']) ? $settings['chat_settings']['template1']['styles']['button_color'] : '',
                        'header_color' => isset($settings['chat_settings']['template1']['styles']['header_color']) ? $settings['chat_settings']['template1']['styles']['header_color'] : '',
                        'header_title_color' => isset($settings['chat_settings']['template1']['styles']['header_title_color']) ? $settings['chat_settings']['template1']['styles']['header_title_color'] : '',
                        'header_caption_color' => isset($settings['chat_settings']['template1']['styles']['header_caption_color']) ? $settings['chat_settings']['template1']['styles']['header_caption_color'] : ''
                    )
                ),

                'template2' => array(
                    'template' => 'template2',
                    'platform' => 'messenger',
                    'chat_header' => array(
                        'name' => isset($settings['chat_settings']['template2']['chat_header']['name']) ? $settings['chat_settings']['template2']['chat_header']['name'] : __('Kavin Miller', 'wpsocialreviews'),
                        'caption' => isset($settings['chat_settings']['template2']['chat_header']['caption']) ? $settings['chat_settings']['template2']['chat_header']['caption'] : __('Typically replies within an hour', 'wpsocialreviews'),
                        'picture' => isset($settings['chat_settings']['template2']['chat_header']['picture']) ? $settings['chat_settings']['template2']['chat_header']['picture'] : WPSOCIALREVIEWS_URL . 'assets/images/chat-imgs/user-profile.png'
                    ),
                    'chat_body' => array(
                        'greeting_msg' => isset($settings['chat_settings']['template2']['chat_body']['greeting_msg']) ? $settings['chat_settings']['template2']['chat_body']['greeting_msg'] : __('Hey there 👋 ,  How can i help you?', 'wpsocialreviews')
                    ),
                    'chat_button' => array(
                        'button_text' => isset($settings['chat_settings']['template2']['chat_button']['button_text']) ? $settings['chat_settings']['template2']['chat_button']['button_text'] : __('Start Chat', 'wpsocialreviews'),
                        'button_base_url' => 'https://www.messenger.com/t/',
                        'button_url' => $pageId, // isset( $settings['chat_settings']['template2']['chat_button']['button_url'] ) ? $settings['chat_settings']['template2']['chat_button']['button_url'] : $pageId,
                        'display_icon' => isset($settings['chat_settings']['template2']['chat_button']['display_icon']) ? $settings['chat_settings']['template2']['chat_button']['display_icon'] : 'true'
                    ),
                    'chat_bubble' => array(
                        'cb_button_text' => isset($settings['chat_settings']['template2']['chat_bubble']['cb_button_text']) ? $settings['chat_settings']['template2']['chat_bubble']['cb_button_text'] : __('Need Help?', 'wpsocialreviews'),
                        'cb_button_icon' => isset($settings['chat_settings']['template2']['chat_bubble']['cb_button_icon']) ? $settings['chat_settings']['template2']['chat_bubble']['cb_button_icon'] : 'icon5',
                    ),
                    'additional_settings' => array(
                        'chat_bubble_position' => isset($settings['chat_settings']['template2']['additional_settings']['chat_bubble_position']) ? $settings['chat_settings']['template2']['additional_settings']['chat_bubble_position'] : 'bottom-right',
                        'page_list' => isset($settings['chat_settings']['template2']['additional_settings']['page_list']) ? $settings['chat_settings']['template2']['additional_settings']['page_list'] : array('-1'),
                        'display_greeting' => isset($settings['chat_settings']['template2']['additional_settings']['display_greeting']) ? $settings['chat_settings']['template2']['additional_settings']['display_greeting'] : 'false',

                        //schedule time for chat to show
                        'day_time_schedule' => isset($settings['chat_settings']['template2']['additional_settings']['day_time_schedule']) && defined('WPSOCIALREVIEWS_PRO') ? $settings['chat_settings']['template2']['additional_settings']['day_time_schedule'] : 'false',
                        'day_list' => array(
                            __('Saturday', 'wpsocialreviews'),
                            __('Sunday', 'wpsocialreviews'),
                            __('Monday', 'wpsocialreviews'),
                            __('Tuesday', 'wpsocialreviews'),
                            __('Wednesday', 'wpsocialreviews'),
                            __('Thursday', 'wpsocialreviews'),
                            __('Friday', 'wpsocialreviews')
                        ),
                        'time_schedule' => isset($settings['chat_settings']['template2']['additional_settings']['time_schedule']) ? $settings['chat_settings']['template2']['additional_settings']['time_schedule'] : 'false',
                        'start_time' => isset($settings['chat_settings']['template2']['additional_settings']['start_time']) ? $settings['chat_settings']['template2']['additional_settings']['start_time'] : "03:07:26 PM",
                        'end_time' => isset($settings['chat_settings']['template2']['additional_settings']['end_time']) ? $settings['chat_settings']['template2']['additional_settings']['end_time'] : "03:07:26 PM",
                        'caption_when_offline' => isset($settings['chat_settings']['template2']['additional_settings']['caption_when_offline']) ? $settings['chat_settings']['template2']['additional_settings']['caption_when_offline'] : __('I will be back soon', 'wpsocialreviews')
                    ),
                    'styles' => array(
                        'button_color' => isset($settings['chat_settings']['template2']['styles']['button_color']) ? $settings['chat_settings']['template2']['styles']['button_color'] : '',
                        'header_color' => isset($settings['chat_settings']['template2']['styles']['header_color']) ? $settings['chat_settings']['template2']['styles']['header_color'] : '',
                        'header_title_color' => isset($settings['chat_settings']['template2']['styles']['header_title_color']) ? $settings['chat_settings']['template2']['styles']['header_title_color'] : '',
                        'header_caption_color' => isset($settings['chat_settings']['template2']['styles']['header_caption_color']) ? $settings['chat_settings']['template2']['styles']['header_caption_color'] : ''
                    )
                ),

                'template3' => array(
                    'template' => 'template3',
                    'platform' => 'messenger',
                    'chat_header' => array(
                        'name' => isset($settings['chat_settings']['template3']['chat_header']['name']) ? $settings['chat_settings']['template3']['chat_header']['name'] : __('R. Thomas', 'wpsocialreviews'),
                        'caption' => isset($settings['chat_settings']['template3']['chat_header']['caption']) ? $settings['chat_settings']['template3']['chat_header']['caption'] : __('QA Manager', 'wpsocialreviews'),
                        'picture' => isset($settings['chat_settings']['template3']['chat_header']['picture']) ? $settings['chat_settings']['template3']['chat_header']['picture'] : WPSOCIALREVIEWS_URL . 'assets/images/chat-imgs/user-profile.png'
                    ),
                    'chat_body' => array(
                        'greeting_msg' => isset($settings['chat_settings']['template3']['chat_body']['greeting_msg']) ? $settings['chat_settings']['template3']['chat_body']['greeting_msg'] : __('Hi there 👋 . Quick question - How do you like our WP Social Ninja plugin so far?', 'wpsocialreviews')
                    ),
                    'chat_button' => array(
                        'button_text' => isset($settings['chat_settings']['template3']['chat_button']['button_text']) ? $settings['chat_settings']['template3']['chat_button']['button_text'] : __('Share Feedback', 'wpsocialreviews'),
                        'button_base_url' => 'https://www.messenger.com/t/',
                        'button_url' => $pageId, //isset( $settings['chat_settings']['template3']['chat_button']['button_url'] ) ? $settings['chat_settings']['template3']['chat_button']['button_url'] : $pageId,
                        'display_icon' => isset($settings['chat_settings']['template3']['chat_button']['display_icon']) ? $settings['chat_settings']['template3']['chat_button']['display_icon'] : 'true'
                    ),
                    'chat_bubble' => array(
                        'cb_button_text' => isset($settings['chat_settings']['template3']['chat_bubble']['cb_button_text']) ? $settings['chat_settings']['template3']['chat_bubble']['cb_button_text'] : __('Feedback', 'wpsocialreviews'),
                        'cb_button_icon' => isset($settings['chat_settings']['template3']['chat_bubble']['cb_button_icon']) ? $settings['chat_settings']['template3']['chat_bubble']['cb_button_icon'] : 'icon6',
                    ),
                    'additional_settings' => array(
                        'chat_bubble_position' => isset($settings['chat_settings']['template3']['additional_settings']['chat_bubble_position']) ? $settings['chat_settings']['template3']['additional_settings']['chat_bubble_position'] : 'bottom-right',
                        'page_list' => isset($settings['chat_settings']['template3']['additional_settings']['page_list']) ? $settings['chat_settings']['template3']['additional_settings']['page_list'] : array('-1'),
                        'display_greeting' => isset($settings['chat_settings']['template3']['additional_settings']['display_greeting']) ? $settings['chat_settings']['template3']['additional_settings']['display_greeting'] : 'false',

                        //schedule time for chat to show
                        'day_time_schedule' => isset($settings['chat_settings']['template3']['additional_settings']['day_time_schedule']) ? $settings['chat_settings']['template3']['additional_settings']['day_time_schedule'] : 'false',
                        'day_list' => array(
                            __('Saturday', 'wpsocialreviews'),
                            __('Sunday', 'wpsocialreviews'),
                            __('Monday', 'wpsocialreviews'),
                            __('Tuesday', 'wpsocialreviews'),
                            __('Wednesday', 'wpsocialreviews'),
                            __('Thursday', 'wpsocialreviews'),
                            __('Friday', 'wpsocialreviews')
                        ),
                        'time_schedule' => isset($settings['chat_settings']['template3']['additional_settings']['time_schedule']) ? $settings['chat_settings']['template3']['additional_settings']['time_schedule'] : 'false',
                        'start_time' => isset($settings['chat_settings']['template3']['additional_settings']['start_time']) ? $settings['chat_settings']['template3']['additional_settings']['start_time'] : "03:07:26 PM",
                        'end_time' => isset($settings['chat_settings']['template3']['additional_settings']['end_time']) ? $settings['chat_settings']['template3']['additional_settings']['end_time'] : "03:07:26 PM",
                        'caption_when_offline' => isset($settings['chat_settings']['template3']['additional_settings']['caption_when_offline']) ? $settings['chat_settings']['template3']['additional_settings']['caption_when_offline'] : __('I will be back soon', 'wpsocialreviews')
                    ),
                    'styles' => array(
                        'button_color' => isset($settings['chat_settings']['template3']['styles']['button_color']) ? $settings['chat_settings']['template3']['styles']['button_color'] : '',
                        'header_color' => isset($settings['chat_settings']['template3']['styles']['header_color']) ? $settings['chat_settings']['template3']['styles']['header_color'] : '',
                        'header_title_color' => isset($settings['chat_settings']['template3']['styles']['header_title_color']) ? $settings['chat_settings']['template3']['styles']['header_title_color'] : '',
                        'header_caption_color' => isset($settings['chat_settings']['template3']['styles']['header_caption_color']) ? $settings['chat_settings']['template3']['styles']['header_caption_color'] : ''
                    )
                ),

                'template4' => array(
                    'template' => 'template4',
                    'platform' => 'messenger',
                    'chat_header' => array(
                        'name' => isset($settings['chat_settings']['template4']['chat_header']['name']) ? $settings['chat_settings']['template4']['chat_header']['name'] : __('Shirley C. Lynn', 'wpsocialreviews'),
                        'caption' => isset($settings['chat_settings']['template4']['chat_header']['caption']) ? $settings['chat_settings']['template4']['chat_header']['caption'] : __('Sales Manager', 'wpsocialreviews'),
                        'picture' => isset($settings['chat_settings']['template4']['chat_header']['picture']) ? $settings['chat_settings']['template4']['chat_header']['picture'] : WPSOCIALREVIEWS_URL . 'assets/images/chat-imgs/user-profile.png'
                    ),
                    'chat_body' => array(
                        'greeting_msg' => isset($settings['chat_settings']['template4']['chat_body']['greeting_msg']) ? $settings['chat_settings']['template4']['chat_body']['greeting_msg'] : __('Looking for the WP Social Ninja offer? 🤑 I\'m happy to tell you about our promotional sale, up to 20% discount. Let me know if you\'ve any questions.', 'wpsocialreviews')
                    ),
                    'chat_button' => array(
                        'button_text' => isset($settings['chat_settings']['template4']['chat_button']['button_text']) ? $settings['chat_settings']['template4']['chat_button']['button_text'] : __('Start Chat', 'wpsocialreviews'),
                        'button_base_url' => 'https://www.messenger.com/t/',
                        'button_url' => $pageId, //isset( $settings['chat_settings']['template4']['chat_button']['button_url'] ) ? $settings['chat_settings']['template4']['chat_button']['button_url'] : $pageId,
                        'display_icon' => isset($settings['chat_settings']['template4']['chat_button']['display_icon']) ? $settings['chat_settings']['template4']['chat_button']['display_icon'] : 'true'
                    ),
                    'chat_bubble' => array(
                        'cb_button_text' => isset($settings['chat_settings']['template4']['chat_bubble']['cb_button_text']) ? $settings['chat_settings']['template4']['chat_bubble']['cb_button_text'] : __('', 'wpsocialreviews'),
                        'cb_button_icon' => isset($settings['chat_settings']['template4']['chat_bubble']['cb_button_icon']) ? $settings['chat_settings']['template4']['chat_bubble']['cb_button_icon'] : 'icon2',
                    ),
                    'additional_settings' => array(
                        'chat_bubble_position' => isset($settings['chat_settings']['template4']['additional_settings']['chat_bubble_position']) ? $settings['chat_settings']['template4']['additional_settings']['chat_bubble_position'] : 'bottom-right',
                        'page_list' => isset($settings['chat_settings']['template4']['additional_settings']['page_list']) ? $settings['chat_settings']['template4']['additional_settings']['page_list'] : array('-1'),
                        'display_greeting' => isset($settings['chat_settings']['template4']['additional_settings']['display_greeting']) ? $settings['chat_settings']['template4']['additional_settings']['display_greeting'] : 'false',

                        //schedule time for chat to show
                        'day_time_schedule' => isset($settings['chat_settings']['template4']['additional_settings']['day_time_schedule']) ? $settings['chat_settings']['template4']['additional_settings']['day_time_schedule'] : 'false',
                        'day_list' => array(
                            __('Saturday', 'wpsocialreviews'),
                            __('Sunday', 'wpsocialreviews'),
                            __('Monday', 'wpsocialreviews'),
                            __('Tuesday', 'wpsocialreviews'),
                            __('Wednesday', 'wpsocialreviews'),
                            __('Thursday', 'wpsocialreviews'),
                            __('Friday', 'wpsocialreviews')
                        ),
                        'time_schedule' => isset($settings['chat_settings']['template4']['additional_settings']['time_schedule']) ? $settings['chat_settings']['template4']['additional_settings']['time_schedule'] : 'false',
                        'start_time' => isset($settings['chat_settings']['template4']['additional_settings']['start_time']) ? $settings['chat_settings']['template4']['additional_settings']['start_time'] : "03:07:26 PM",
                        'end_time' => isset($settings['chat_settings']['template4']['additional_settings']['end_time']) ? $settings['chat_settings']['template4']['additional_settings']['end_time'] : "03:07:26 PM",
                        'caption_when_offline' => isset($settings['chat_settings']['template4']['additional_settings']['caption_when_offline']) ? $settings['chat_settings']['template4']['additional_settings']['caption_when_offline'] : __('I will be back soon', 'wpsocialreviews')
                    ),
                    'styles' => array(
                        'button_color' => isset($settings['chat_settings']['template4']['styles']['button_color']) ? $settings['chat_settings']['template4']['styles']['button_color'] : '',
                        'header_color' => isset($settings['chat_settings']['template4']['styles']['header_color']) ? $settings['chat_settings']['template4']['styles']['header_color'] : '',
                        'header_title_color' => isset($settings['chat_settings']['template4']['styles']['header_title_color']) ? $settings['chat_settings']['template4']['styles']['header_title_color'] : '',
                        'header_caption_color' => isset($settings['chat_settings']['template4']['styles']['header_caption_color']) ? $settings['chat_settings']['template4']['styles']['header_caption_color'] : ''
                    )
                ),

            )

        );
        return $data;
    }

    /**
     *
     * Update Credential
     *
     * @return json response
     * @since 1.0.0
     */
    public function updateChatCredential()
    {
        $args = json_decode(wp_unslash($_REQUEST['chat_config']));
        $args = json_decode(json_encode($args), true);

        //check if page lists exists or not , if not then make it 1;
        if (isset($args[$args['template']]['additional_settings']['page_list']) && count($args[$args['template']]['additional_settings']['page_list']) === 0) {
            $args[$args['template']]['additional_settings']['page_list'] = array('-1');
        }

        $messengerConfig = $args;
        $messengerConfig = array(
            'chat_settings' => $messengerConfig
        );
        update_option('wpsr_messenger_settings', $messengerConfig, 'no');
        $getMessengerConfig = get_option('wpsr_messenger_settings', false);
        if (!$getMessengerConfig) {
            $getMessengerConfig = get_option('messenger_settings', true);
        }
        Helper::sendSuccess([
            'message' => __('Successfully Updated', 'wpsocialreviews'),
            'connection_details' => $getMessengerConfig
        ]);
    }

    /**
     *
     * Delete Credential
     *
     * @return json response
     * @since 1.0.0
     */
    public function deleteChatCredential()
    {
        $chatSettings = get_option('wpsr_messenger_settings', true);
        if (!$chatSettings) {
            $chatSettings = get_option('messenger_settings', true);
        }
        $formattedChatSettings = self::getFormattedMessengerConfig($chatSettings, true);
        update_option('wpsr_messenger_settings', $formattedChatSettings, 'no');
        Helper::sendSuccess([
            'message' => __('Successfully Disconnected!', 'wpsocialreviews'),
            'chatSettings' => $formattedChatSettings
        ]);
    }

}
