<?php

namespace WPSocialReviews\Classes\Feeds;

if (!defined('ABSPATH')) {
    exit;
}

abstract class BaseFeed
{

    public $platform;

    public function __construct($platform)
    {
        $this->platform = $platform;
    }

    public function registerHooks()
    {
        //add_action('wpsocialreviews/save_feed_settings_' . $this->platform, array($this, 'saveFeedSettings'));
        add_action('wpsocialreviews/get_feed_settings_' . $this->platform, array($this, 'getFeedSettings'));

        //login
        add_action('wpsocialreviews/verification_login_' . $this->platform, array($this, 'platformVarificationLoginNow'));
        add_action('wpsocialreviews/get_verification_configs_' . $this->platform, array($this, 'getVerificationConfigs'));
        add_action('wpsocialreviews/disconnect_verification_configs_' . $this->platform, array($this, 'disconnectVerificationConfigs'));

        //editor
        add_action('wpsocialreviews/update_feed_editor_settings_' . $this->platform, array($this, 'updateFeedEditorSettings'));
        add_action('wpsocialreviews/save_updated_feed_editor_settings_' . $this->platform, array($this, 'saveUpdatedFeedEditorSettings'));

        //clear cache
        add_action('wpsocialreviews/clear_cache_' . $this->platform, array($this, 'clearCache'));

        //clear cache on interval
        add_action('interval_cron_job', array($this, 'clear_interval_cache'));

        //for running the cron job
        add_action('wpsr_daily_feed_event_' . $this->platform, array($this, 'wpsrDoThisCronEvent'));

        register_deactivation_hook(__FILE__, array($this, 'twitter_deactivate'));

        add_action('wpsocialreviews/save_global_settings_' . $this->platform, array($this, 'saveGlobalSettings'));
        add_action('wpsocialreviews/get_global_settings_' . $this->platform, array($this, 'getGlobalSettings'));

        add_action('wpsocialreviews/set_youtube_account_data' . $this->platform, array($this, 'setYoutubeAccountData'));
        add_action('wpsocialreviews/set_account_data_' . $this->platform, array($this, 'setAccountData'));

    }

    /**
     * Clear Cache
     * @return string
     * @throws /exception
     * @since 1.1.0
     */
    public function clearCache()
    {
        wpSocialReviewsDB()->table('options')->where('option_name', 'LIKE', '_transient_wpsr_' . $this->platform . '_tc_%')->delete();
        wpSocialReviewsDB()->table('options')->where('option_name', 'LIKE', '_transient_timeout_wpsr_' . $this->platform . '_tc_%')->delete();
        wp_send_json_success([
            'message' => __('Cache Cleared!', 'wpsocialreviews'),
        ], 200);
    }

    public function clear_interval_cache()
    {
        wpSocialReviewsDB()->table('options')->where('option_name', 'LIKE', '_transient_wpsr_' . $this->platform . '_tc_%')->delete();
        wpSocialReviewsDB()->table('options')->where('option_name', 'LIKE', '_transient_timeout_wpsr_' . $this->platform . '_tc_%')->delete();
    }

    //cron job function
    public function wpsrDoThisCronEvent()
    {
        wpSocialReviewsDB()->table('options')->where('option_name', 'LIKE', '_transient_wpsr_' . $this->platform . '_tc_%')->delete();
        wpSocialReviewsDB()->table('options')->where('option_name', 'LIKE', '_transient_timeout_wpsr_' . $this->platform . '_tc_%')->delete();
    }

}
