<?php

namespace WPSocialReviews\Classes\Feeds;

if (!defined('ABSPATH')) {
    exit;
}

class CacheHandler
{

    public $platform;

    public function __construct($platform)
    {
        $this->platform = $platform;
    }

    /**
     * Create cache
     *
     * cache the data for future usage
     *
     * @param string $transientName transient name
     * @param array $data data
     * @throws /Exception
     * @since 1.2.5
     */
    public function createFeedCache($transientName, $data)
    {
        // Is there old Cache? If so Delete it!
        if (true === $this->checkFeedCacheExists($transientName)) {
            // Make Sure to delete old permanent cache before setting up new cache!
            $this->deletePermanentFeedCache($transientName);
        }
        // Cache Time set
        $settings = get_option('wpsr_' . $this->platform . '_global_settings', false);
        $cacheTimeLimit = isset($settings['global_settings']['feed_cache_time']) ? intval($settings['global_settings']['feed_cache_time']) : 86400;
        // Timed Cache.
        set_transient('wpsr_' . $this->platform . '_tc_' . $transientName, $data, $cacheTimeLimit);
        // Permanent Feed cache. NOTE set to 0.
        set_transient('wpsr_' . $this->platform . '_pc_' . $transientName, $data, 0);
    }

    /**
     * Delete cache
     *
     * @param string $transientName transient name
     * @throws /Exception
     * @since 1.2.5
     */
    public function deletePermanentFeedCache($transientName)
    {
        // Clear ONLY Specfic Feeds Cache!
        wpSocialReviewsDB()->table('options')->where('option_name', 'LIKE', '_transient_wpsr_' . $this->platform . '_pc_' . $transientName)->delete();
    }

    /**
     * Check cache is exists
     *
     * @param string $transientName transient name
     * @param boolean $errored error.
     * @return boolean
     * @since 1.2.5
     */
    public function checkFeedCacheExists($transientName, $errored = null)
    {
        $transient_permanent_check = get_transient('wpsr_' . $this->platform . '_pc_' . $transientName);
        $transient_time_check = get_transient('wpsr_' . $this->platform . '_tc_' . $transientName);
        // If error exists is set and old cache still exists.
        if (true === $errored && false !== $transient_permanent_check) {
            return true;
        }
        if (true !== $errored && false !== $transient_permanent_check && false !== $transient_time_check) {
            return true;
        }
        return false;
    }

    /**
     * Get feed from cache
     *
     * @param string $transientName transient name
     * @param boolean $errored error.
     * @return array
     * @since 1.2.5
     */
    public function getFeedCache($transientName, $errored = null)
    {
        // If Error use Permanent Cache!
        if (true === $errored) {
            return get_transient('wpsr_' . $this->platform . '_pc_' . $transientName);
        }
        // If no error use Timed Cache!
        return get_transient('wpsr_' . $this->platform . '_tc_' . $transientName);
    }

}