<?php

namespace WPSocialReviews\Classes\Feeds\Common;

if (!defined('ABSPATH')) {
    exit;
}

class FeedFilters
{

    private $platform;

    /**
     * getTimestamp feed time handler
     * @param array $feed
     * @return date
     * @since 1.3.0
     *
     */
    public function getTimestamp($feed)
    {

        $date = null;

        if ($this->platform === 'youtube') {
            $date = isset($feed['snippet']['publishedAt']) ? $feed['snippet']['publishedAt'] : null;
        } elseif ($this->platform === 'twitter') {
            $date = isset($feed['created_at']) ? $feed['created_at'] : null;
        } elseif ($this->platform === 'instagram') {
            $date = isset($feed['timestamp']) ? $feed['timestamp'] : null;
        }

        if (!empty($date)) {
            $date = strtotime($date);
        }

        return $date;

    }

    /**
     * filterFeedResponse filter the feed response
     * @param array $filterSettings filter settings
     * @param array $response response
     * @return array
     * @since 1.3.0
     *
     */
    public function filterFeedResponse($platform, $filterSettings, $response)
    {
        if ($filterSettings && $response && !empty($response) && !empty($filterSettings)) {
            $this->platform = $platform;

            $filterResponse = $newArray = $header = array();

            if ($this->platform === 'instagram') {
                $header = isset($response['header']) ? $response['header'] : array();
                $newArray = isset($response['items']) ? $response['items'] : array();
            }

            if ($this->platform === 'youtube') {
                $header = isset($response['channel_info']) ? $response['channel_info'] : array();
                $newArray = isset($response['items']) ? $response['items'] : array();
            }

            if ($this->platform === 'twitter') {
                $header = isset($response['header']) ? $response['header'] : array();
                $newArray = isset($response['feed']) ? $response['feed'] : array();
            }

            //filter by date
            if (($filterSettings['post_order'] === 'ascending' || $filterSettings['post_order'] === 'descending')) {
                $multiply = ($filterSettings['post_order'] === 'ascending') ? -1 : 1;

                usort($newArray, function ($m1, $m2) use ($multiply) {
                    $timestamp1 = $this->getTimestamp($m1);
                    $timestamp2 = $this->getTimestamp($m2);

                    // If both have dates
                    if ($timestamp1 !== null && $timestamp2 !== null) {
                        return ($timestamp1 <=> $timestamp2) * $multiply;
                    }

                    // If m2 has no date, consider it as more recent
                    if ($timestamp1 !== null) {
                        return $multiply;
                    }

                    // If m1 has no date, consider it as more recent
                    if ($timestamp2 !== null) {
                        return -$multiply;
                    }

                    // Neither have dates
                    return 0;
                });
            }

            if ($this->platform === 'instagram') {
                //filter by popularity
                if (($filterSettings['post_order'] === 'most_popular' || $filterSettings['post_order'] === 'least_popular')) {
                    $newArray = apply_filters('wpsocialreviews/instagram_feeds_by_popularity', $newArray,
                        $filterSettings['post_order']);
                }
            }

            if ($this->platform === 'youtube') {
                //filter by popularity
                if (($filterSettings['post_order'] === 'most_popular' || $filterSettings['post_order'] === 'least_popular')) {
                    $newArray = apply_filters('wpsocialreviews/youtube_feeds_by_popularity', $newArray, $filterSettings['post_order']);
                }
            }

            if ($this->platform === 'twitter') {
                //filter by popularity
                if (($filterSettings['post_order'] === 'most_popular' || $filterSettings['post_order'] === 'least_popular')) {
                    $newArray = apply_filters('wpsocialreviews/twitter_feeds_by_popularity', $newArray, $filterSettings['post_order']);
                }
            }

            //filter by randomly
            if ($filterSettings['post_order'] === 'random') {
                $newArray = apply_filters('wpsocialreviews/feeds_by_random', $newArray);
            }

            //end of 1st filter
            $totalPosts = 10;
            if (isset($filterSettings['total_posts'])) {
                $totalPosts = (int)$filterSettings['total_posts'];
            }

            //we have to get include or exclude feeds from here
            $includesWords = array();
            $excludesWords = array();

            if (!empty($filterSettings['includes_inputs'])) {
                $includesWords = array_map('trim', explode(",", $filterSettings['includes_inputs']));
            }
            if (!empty($filterSettings['excludes_inputs'])) {
                $excludesWords = array_map('trim', explode(",", $filterSettings['excludes_inputs']));
            }

            $totalPostsIterator = 0;
            $res = array();
            foreach ($newArray as $index => $feed) {

                $text_description = '';

                if ($this->platform === 'instagram') {
                    $text_description = isset($feed['caption']) ? $feed['caption'] : '';
                }

                if ($this->platform === 'youtube') {
                    $text_description = isset($feed['snippet']['description']) ? $feed['snippet']['description'] : '';
                }

                if ($this->platform === 'twitter') {
                    $text_description = isset($feed['retweeted_status']) ? $feed['retweeted_status']['full_text'] : $feed['full_text'];
                }

                $post_caption = ' ' . str_replace(array('+', '%0A'), ' ', urlencode(str_replace(array('#', '@'), array(' HASHTAG', ' MENTION'), strtolower($text_description)))) . ' ';


                //start of 1st filter: Numbers Of Posts To Display
                if ($totalPostsIterator >= ($totalPosts)) {
                    break;
                }
                //end of 1st filter: Numbers Of Posts To Display

                $hasIncludeword = false;
                $hasExcludeword = false;

                if (!empty($includesWords)) {
                    $hasIncludeword = apply_filters('wpsocialreviews/include_or_exclude_feed', true, $includesWords, $post_caption);
                }

                if (!empty($excludesWords)) {
                    $hasExcludeword = apply_filters('wpsocialreviews/include_or_exclude_feed', false, $excludesWords, $post_caption);
                }

                $word_filter_passed = false;

                if (!empty($excludesWords) && !empty($includesWords)) {
                    $word_filter_passed = $hasIncludeword && !$hasExcludeword;
                } elseif (!empty($includesWords)) {
                    $word_filter_passed = $hasIncludeword;
                } else {
                    $word_filter_passed = !$hasExcludeword;
                }

                if ($word_filter_passed) {
                    $totalPostsIterator++;

                    if ($this->platform === 'instagram') {
                        // 3rd filter: start of filters for Types Of Posts
                        if ($filterSettings['post_type'] === 'all') {
                            $filterResponse[] = $feed;
                        } elseif (isset($feed['media_type']) && $feed['media_type'] === "IMAGE" && $filterSettings['post_type'] === 'images') {
                            $filterResponse[] = $feed;
                        } elseif (isset($feed['media_type']) && $feed['media_type'] === "VIDEO" && $filterSettings['post_type'] === 'videos') {
                            $filterResponse[] = $feed;
                        }
                        //3rd filter: end of filters for Types Of Posts
                    }

                    if ($this->platform === 'youtube' || $this->platform === 'twitter') {
                        $filterResponse[] = $feed;
                    }
                }
            }

            if ($this->platform === 'instagram') {
                $data = array(
                    'header' => $header,
                    'items' => $filterResponse
                );

                return $data;
            }

            if ($this->platform === 'youtube') {
                $data = array(
                    'channel_info' => $header,
                    'items' => $filterResponse
                );

                return $data;
            }

            if ($this->platform === 'twitter') {
                $data = array(
                    'header' => $header,
                    'feed' => $filterResponse
                );

                return $data;
            }


        }

        return $response;
    }
}