<?php

namespace WPSocialReviews\Classes\Feeds\Instagram;

use WPSocialReviews\Classes\Feeds\Instagram\Common;
use WPSocialReviews\Classes\Feeds\CacheHandler;
use WPSocialReviews\Classes\Feeds\Instagram\RefreshToken;

if (!defined('ABSPATH')) {
    exit;
}

class AccountFeed
{
    protected $cacheHandler;

    public function __construct()
    {
        $this->cacheHandler = new CacheHandler('instagram');
    }

    /**
     * Get Accounts Feed
     *
     * @param array $accountIds
     *
     * @return array
     * @since 1.3.0
     */
    public function getMultipleAccountResponse($accountIds)
    {
        $response = array();
        $connectedAccounts = (new Common)->findConnectedAccounts();
        foreach ($accountIds as $index => $accountId) {
            $accountDetails = isset($connectedAccounts[$accountId]) ? $connectedAccounts[$accountId] : '';
            $resultWithComments = array();
            if ($accountDetails) {

                $feedCacheName = 'wpsr_instagram_feed_account_' . $accountId;
                $instagramApiUrl = $this->getApiUrl($accountDetails);

                if (true === $this->cacheHandler->checkFeedCacheExists($feedCacheName)) {
                    $resultWithComments = $this->cacheHandler->getFeedCache($feedCacheName);
                } else {
                    $resultWithoutComments = (new Common)->expandWithoutComments($instagramApiUrl);
                    if (!(new Common)->instagramError($resultWithoutComments)) {
                        $resultWithComments = (new Common)->expandWithComments($accountDetails, $resultWithoutComments);
                        $this->cacheHandler->createFeedCache($feedCacheName, $resultWithComments);
                    } else {
                        $resultWithComments = $this->cacheHandler->getFeedCache($feedCacheName, true);
                    }
                }

            }
            $response[$index] = $resultWithComments ? $resultWithComments : array();
        }

        $accountFeed = array();

        foreach ($response as $index => $feeds) {
            $accountFeed = array_merge($accountFeed, $feeds);
        }

        return $accountFeed;
    }

    public function getApiUrl($accountDetails)
    {
        $num = apply_filters('wpsocialreviews/instagram_feeds_limit', 10);
        $apiUrl = '';
        if ($accountDetails['api_type'] === 'business') {
            $apiUrl = 'https://graph.facebook.com/' . $accountDetails['user_id'] . '/media?fields=media_url,thumbnail_url,caption,id,media_type,timestamp,username,comments_count,like_count,permalink,children{media_url,id,media_type,timestamp,permalink,thumbnail_url}&limit=' . $num . '&access_token=' . $accountDetails['access_token'];
        } else if ($accountDetails['api_type'] === 'personal') {
            $accessToken = (new RefreshToken())->getAccessToken($accountDetails);
            $apiUrl = 'https://graph.instagram.com/' . $accountDetails['user_id'] . '/media?fields=media_url,thumbnail_url,caption,id,media_type,timestamp,username,comments_count,like_count,permalink,children{media_url,id,media_type,timestamp,permalink,thumbnail_url}&limit=' . $num . '&access_token=' . $accessToken;
        }
        return $apiUrl;
    }

}