<?php

namespace WPSocialReviews\Classes\Feeds\Instagram;

if (!defined('ABSPATH')) {
    exit;
}

class Common
{

    /**
     * Connect to the Instagram API
     *
     * @param string $url
     * @return array
     * @since 1.3.0
     */
    public function makeRequest($url)
    {
        $args = array(
            'timeout' => 60,
            'sslverify' => false
        );
        $response = wp_remote_get($url, $args);

        if (!is_wp_error($response)) {
            $response = json_decode(str_replace('%22', '&rdquo;', $response['body']), true);
        }

        return $response;
    }

    /**
     * Add Comments For Ig Feeds
     *
     * @param array $accountDetails
     * @param array $response
     * @return array
     * @since 1.3.0
     */
    public function expandWithComments($accountDetails, $response)
    {

        $mediaList = $response['data'];

        if (isset($accountDetails['api_type']) && $accountDetails['api_type'] === 'business') {

            $mediaIds = array_filter(array_column($mediaList, 'id'));

            $apiUrl = apply_filters('wpsocialreviews/build_instagram_comments_api', $mediaIds, $accountDetails['access_token']);

            if (filter_var($apiUrl, FILTER_VALIDATE_URL)) {

                $comments = $this->makeRequest($apiUrl);
                foreach ($mediaList as $idx => $media) {
                    $mediaId = $media['id'];
                    if (!isset($comments[$mediaId])) {
                        continue;
                    }
                    $mediaList[$idx]['comments'] = $comments[$mediaId]['data'];
                }

            }

        }

        return $mediaList;

    }

    /**
     * Ig Feeds
     *
     * @param string $apiUrl
     *
     * @return array
     * @since 1.3.0
     */
    public function expandWithoutComments($apiUrl)
    {
        $response = $this->makeRequest($apiUrl);
        return $response;
    }

    /**
     * Formatted Verified Accounts
     *
     * @return array
     * @since 1.3.0
     */
    public function findConnectedAccounts()
    {
        $connected_ids = get_option('wpsr_instagram_configs', array());
        $connected_ids = isset($connected_ids['connected_accounts']) ? $connected_ids['connected_accounts'] : array();
        $connected_ids = json_decode(json_encode($connected_ids), true);
        return $connected_ids;
    }

    /**
     * Weather Response Has Error or Not
     *
     * @param array $response
     * @return boolean
     * @since 1.3.0
     */
    public function instagramError($response)
    {
        return (isset($response->errors) || isset($response['meta']['error_type']) || isset($response['error']['message']) || isset($response['error']) || isset($response['errors']));
    }

}