<?php

namespace WPSocialReviews\Classes\Feeds\Instagram;

use WPSocialReviews\Classes\Feeds\BaseFeed;
use WPSocialReviews\Classes\Feeds\CacheHandler;
use WPSocialReviews\Classes\Feeds\Common\FeedFilters;
use WPSocialReviews\Classes\Feeds\Instagram\Common;

use WPSocialReviews\Classes\Feeds\Instagram\AccountFeed;

if (!defined('ABSPATH')) {
    exit;
}

class InstagramFeed extends BaseFeed
{
    public static $totalFeed = 50;
    public $platform = 'instagram';
    protected $cacheHandler;

    public function __construct()
    {

        parent::__construct($this->platform);
        $this->cacheHandler = new CacheHandler('instagram');

    }

    /**
     * Instagram Api Error Message
     *
     * @param array $response
     * @return string
     * @since 1.3.0
     */
    public function getErrorMessage($response)
    {
        $message = __('Error connecting to instagram', 'wpsocialreviews');
        if (isset($response['error'])) {
            $message = sprintf(__('API error %s:', 'wpsocialreviews'), $response['error']['code']) . ' ' . $response['error']['message'];
        } else {
            if (isset($response['response']) && isset($response['response']->errors)) {
                foreach ($response['response']->errors as $key => $item) {
                    $message .= ' ' . $key . ' - ' . $item[0];
                }
            }
        }
        return $message;
    }

    public function setCronEvent()
    {

        $existsEvent = get_option('wpsr_' . $this->platform . '_global_settings', false);

        //if not exists cron event already then assign an event
        if (!$existsEvent) {
            // add global instagram settings when user verified
            $args = array(
                'global_settings' => array(
                    'feed_cache_time' => '1209600',
                    'feed_cache_clear' => 'clear_cache_button',
                    'auto_syncing' => 'true',
                    'cache_recurrence' => '2weeks',
                    'platform' => $this->platform
                )
            );
            update_option('wpsr_' . $this->platform . '_global_settings', $args);
            $this->doCronEvent();
        }

    }

    /**
     * Manual access token handler
     *
     * @return json
     * @since 1.3.0
     */
    public function setAccountData()
    {
        try {

            $args = json_decode(wp_unslash($_REQUEST['args']));
            $args = json_decode(json_encode($args), true);

            $args['api_type'] = 'personal';

            $isConnected = false;

            $instagramUrl = $this->instagramApiUrlSetup($args, 'verification_header');
            $response = (new Common)->makeRequest($instagramUrl);

            if (!is_wp_error($response) && !(new Common)->instagramError($response) && isset($response['username']) && isset($response['id'])) {
                $args['username'] = $response['username'];
                $args['user_id'] = $response['id'];
                $args['user_avatar'] = '';

                $isConnected = true;

                $settings = $this->updateAndGetVerificationConfigs($args);

                $this->setCronEvent();

                wp_send_json_success([
                    'settings' => $settings,
                    'message' => __('You\'ve successfully connected your account!', 'wpsocialreviews')
                ]);
            }

            $args['api_type'] = 'business';
            $instagramUrl = $this->instagramApiUrlSetup($args, 'verification');

            $response = (new Common)->makeRequest($instagramUrl);

            if (!is_wp_error($response) && isset($response['data']) && !(new Common)->instagramError($response)) {

                foreach ($response['data'] as $responseData) {
                    if (isset($responseData['id'])) {
                        $pageId = $responseData['id'];
                        $access_token = $args['access_token'];

                        $instagramBusinessToken = "https://graph.facebook.com/" . $pageId . '?fields=instagram_business_account&access_token=' . $access_token;
                        $response = (new Common)->makeRequest($instagramBusinessToken);

                        if (!is_wp_error($response) && isset($response['instagram_business_account']['id']) && !(new Common)->instagramError($response)) {
                            $isConnected = true;
                            $args['user_id'] = $response['instagram_business_account']['id'];
                            $instagramUrl = $this->instagramApiUrlSetup($args, 'header');
                            $response = (new Common)->makeRequest($instagramUrl);
                            $args['username'] = $response['username'];
                            $args['user_avatar'] = $response['profile_picture_url'];
                        }
                    }
                }
            }

            if (is_wp_error($response)) {
                throw new \Exception($response->get_error_message());
            }

            if (!is_wp_error($response) && !(new Common)->instagramError($response)) {

                if (!$isConnected) {
                    wp_send_json_error([
                        'message' => __('Configure your business account correctly!', 'wpsocialreviews')
                    ], 423);
                }

                $args['username'] = isset($response['username']) ? $response['username'] : '';
                $settings = $this->updateAndGetVerificationConfigs($args);

                $this->setCronEvent();

                //create cache for header details
                // $headerDetails = $this->formatHeaderDetails($response);
                // $accountToShow = 'hilljk';
                // $accountCacheName      = 'wpsr_instagram_account_header_'.$accountToShow;
                // $this->cacheHandler->createFeedCache( $accountCacheName, $headerDetails );

                wp_send_json_success([
                    'settings' => $settings,
                    'message' => __('You\'ve successfully connected your account!', 'wpsocialreviews')
                ]);
            }

            $message = $this->getErrorMessage($response);

            wp_send_json_error([
                'message' => $message
            ], 423);
            //throw new \WP_Error(423, $message);

        } catch (\Exception $exception) {
            wp_send_json_error([
                'message' => $exception->getMessage()
            ], 423);
        }

    }

    /**
     * Set instagram api url
     *
     * @return string
     * @since 1.3.0
     */
    public function instagramApiUrlSetup($args, $endpoint)
    {
        $num = 100;
        $accountType = $args['api_type'];
        $num = min($num, 200);
        $access_token = $args['access_token'];

        $apiUrl = '';
        if ($accountType === 'personal') {
            if ($endpoint === 'verification_header') {
                //header
                $apiUrl = 'https://graph.instagram.com/me?fields=id,username,media_count&access_token=' . $access_token;
            } else if ($endpoint === 'header') {
                //header
                $access_token = (new RefreshToken())->getAccessToken($args);
                $apiUrl = 'https://graph.instagram.com/me?fields=id,username,media_count&access_token=' . $access_token;
            }
        } else if ($accountType === 'business') {

            if ($endpoint === 'verification') {
                //verification
                $apiUrl = "https://graph.facebook.com/v8.0/me/accounts?fields=name,id&access_token=" . $access_token;
            } else if ($endpoint === 'header') {
                //header
                $apiUrl = 'https://graph.facebook.com/' . $args['user_id'] . '?fields=biography,id,username,website,followers_count,media_count,profile_picture_url,name&access_token=' . $access_token;
            }

        }
        return $apiUrl;
    }

    /**
     * Get All Verified Accounts
     * @return json
     * @since 1.3.0
     */
    public function getVerificationConfigs()
    {
        $connected_accounts = (new Common)->findConnectedAccounts();
        wp_send_json_success([
            'message' => __('Instagram Successfully Connected!', 'wpsocialreviews'),
            'connected_accounts' => $connected_accounts
        ], 200);
    }

    /**
     * Disconnect Verification Configs
     * @return json
     * @since 1.3.0
     */
    public function disconnectVerificationConfigs()
    {
        $user_id = sanitize_text_field($_REQUEST['user_id']);
        $accounts = (new Common)->findConnectedAccounts();

        unset($accounts[$user_id]);

        update_option('wpsr_instagram_configs', array('connected_accounts' => $accounts));

        //delete existing data of this user
        wpSocialReviewsDB()->table('options')->where('option_name', 'LIKE', '_transient_wpsr_' . $this->platform . '_tc_wpsr_' . $this->platform . '_feed_account_' . $user_id)->delete();
        wpSocialReviewsDB()->table('options')->where('option_name', 'LIKE', '_transient_timeout_wpsr_' . $this->platform . '_tc_wpsr_' . $this->platform . '_feed_account_' . $user_id)->delete();

        if (!count($accounts)) {
            delete_option('wpsr_instagram_configs');
        }

        wp_send_json_success([
            'message' => __('Your Instagram Account Successfully Disconnected!', 'wpsocialreviews'),
        ], 200);
    }

    /**
     * Get Feed Settings
     *
     * @return json
     * @since 1.3.0
     */
    public function getFeedSettings()
    {
        $postId = intval($_REQUEST['post_id']);
        $feed_template_meta = get_post_meta($postId, '_wpsr_instagram_template_config', true);
        $configs = isset($feed_template_meta['feed_settings']) ? $feed_template_meta['feed_settings'] : array();

        $formatted_feed_template_meta = self::formatInstagramConfig($configs, array());

        //feed settings to simplify repetitive use
        $feed_settings = isset($formatted_feed_template_meta['feed_settings']) ? $formatted_feed_template_meta['feed_settings'] : array();

        //get dynamic response

        $response = $this->templateApiHandler($feed_settings);

        //filter the feeds
        $filterSettings = isset($feed_settings['filters']) ? $feed_settings['filters'] : array();

        if (isset($response['error_message'])) {
            $filterResponse = $response;
        } else {
            $filterResponse = (new FeedFilters)->filterFeedResponse($this->platform, $filterSettings, $response);
        }

        $formatted_feed_template_meta['dynamic'] = $filterResponse;
        $configs = $formatted_feed_template_meta;

        $templateDetails = get_post($postId);

        //get all connected ids
        $connected_ids = (new Common)->findConnectedAccounts();
        $configs['connected_ids'] = $connected_ids;

        wp_send_json_success([
            'message' => __('Success', 'wpsocialreviews'),
            'settings' => $configs,
            'template_details' => $templateDetails,
        ]);
    }

    /**
     * Template Api Handler
     *
     * @param array $apiSettings
     *
     * @return array
     * @since 1.3.0
     */
    public function templateApiHandler($feed_settings)
    {

        $apiSettings = isset($feed_settings['source_settings']) ? $feed_settings['source_settings'] : array();
        $headerSettings = isset($feed_settings['header_settings']) ? $feed_settings['header_settings'] : array();

        $accountIds = isset($apiSettings['account_ids']) ? $apiSettings['account_ids'] : array();
        $connectedAccounts = (new Common)->findConnectedAccounts();
        $actualConnectedIds = array_keys($connectedAccounts);
        $existsAccounts = array_intersect($actualConnectedIds, $accountIds);

        if (empty($existsAccounts)) {
            return array('error_message' => 'Configure source settings from the template editor panel');
        }

        $accountToShow = isset($headerSettings['account_to_show']) ? $headerSettings['account_to_show'] : '';
        $accountCacheName = 'wpsr_instagram_account_header_' . $accountToShow;

        $accountDetails = isset($connectedAccounts[$accountToShow]) ? $connectedAccounts[$accountToShow] : array();
        $instagramApiUrl = $this->instagramApiUrlSetup($accountDetails, 'header');

        $headerDetails = array();
        if (true === $this->cacheHandler->checkFeedCacheExists($accountCacheName)) {
            $headerDetails = $this->cacheHandler->getFeedCache($accountCacheName);
        } else {
            $headerDetails = (new Common)->makeRequest($instagramApiUrl);

            if (!(new Common)->instagramError($headerDetails)) {
                $headerDetails = $this->formatHeaderDetails($headerDetails);
                $this->cacheHandler->createFeedCache($accountCacheName, $headerDetails);
            } else {
                $headerDetails = $this->cacheHandler->getFeedCache($accountCacheName, true);
            }
        }

        if (isset($apiSettings['account_ids'])) {
            $feedType = $apiSettings['feed_type'];
            $response = array();
            if ($feedType === 'user_account') {
                $accountIds = $apiSettings['account_ids'];
                $response = (new AccountFeed)->getMultipleAccountResponse($accountIds);
            }

            if ($feedType === 'tagged_feed') {
                $accountIds = $apiSettings['account_ids'];
                if (defined('WPSOCIALREVIEWS_PRO')) {
                    $response = (new \WPSocialReviewsPro\Classes\Feeds\Instagram\TaggedFeed)->getMultipleTaggedResponse($accountIds);
                } else {
                    $message = __('You need to upgrade to pro version to show tagged feeds!!', 'wpsocialreviews');
                    return array('error_message' => $message);
                }
            }

            if ($feedType === 'hashtag_feed') {
                $accountIds = $apiSettings['account_ids'];
                $hashtagType = isset($apiSettings['hashtag_type']) ? $apiSettings['hashtag_type'] : 'recent_media ';
                $hashtags = isset($apiSettings['hash_tags']) ? $apiSettings['hash_tags'] : '';

                if ($hashtags && !empty($hashtags)) {
                    if (defined('WPSOCIALREVIEWS_PRO')) {
                        $response = (new \WPSocialReviewsPro\Classes\Feeds\Instagram\HashtagFeed)->getMultipleHashtagResponse($accountIds, $hashtags, $hashtagType);
                    } else {
                        $message = __('You need to upgrade to pro version to show hashtag feeds!!', 'wpsocialreviews');
                        return array('error_message' => $message);
                    }
                } else {
                    $message = __('Please enter hashtags to connect', 'wpsocialreviews');
                    return array('error_message' => $message);
                }
            }

            $data = array(
                'header' => $headerDetails,
                'items' => $response
            );

            return $data;
        }

        return array();
    }

    public function formatHeaderDetails($args)
    {

        $data = array(
            'username' => isset($args['username']) ? $args['username'] : '',
            'biography' => isset($args['biography']) ? $args['biography'] : '',
            'user_avatar' => isset($args['profile_picture_url']) ? $args['profile_picture_url'] : '',
            'followers_count' => isset($args['followers_count']) ? $args['followers_count'] : '',
            'media_count' => isset($args['media_count']) ? $args['media_count'] : '',
            'name' => isset($args['name']) ? $args['name'] : ''
        );
        return $data;

    }

    /**
     * Show updated data if new data fetched in editor without update in db
     *
     * @return json
     * @throws /Exception
     * @since 1.3.0
     */
    public function updateFeedEditorSettings()
    {
        $postId = intval($_REQUEST['post_id']);
        $configs = json_decode(wp_unslash($_REQUEST['args']));
        $configs = json_decode(json_encode($configs), true);
        $formatted_feed_template_meta = self::formatInstagramConfig($configs['feed_settings'], array());

        //feed settings to simplify repetitive use
        $feed_settings = isset($formatted_feed_template_meta['feed_settings']) ? $formatted_feed_template_meta['feed_settings'] : array();

        //get dynamic response

        $response = $this->templateApiHandler($feed_settings);

        //filter the feeds
        $filterSettings = isset($feed_settings['filters']) ? $feed_settings['filters'] : array();
        if (isset($response['error_message'])) {
            $filterResponse = $response;
        } else {
            $filterResponse = (new FeedFilters)->filterFeedResponse($this->platform, $filterSettings, $response);
        }

        $formatted_feed_template_meta['dynamic'] = $filterResponse;
        $configs = $formatted_feed_template_meta;

        //get all connected ids
        $connected_ids = (new Common)->findConnectedAccounts();
        $configs['connected_ids'] = $connected_ids;

        wp_send_json_success([
            'message' => __('Instagram Settings Updated successfully', 'wpsocialreviews'),
            'settings' => $configs
        ]);
    }

    /**
     * Update template is settings is changed in editor
     *
     * @return json
     * @since 1.3.0
     */
    public function saveUpdatedFeedEditorSettings()
    {
        $postId = intval($_REQUEST['post_id']);
        $args = json_decode(wp_unslash($_REQUEST['args']));
        $args = json_decode(json_encode($args), true);
        update_post_meta($postId, '_wpsr_instagram_template_config', $args);
        wp_send_json_success([
            'message' => __('Template Saved Successfully!!', 'wpsocialreviews'),
        ]);
    }

    public function getUserAccounts($settings)
    {
        $connected_accounts = isset($settings['source_settings']['account_ids']) ? $settings['source_settings']['account_ids'] : array();

        $connected_account1 = (count($connected_accounts) && isset($connected_accounts[0])) ? $connected_accounts[0] : '';
        $connected_account2 = isset($settings['header_settings']['account_to_show']) ? $settings['header_settings']['account_to_show'] : $connected_account1;

        $connected_account = $connected_account2;

        if (empty($connected_account)) {
            $connected_account = $connected_account1;
        }

        $allAccounts = (new Common)->findConnectedAccounts();

        $connectedAccountId = isset($allAccounts[$connected_account]) ? $connected_account : '';

        $actualConnectedIds = array_keys($allAccounts);
        $actualConnectedIds = array_map('strval', $actualConnectedIds);

        $accountIds = isset($settings['source_settings']['account_ids']) ? $settings['source_settings']['account_ids'] : array();

        $existsAccounts = array_intersect($actualConnectedIds, $accountIds);

        $connectedAccountIds = array();
        foreach ($existsAccounts as $account) {
            $connectedAccountIds[] = $account;
        }

        $data = array(
            'connected_account_id' => $connectedAccountId,
            'account_ids' => $connectedAccountIds
        );

        return $data;
    }

    /**
     * Formatted All Instagram Configs
     * @param array $settings
     * @param array $response
     * @return array
     * @since 1.3.0
     */
    public function formatInstagramConfig($settings, $response)
    {

        // $connected_accounts  = isset( $settings['source_settings']['account_ids'] ) ? $settings['source_settings']['account_ids'] : array();

        // $connected_account1  = ( count( $connected_accounts ) && isset($connected_accounts[0]) ) ? $connected_accounts[0] : '';
        // $connected_account2  = isset($settings['header_settings']['account_to_show']) ? $settings['header_settings']['account_to_show'] : $connected_account1;

        // $connected_account = $connected_account2;

        // if( empty( $connected_account ) ) {
        //     $connected_account   = $connected_account1;
        // }

        // $accountIds = isset( $settings['source_settings']['account_ids'] ) ? $settings['source_settings']['account_ids'] : array();

        // $allAccounts =(new Common)->findConnectedAccounts();

        // $connected_account = isset( $allAccounts[$connected_account] ) ?  $connected_account : '';

        // $actualConnectedIds = array_keys( $allAccounts );
        // $actualConnectedIds = array_map('strval',$actualConnectedIds);

        // $existsAccounts = array_intersect($actualConnectedIds, $accountIds);

        // $newAccounts = array();
        // foreach( $existsAccounts as $account ) {
        //     $newAccounts[] = $account;
        // }

        $accounts = $this->getUserAccounts($settings);

        $displayMode = isset($settings['post_settings']['display_mode']) ? $settings['post_settings']['display_mode'] : 'instagram';

        if (!defined('WPSOCIALREVIEWS_PRO')) {
            $displayMode = (isset($settings['post_settings']['display_mode']) && $settings['post_settings']['display_mode'] === 'none') ? 'none' : 'instagram';
        }

        return array(
            'feed_settings' => array(
                'platform' => 'instagram',
                'template' => isset($settings['template']) ? $settings['template'] : 'template1',
                'layout_type' => isset($settings['layout_type']) ? $settings['layout_type'] : 'grid',
                'column_number' => isset($settings['column_number']) ? $settings['column_number'] : '4',
                'column_gaps' => isset($settings['column_gaps']) ? $settings['column_gaps'] : 'default',

                'source_settings' => array(
                    'feed_type' => isset($settings['source_settings']['feed_type']) ? $settings['source_settings']['feed_type'] : 'user_account',
                    'account_ids' => $accounts['account_ids'],//$newAccounts,
                    'hash_tags' => isset($settings['source_settings']['hash_tags']) ? $settings['source_settings']['hash_tags'] : '',
                    'hashtag_type' => isset($settings['source_settings']['hashtag_type']) ? $settings['source_settings']['hashtag_type'] : 'top_media',
                ),

                'carousel_settings' => array(
                    'autoplay' => isset($settings['carousel_settings']['autoplay']) ? $settings['carousel_settings']['autoplay'] : 'true',
                    'autoplay_speed' => isset($settings['carousel_settings']['autoplay_speed']) ? intval($settings['carousel_settings']['autoplay_speed']) : 3000,
                    'slides_to_show' => isset($settings['carousel_settings']['slides_to_show']) ? intval($settings['carousel_settings']['slides_to_show']) : 3,
                    'slides_to_scroll' => isset($settings['carousel_settings']['slides_to_scroll']) ? intval($settings['carousel_settings']['slides_to_scroll']) : 3,
                    'navigation' => isset($settings['carousel_settings']['navigation']) ? $settings['carousel_settings']['navigation'] : 'dot'
                ),

                'header_settings' => array(
                    'display_header' => isset($settings['header_settings']['display_header']) ? $settings['header_settings']['display_header'] : 'true',
                    'account_to_show' => $accounts['connected_account_id'],
                    'display_name' => isset($settings['header_settings']['display_name']) ? $settings['header_settings']['display_name'] : 'true',
                    'display_username' => isset($settings['header_settings']['display_username']) ? $settings['header_settings']['display_username'] : 'true',
                    'display_avatar' => isset($settings['header_settings']['display_avatar']) ? $settings['header_settings']['display_avatar'] : 'true',
                    'display_description' => isset($settings['header_settings']['display_description']) ? $settings['header_settings']['display_description'] : 'true',
                    'display_posts_counter' => isset($settings['header_settings']['display_posts_counter']) ? $settings['header_settings']['display_posts_counter'] : 'true',
                    'display_followers_counter' => isset($settings['header_settings']['display_followers_counter']) ? $settings['header_settings']['display_followers_counter'] : 'true',
                    'custom_profile_bio_text' => isset($settings['header_settings']['custom_profile_bio_text']) ? $settings['header_settings']['custom_profile_bio_text'] : '',
                    'custom_profile_photo' => isset($settings['header_settings']['custom_profile_photo']) ? $settings['header_settings']['custom_profile_photo'] : '',
                ),

                'post_settings' => array(
                    'display_mode' => $displayMode,
                    'display_likes_counter' => isset($settings['post_settings']['display_likes_counter']) ? $settings['post_settings']['display_likes_counter'] : 'true',
                    'display_comments_counter' => isset($settings['post_settings']['display_comments_counter']) ? $settings['post_settings']['display_comments_counter'] : 'true',
                    'display_caption' => isset($settings['post_settings']['display_caption']) ? $settings['post_settings']['display_caption'] : 'true',
                    'trim_caption_words' => isset($settings['post_settings']['trim_caption_words']) ? intval($settings['post_settings']['trim_caption_words']) : 0,
                ),

                'popup_settings' => array(
                    'display_sidebar' => isset($settings['popup_settings']['display_sidebar']) ? $settings['popup_settings']['display_sidebar'] : 'true',
                    'display_profile_photo' => isset($settings['popup_settings']['display_profile_photo']) ? $settings['popup_settings']['display_profile_photo'] : 'true',
                    'display_username' => isset($settings['popup_settings']['display_username']) ? $settings['popup_settings']['display_username'] : 'true',
                    'display_caption' => isset($settings['popup_settings']['display_caption']) ? $settings['popup_settings']['display_caption'] : 'true',
                    'display_date' => isset($settings['popup_settings']['display_date']) ? $settings['popup_settings']['display_date'] : 'true',
                    'display_comments' => isset($settings['popup_settings']['display_comments']) ? $settings['popup_settings']['display_comments'] : 'true',
                    'display_cta_btn' => isset($settings['popup_settings']['display_cta_btn']) ? $settings['popup_settings']['display_cta_btn'] : 'true',
                ),

                'follow_button_settings' => array(
                    'display_follow_button' => isset($settings['follow_button_settings']['display_follow_button']) ? $settings['follow_button_settings']['display_follow_button'] : 'true',
                    'follow_button_text' => isset($settings['follow_button_settings']['follow_button_text']) ? $settings['follow_button_settings']['follow_button_text'] : __('Follow on Instagram', 'wpsocialreviews'),
                    'follow_button_position' => isset($settings['follow_button_settings']['follow_button_position']) ? $settings['follow_button_settings']['follow_button_position'] : 'header',
                ),

                'filters' => array(
                    'total_posts' => isset($settings['filters']['total_posts']) ? intval($settings['filters']['total_posts']) : 50,
                    'post_order' => isset($settings['filters']['post_order']) ? $settings['filters']['post_order'] : 'ascending',
                    'post_type' => isset($settings['filters']['post_type']) ? $settings['filters']['post_type'] : 'all',
                    'includes_inputs' => isset($settings['filters']['includes_inputs']) ? $settings['filters']['includes_inputs'] : '',
                    'excludes_inputs' => isset($settings['filters']['excludes_inputs']) ? $settings['filters']['excludes_inputs'] : '',
                ),

                'pagination_settings' => array(
                    'pagination_type' => isset($settings['pagination_settings']['pagination_type']) ? $settings['pagination_settings']['pagination_type'] : 'none',
                    'paginate' => (isset($settings['pagination_settings']['paginate']) && !empty($settings['pagination_settings']['paginate'])) ? $settings['pagination_settings']['paginate'] : 6,
                ),
            ),
            'dynamic' => $response
        );

    }

    /**
     * Update and Get Verification Configs
     * @param array $args
     * @return array
     * @since 1.3.0
     */
    public function updateAndGetVerificationConfigs($args)
    {
        $options = get_option('wpsr_instagram_configs', array());
        $connected_accounts = isset($options['connected_accounts']) ? $options['connected_accounts'] : array();

        if (isset($args['user_id']) && isset($args['username'])) {

            $userId = (string)$args['user_id'];
            $connected_accounts[$userId] = array(
                'access_token' => isset($args['access_token']) ? $args['access_token'] : '',
                'expires_in' => isset($args['expires_in']) ? $args['expires_in'] : '',
                'created_at' => time(),
                'user_id' => $userId,
                'username' => isset($args['username']) ? $args['username'] : '',
                'api_type' => isset($args['api_type']) ? $args['api_type'] : '',
                'user_avatar' => isset($args['user_avatar']) ? $args['user_avatar'] : '',
            );

            update_option('wpsr_instagram_configs', array('connected_accounts' => $connected_accounts));

        }

        return get_option('wpsr_instagram_configs', array());
    }

    /**
     * Get Cache Settings
     *
     * @return json
     * @since 1.2.5
     */
    public function getGlobalSettings()
    {
        $settings = get_option('wpsr_instagram_global_settings', false);
        wp_send_json_success([
            'message' => __('Settings Found Successfully', 'wpsocialreviews'),
            'settings' => $settings
        ]);
    }

    /**
     * Save Cache Settings
     *
     * @return json
     * @since 1.2.5
     */
    public function saveGlobalSettings()
    {
        $args = json_decode(wp_unslash($_REQUEST['args']));
        $args = json_decode(json_encode($args), true);
        update_option('wpsr_' . $this->platform . '_global_settings', $args, 'no');
        $settings = get_option('wpsr_' . $this->platform . '_global_settings', false);
        $this->doCronEvent();
        wp_send_json_success([
            'message' => __('Settings Saved Successfully', 'wpsocialreviews'),
            'settings' => $settings
        ]);
    }

    /**
     * Set cron event
     *
     * @since 1.2.5
     */
    public function doCronEvent()
    {
        $settings = get_option('wpsr_' . $this->platform . '_global_settings', false);
        if ($settings) {
            //check sync is on or off, if off clear cron event
            $sync = isset($settings['global_settings']['auto_syncing']) ? $settings['global_settings']['auto_syncing'] : 'true';
            $recurrence = isset($settings['global_settings']['cache_recurrence']) ? $settings['global_settings']['cache_recurrence'] : '2weeks';
            if ($sync === 'false') {
                // clear cron event
                wp_clear_scheduled_hook('wpsr_daily_feed_event_' . $this->platform);
            } else if ($sync === 'true') {
                //clear the existing cron event
                wp_clear_scheduled_hook('wpsr_daily_feed_event_' . $this->platform);
                wp_schedule_event(time(), $recurrence, 'wpsr_daily_feed_event_' . $this->platform);
            }
        }
    }

}