<?php

namespace WPSocialReviews\Classes\Feeds\Instagram;

if (!defined('ABSPATH')) {
    exit;
}

class RefreshToken
{

    private $api = 'https://graph.instagram.com/refresh_access_token';
    private $grant_type = 'ig_refresh_token';
    private $optionKey = 'wpsr_instagram_configs';

    public function __construct()
    {

    }

    public function makeRequest($url, $bodyArgs, $type = 'GET', $headers = false)
    {
        if (!$headers) {
            $headers = array(
                'Content-Type' => 'application/http',
                'Content-Transfer-Encoding' => 'binary',
                'MIME-Version' => '1.0',
            );
        }
        $args = [
            'headers' => $headers
        ];
        if ($bodyArgs) {
            $args['body'] = json_encode($bodyArgs);
        }
        $args['method'] = $type;

        $url = $url . '?grant_type=ig_refresh_token&access_token=' . $bodyArgs['access_token'];
        $request = wp_remote_retrieve_body(wp_remote_request($url));

        if (is_wp_error($request)) {
            $message = $request->get_error_message();
            return new \WP_Error(423, $message);
        }
//        $body = json_decode(wp_remote_retrieve_body($request), true);
//        if(!empty($body['error'])) {
//            $error = 'Unknown Error';
//            if(isset($body['error_description'])) {
//                $error = $body['error_description'];
//            } else if(!empty($body['error']['message'])) {
//                $error = $body['error']['message'];
//            }
//            return new \WP_Error(423, $error);
//        }

        return $request;
    }

    public function generateAccessKey($token)
    {
        $body = [
            'grant_type' => $this->grant_type,
            'access_token' => $token,
        ];
        return $this->makeRequest($this->api, $body);
    }

    public function getAccessToken($connected_account)
    {

        $options = get_option($this->optionKey);
        if (!$options) {
            return false;
        }
        $connected_accounts = isset($options['connected_accounts']) ? $options['connected_accounts'] : array();

        $connectedId = isset($connected_account['user_id']) ? $connected_account['user_id'] : '';
        $connected_account = isset($connected_accounts[$connectedId]) ? $connected_accounts[$connectedId] : array();

        if (empty($connected_accounts)) {
            return false;
        }

        $t = 24 * 60 * 60;

        if (!empty($connected_account['expires_in'] && !empty($connected_account['created_at'])) && ($connected_account['created_at'] + $connected_account['expires_in'] - $t) < time()) {

            // It's expired so we have to re-issue again
            $refreshTokens = $this->refreshToken($connected_account);

            if (!is_wp_error($refreshTokens)) {

                $accessToken = isset($refreshTokens['access_token']) ? $refreshTokens['access_token'] : '';
                $connected_accounts[$connectedId] = array(
                    'access_token' => $accessToken,
                    'expires_in' => isset($refreshTokens['expires_in']) ? $refreshTokens['expires_in'] : '',
                    'created_at' => time(),
                    'user_id' => $connectedId,
                    'username' => isset($connected_account['username']) ? $connected_account['username'] : '',
                    'api_type' => isset($connected_account['api_type']) ? $connected_account['api_type'] : '',
                    'user_avatar' => isset($connected_account['user_avatar']) ? $connected_account['user_avatar'] : '',
                    'name' => isset($connected_account['name']) ? $connected_account['name'] : ''
                );

                update_option($this->optionKey, array('connected_accounts' => $connected_accounts, 'no'));
                return $accessToken;

            } else {
                return false;
            }
        }
        return $connected_account['access_token'];

    }

    private function refreshToken($token)
    {

        $args = [
            'access_token' => $token['access_token'],
            'grant_type' => $this->grant_type
        ];
        return $this->makeRequest($this->api, $args);
    }

}
