<?php

namespace WPSocialReviews\Classes\Feeds\Twitter;

use WPSocialReviews\Classes\Feeds\BaseFeed;
use WPSocialReviews\Classes\Helper;
use WPSocialReviews\Classes\Feeds\Common\FeedFilters;

if (!defined('ABSPATH')) {
    exit;
}

class TwitterFeed extends BaseFeed
{
    protected $consumerKey = 'sh28wFaco96FXhzEWuKY71k4z';
    protected $consumerSecret = 'pJASn62pdt60DjlUi4OWvL8guRVnnAhuhRl5xaqnqfz6oRXxuO';
    protected $baseFeedUrl = 'https://api.twitter.com/1.1/';
    protected $totalFeed = 10;
    protected $paginate = 6;

    public $platform = 'twitter';

    public function __construct()
    {
        parent::__construct($this->platform);
    }

    public function getFeedSettings()
    {
        $postId = intval($_REQUEST['post_id']);
        $feed_template_meta = get_post_meta($postId, '_wpsr_twitter_template_config', true);

        // wp_send_json_success([
        //     'feed_meta' => $feed_template_meta
        // ]);

        $configs = isset($feed_template_meta['feed_settings']) ? $feed_template_meta['feed_settings'] : array();
        $formatted_feed_template_meta = self::formatTwitterConfig($configs, array());


        //feed settings to simplify repetitive use
        $feed_settings = isset($formatted_feed_template_meta['feed_settings']) ? $formatted_feed_template_meta['feed_settings'] : array();

        //get dynamic response
        $apiSettings = isset($feed_settings['additional_settings']) ? $feed_settings['additional_settings'] : array();

        $feed_type = isset($apiSettings['additional_settings']['feed_type']) ? $apiSettings['additional_settings']['feed_type'] : '';
        $count = isset($apiSettings['additional_settings']['feed_count']) ? $apiSettings['additional_settings']['feed_count'] : $this->totalFeed;
        $response = $this->apiConnectionResponse($feed_type, $count, $formatted_feed_template_meta);

        $filterSettings = isset($feed_settings['filters']) ? $feed_settings['filters'] : array();

        if (isset($response['error_message'])) {
            $filterResponse = $response;
        } else {
            $filterResponse = (new FeedFilters)->filterFeedResponse($this->platform, $filterSettings, $response);
        }

        $formatted_feed_template_meta['dynamic'] = isset($filterResponse['feed']) ? $filterResponse['feed'] : array();
        $formatted_feed_template_meta['header'] = isset($filterResponse['header']) ? $filterResponse['header'] : array();
        $configs = $formatted_feed_template_meta;

        $templateDetails = get_post($postId);
        Helper::sendSuccess([
            'message' => __('Success', 'wpsocialreviews'),
            'settings' => $configs,
            'template_details' => $templateDetails
        ]);
    }

    //login
    public function platformVarificationLoginNow()
    {
        $this->intervalCacheSettings();
        $args = wp_unslash($_REQUEST['args']);
        $verificationConfigs = json_decode($args);
        if ($verificationConfigs->manual_connect) {
            $settings = array(
                'oauth_access_token' => $verificationConfigs->oauth_token,
                'oauth_access_token_secret' => $verificationConfigs->oauth_token_secret,
                'consumer_key' => $verificationConfigs->consumer_key,
                'consumer_secret' => $verificationConfigs->consumer_secret
            );
        } else {
            $settings = array(
                'oauth_access_token' => $verificationConfigs->oauth_token,
                'oauth_access_token_secret' => $verificationConfigs->oauth_token_secret,
                'consumer_key' => $this->consumerKey,//'sh28wFaco96FXhzEWuKY71k4z',
                'consumer_secret' => $this->consumerSecret//'pJASn62pdt60DjlUi4OWvL8guRVnnAhuhRl5xaqnqfz6oRXxuO'
            );
        }
        $requestMethod = "GET";
        $api_url = $this->baseFeedUrl . 'account/verify_credentials.json';
        $twitter = new TwitterApiSettings($settings);
        $responseTwitter = $twitter->buildOauth($api_url, $requestMethod)->performRequest();
        if (isset($responseTwitter['errors']) || isset($responseTwitter['error'])) {
            $errorMessage = __('Can\'t authenticate you,please provide valid information', 'wpsocialreviews');
            if (isset($responseTwitter['errors']) && isset($responseTwitter['errors'][0]['message'])) {
                $errorMessage = $responseTwitter['errors'][0]['message'];
            }
            if (isset($responseTwitter['error'])) {
                $errorMessage = $responseTwitter['errror'];
            }
            wp_send_json_error([
                'message' => $errorMessage
            ], 423);
        }
        $verificationConfigs->screen_name = isset($responseTwitter['screen_name']) ? $responseTwitter['screen_name'] : '';
        $setTwitterConfigs = self::getTwitterConfig($verificationConfigs);
        update_option('wpsr_twitter_verification_configs', $setTwitterConfigs, 'no');
        $getTwitterConfig = get_option('wpsr_twitter_verification_configs');
        // add global twitter settings when user verified
        $args = array(
            'global_settings' => array(
                'feed_cache_time' => '1209600',
                'feed_cache_clear' => 'clear_cache_button',

                'auto_syncing' => 'true',
                'cache_recurrence' => '2weeks'
            )
        );
        update_option('wpsr_twitter_global_settings', $args);
        Helper::sendSuccess([
            'message' => __('Twitter Successfully Connected!', 'wpsocialreviews'),
            'settings' => $getTwitterConfig
        ]);
    }

    public function getVerificationConfigs()
    {
        $twitterConfig = get_option('twitter_verification_configs', false);
        if (!$twitterConfig) {
            $twitterConfig = get_option('wpsr_twitter_verification_configs');
        }
        Helper::sendSuccess([
            'message' => __('Twitter Successfully Connected!', 'wpsocialreviews'),
            'settings' => $twitterConfig
        ]);
    }

    public function disconnectVerificationConfigs()
    {
        $twitterConfig = delete_option('twitter_verification_configs', false);
        if (!$twitterConfig) {
            $twitterConfig = delete_option('wpsr_twitter_verification_configs');
        }
        delete_option('wpsr_twitter_global_settings', false);
        delete_option('twitter_global_settings', false);

        Helper::sendSuccess([
            'message' => __('Twitter Successfully Disconnected!', 'wpsocialreviews'),
            'settings' => $twitterConfig
        ]);
    }

    public function apiConnectionResponse($feed_type, $count, $newConfigs = null)
    {
        //do not cache if no tweets found
        $configs = get_option('twitter_verification_configs', false);
        if (!$configs) {
            $configs = get_option('wpsr_twitter_verification_configs', false);
        }

        $name = $hashtag = '';

        if ($newConfigs) {
            $newConfigs = $newConfigs['feed_settings']['additional_settings'];
            $feed_type = isset($newConfigs['feed_type']) ? $newConfigs['feed_type'] : '';
            $count = isset($newConfigs['feed_count']) ? $newConfigs['feed_count'] : '';
            $name = isset($newConfigs['screen_name']) ? $newConfigs['screen_name'] : '';
            $hashtag = isset($newConfigs['hashtag']) ? $newConfigs['hashtag'] : '';
        }

        if (!$name) {
            //for old settings
            if (isset($configs['dynamic'])) {
                $name = $configs['dynamic']->screen_name;
            }
        }

        if ($name) {

            $data_cache = '';

            if ($feed_type === 'home_timeline') {
                $data_cache = 'twitter_data_cache_' . $feed_type . '_num' . $count . '';
            } else if ($feed_type === 'user_timeline') {
                $data_cache = 'twitter_data_cache_' . $feed_type . '_num' . $count . '_name' . $name;
            }

            $data_cache = apply_filters('wpsocialreviews/twitter_data_cache', $data_cache, $feed_type, $count, $hashtag);

            $response = array();
            // Check Cache.
            $cache_used = false;
            if (false !== $this->checkFeedCacheExists($data_cache)) {
                $response = $this->getFeedCache($data_cache);
                $cache_used = true;
            } else {

                $settings = array();
                $connectTwitter = false;


                //if manually connect we need four params
                if (!empty($configs) && (isset($configs['dynamic']->manual_connect) && $configs['dynamic']->manual_connect)) {
                    $settings = array(
                        'oauth_access_token' => isset($configs['dynamic']->oauth_token) ? $configs['dynamic']->oauth_token : '',
                        'oauth_access_token_secret' => isset($configs['dynamic']->oauth_token_secret) ? $configs['dynamic']->oauth_token_secret : '',
                        'consumer_key' => isset($configs['dynamic']->consumer_key) ? $configs['dynamic']->consumer_key : '',
                        'consumer_secret' => isset($configs['dynamic']->consumer_secret) ? $configs['dynamic']->consumer_secret : '',
                    );

                    $connectTwitter = true;
                } else {

                    $settings = array(
                        'oauth_access_token' => isset($configs['dynamic']->oauth_token) ? $configs['dynamic']->oauth_token : '',
                        'oauth_access_token_secret' => isset($configs['dynamic']->oauth_token_secret) ? $configs['dynamic']->oauth_token_secret : '',
                        'consumer_key' => $this->consumerKey,//'sh28wFaco96FXhzEWuKY71k4z',
                        'consumer_secret' => $this->consumerSecret//'pJASn62pdt60DjlUi4OWvL8guRVnnAhuhRl5xaqnqfz6oRXxuO'
                    );
                    $connectTwitter = true;
                }

                if ($connectTwitter) {

                    $requestMethod = "GET";

                    $get_field = '?count=' . intval($count);

                    $api_url = '';

                    if ($feed_type === 'user_timeline') {
                        $api_url = $this->baseFeedUrl . 'statuses/user_timeline.json';
                        $get_field = "?screen_name=" . $name . "&count=" . intval($count) . "&tweet_mode=extended&exclude_replies=true";
                    } elseif ($feed_type === 'home_timeline') {
                        $api_url = $this->baseFeedUrl . 'statuses/home_timeline.json';
                        $get_field = '?count=' . intval($count) . "&tweet_mode=extended&exclude_replies=true";
                    }

                    $api_url = apply_filters('wpsocialreviews/twitter_api_url', $api_url, $feed_type, $this->baseFeedUrl);

                    $get_field = apply_filters('wpsocialreviews/twitter_get_field', $get_field, $feed_type, $count, $hashtag);

                    $twitter = new TwitterApiSettings($settings);
                    $responseTwitter = $twitter->setGetfield($get_field)->buildOauth($api_url, $requestMethod)->performRequest();

                    if (isset($responseTwitter['error'])) {

                        //if error found and permanent cache exists then show permanent cache
                        if (true === $this->checkFeedCacheExists($data_cache, true)) {
                            $response = $this->getFeedCache($data_cache, true);
                        } else {
                            return array('error_message' => $responseTwitter['error']);
                        }
                    } else {
                        $response['feed'] = apply_filters('wpsocialreviews/twitter_feed_response', $responseTwitter, $feed_type);

                        $response['header'] = apply_filters('wpsocialreviews/twitter_feed_header_api_response', $twitter, $name, $this->baseFeedUrl);

                        // Cache It.
                        $this->createFeedCache($data_cache, $response);
                    }
                } else {
                    return array('error_message' => __('Please set your twitter configuration correctly!!', 'wpsocialreviews'));
                }
            }

            return $response;

        }

    }

    public function saveUpdatedFeedEditorSettings()
    {
        $postId = intval($_REQUEST['post_id']);
        $args = wp_unslash($_REQUEST['args']);
        update_post_meta($postId, '_wpsr_twitter_template_config', array('feed_settings' => $args));
        $configs = get_post_meta($postId, '_wpsr_twitter_template_config', true);
        $feed_type = $configs['feed_settings']['additional_settings']['feed_type'];
        $count = $configs['feed_settings']['additional_settings']['feed_count'] ? $configs['feed_settings']['additional_settings']['feed_count'] : $this->totalFeed;
        //we have to pass all the credentials for api connection from here
        $response = $this->apiConnectionResponse($feed_type, $count, $configs);
        //$configs = $this->formatTwitterConfig($configs['feed_settings'], $response);

        $filterSettings = isset($configs['feed_settings']['filters']) ? $configs['feed_settings']['filters'] : array();

        $filterResponse = array();

        if (isset($response['error_message'])) {
            $filterResponse = $response;
        } else {
            $filterResponse = (new FeedFilters)->filterFeedResponse($this->platform, $filterSettings, $response);
        }

        $configs = $this->formatTwitterConfig($configs['feed_settings'], $filterResponse);

        $templateDetails = get_post($postId);
        Helper::sendSuccess([
            'message' => __('Template Saved Successfully!!', 'wpsocialreviews'),
            'settings' => $configs,
            'template_details' => $templateDetails
        ]);
    }

    public function updateFeedEditorSettings()
    {
        $args = wp_unslash($_REQUEST['args']);

        $configs = $args;

        $formatted_feed_template_meta = self::formatTwitterConfig($configs, array());

        //feed settings to simplify repetitive use
        $feed_settings = isset($formatted_feed_template_meta['feed_settings']) ? $formatted_feed_template_meta['feed_settings'] : array();

        //get dynamic response
        $apiSettings = isset($feed_settings['additional_settings']) ? $feed_settings['additional_settings'] : array();

        $feed_type = isset($apiSettings['additional_settings']['feed_type']) ? $apiSettings['additional_settings']['feed_type'] : '';
        $count = isset($apiSettings['additional_settings']['feed_count']) ? $apiSettings['additional_settings']['feed_count'] : $this->totalFeed;
        $response = $this->apiConnectionResponse($feed_type, $count, $formatted_feed_template_meta);

        $filterSettings = isset($feed_settings['filters']) ? $feed_settings['filters'] : array();

        $filterResponse = array();

        if (isset($response['error_message'])) {
            $filterResponse = $response;
        } else {
            $filterResponse = (new FeedFilters)->filterFeedResponse($this->platform, $filterSettings, $response);
        }

        $formatted_feed_template_meta['dynamic'] = $filterResponse['feed'];
        $formatted_feed_template_meta['header'] = $filterResponse['header'];
        $configs = $formatted_feed_template_meta;

        Helper::sendSuccess([

            'message' => __('Twitter Settings Updated', 'wpsocialreviews'),
            'settings' => $configs,

        ]);
    }

    //works on save new template
    public function formatTwitterConfig($settings, $response)
    {

        $isPopup = isset($settings['advance_settings']['show_image_video_popup']) ? $settings['advance_settings']['show_image_video_popup'] : 'false';

        if (!defined('WPSOCIALREVIEWS_PRO')) {
            $isPopup = 'false';
        }

        return array(

            'feed_settings' => array(

                'platform' => 'twitter',
                'template' => isset($settings['template']) ? $settings['template'] : 'template1',
                'layout_type' => isset($settings['layout_type']) ? $settings['layout_type'] : 'standard',
                'column_number' => isset($settings['column_number']) ? $settings['column_number'] : '4',
                'column_gaps' => isset($settings['column_gaps']) ? $settings['column_gaps'] : 'default',

                'additional_settings' => array(
                    'feed_type' => isset($settings['additional_settings']['feed_type']) ? $settings['additional_settings']['feed_type'] : 'user_timeline',
                    'feed_count' => isset($settings['additional_settings']['feed_count']) ? $settings['additional_settings']['feed_count'] : $this->totalFeed,
                    "screen_name" => isset($settings['additional_settings']['screen_name']) ? $settings['additional_settings']['screen_name'] : '',
                    "hashtag" => isset($settings['additional_settings']['hashtag']) ? $settings['additional_settings']['hashtag'] : '',
                ),
                'pagination_settings' => array(

                    'pagination_type' => isset($settings['pagination_settings']['pagination_type']) ? $settings['pagination_settings']['pagination_type'] : 'none',
                    'paginate' => (isset($settings['pagination_settings']['paginate']) && !empty($settings['pagination_settings']['paginate'])) ? $settings['pagination_settings']['paginate'] : $this->paginate,

                ),
                'carousel_settings' => array(

                    'autoplay' => isset($settings['carousel_settings']['autoplay']) ? $settings['carousel_settings']['autoplay'] : 'true',
                    'autoplay_speed' => isset($settings['carousel_settings']['autoplay_speed']) ? intval($settings['carousel_settings']['autoplay_speed']) : 3000,
                    'slides_to_show' => isset($settings['carousel_settings']['slides_to_show']) ? intval($settings['carousel_settings']['slides_to_show']) : 3,
                    'slides_to_scroll' => isset($settings['carousel_settings']['slides_to_scroll']) ? intval($settings['carousel_settings']['slides_to_scroll']) : 3,
                    'navigation' => isset($settings['carousel_settings']['navigation']) ? $settings['carousel_settings']['navigation'] : 'dot'
                ),
                'advance_settings' => array(

                    'user_name' => isset($settings['advance_settings']['user_name']) ? $settings['advance_settings']['user_name'] : 'true',
                    'avatar_image' => isset($settings['advance_settings']['avatar_image']) ? $settings['advance_settings']['avatar_image'] : 'true',
                    'author_name' => isset($settings['advance_settings']['author_name']) ? $settings['advance_settings']['author_name'] : 'true',
                    'twitter_logo' => isset($settings['advance_settings']['twitter_logo']) ? $settings['advance_settings']['twitter_logo'] : 'true',
                    'tweet_text' => isset($settings['advance_settings']['tweet_text']) ? $settings['advance_settings']['tweet_text'] : 'true',
                    'date' => isset($settings['advance_settings']['date']) ? $settings['advance_settings']['date'] : 'true',
                    'show_reply_action' => isset($settings['advance_settings']['show_reply_action']) ? $settings['advance_settings']['show_reply_action'] : 'true',
                    'show_retweet_action' => isset($settings['advance_settings']['show_retweet_action']) ? $settings['advance_settings']['show_retweet_action'] : 'true',
                    'show_like_action' => isset($settings['advance_settings']['show_like_action']) ? $settings['advance_settings']['show_like_action'] : 'true',
                    'equal_height' => isset($settings['advance_settings']['equal_height']) ? $settings['advance_settings']['equal_height'] : 'true',
                    'show_retweeted_tweet' => isset($settings['advance_settings']['show_retweeted_tweet']) ? $settings['advance_settings']['show_retweeted_tweet'] : 'true',
                    'show_quoted_tweet' => isset($settings['advance_settings']['show_quoted_tweet']) ? $settings['advance_settings']['show_quoted_tweet'] : 'true',
                    'show_tweet_image' => isset($settings['advance_settings']['show_tweet_image']) ? $settings['advance_settings']['show_tweet_image'] : 'true',
                    'show_tweet_video' => isset($settings['advance_settings']['show_tweet_video']) ? $settings['advance_settings']['show_tweet_video'] : 'true',
                    'show_tweet_gif' => isset($settings['advance_settings']['show_tweet_gif']) ? $settings['advance_settings']['show_tweet_gif'] : 'true',
                    'show_image_video_popup' => $isPopup,
                    'show_twitter_card' => isset($settings['advance_settings']['show_twitter_card']) ? $settings['advance_settings']['show_twitter_card'] : 'false',
                    'show_card_for_third_party_url' => isset($settings['advance_settings']['show_card_for_third_party_url']) ? $settings['advance_settings']['show_card_for_third_party_url'] : 'false',

                ),
                'header_settings' => array(

                    'show_header' => isset($settings['header_settings']['show_header']) ? $settings['header_settings']['show_header'] : 'true',
                    'show_total_tweets' => isset($settings['header_settings']['show_total_tweets']) ? $settings['header_settings']['show_total_tweets'] : 'true',
                    'show_following' => isset($settings['header_settings']['show_following']) ? $settings['header_settings']['show_following'] : 'true',
                    'show_followers' => isset($settings['header_settings']['show_followers']) ? $settings['header_settings']['show_followers'] : 'true',
                    'show_follow_button' => isset($settings['header_settings']['show_follow_button']) ? $settings['header_settings']['show_follow_button'] : 'true',
                    'show_name' => isset($settings['header_settings']['show_name']) ? $settings['header_settings']['show_name'] : 'true',
                    'show_user_name' => isset($settings['header_settings']['show_user_name']) ? $settings['header_settings']['show_user_name'] : 'true',
                    'show_avatar' => isset($settings['header_settings']['show_avatar']) ? $settings['header_settings']['show_avatar'] : 'true',
                    'show_description' => isset($settings['header_settings']['show_description']) ? $settings['header_settings']['show_description'] : 'true',
                    'show_banner_image' => isset($settings['header_settings']['show_banner_image']) ? $settings['header_settings']['show_banner_image'] : 'true',
                    'show_location' => isset($settings['header_settings']['show_location']) ? $settings['header_settings']['show_location'] : 'true',

                ),

                'filters' => array(
                    'total_posts' => isset($settings['filters']['total_posts']) ? intval($settings['filters']['total_posts']) : 50,
                    'post_order' => isset($settings['filters']['post_order']) ? $settings['filters']['post_order'] : 'ascending',
                    'includes_inputs' => isset($settings['filters']['includes_inputs']) ? $settings['filters']['includes_inputs'] : '',
                    'excludes_inputs' => isset($settings['filters']['excludes_inputs']) ? $settings['filters']['excludes_inputs'] : '',
                ),

                'popup_settings' => array(
                    'autoplay' => isset($settings['popup_settings']['autoplay']) ? $settings['popup_settings']['autoplay'] : 'true',
                    'display_sidebar' => isset($settings['popup_settings']['display_sidebar']) ? $settings['popup_settings']['display_sidebar'] : 'true',
                    'user_name' => isset($settings['popup_settings']['user_name']) ? $settings['popup_settings']['user_name'] : 'true',
                    'avatar_image' => isset($settings['popup_settings']['avatar_image']) ? $settings['popup_settings']['avatar_image'] : 'true',
                    'author_name' => isset($settings['popup_settings']['author_name']) ? $settings['popup_settings']['author_name'] : 'true',
                    'twitter_logo' => isset($settings['popup_settings']['twitter_logo']) ? $settings['popup_settings']['twitter_logo'] : 'true',
                    'tweet_text' => isset($settings['popup_settings']['tweet_text']) ? $settings['popup_settings']['tweet_text'] : 'true',
                    'display_date' => isset($settings['popup_settings']['display_date']) ? $settings['popup_settings']['display_date'] : 'true',
                    'show_reply_action' => isset($settings['popup_settings']['show_reply_action']) ? $settings['popup_settings']['show_reply_action'] : 'true',
                    'show_retweet_action' => isset($settings['popup_settings']['show_retweet_action']) ? $settings['popup_settings']['show_retweet_action'] : 'true',
                    'show_like_action' => isset($settings['popup_settings']['show_like_action']) ? $settings['popup_settings']['show_like_action'] : 'true',
                )

            ),
            'dynamic' => isset($response['feed']) ? $response['feed'] : $response,
            'header' => isset($response['header']) ? $response['header'] : []
        );
    }

    //its works on varification
    public static function getTwitterConfig($response)
    {
        return array(
            'dynamic' => $response,
        );
    }

    /**
     * Create Feed Cache
     * @param string $transient_name .
     * @param array $response .
     * @throws /Exception
     * @since 1.1.0
     */
    public function createFeedCache($transient_name, $response)
    {
        if (true === $this->checkFeedCacheExists($transient_name)) {
            $this->deletePermanentFeedCache($transient_name);
        }
        $settings = get_option('twitter_global_settings', false);
        if (!$settings) {
            $settings = get_option('wpsr_twitter_global_settings', false);
        }
        $cache_time_limit = isset($settings['global_settings']['feed_cache_time']) ? intval($settings['global_settings']['feed_cache_time']) : 86400;
        set_transient('wpsr_twitter_tc_' . $transient_name, $response, $cache_time_limit);
        set_transient('wpsr_twitter_pc_' . $transient_name, $response, 0);
    }

    /**
     * Check Feed Cache Exists or Not
     * @param string $transient_name transient name.
     * @param boolean $errored Error Check.
     * @return boolean
     * @since 1.1.0
     */
    public function checkFeedCacheExists($transient_name, $errored = null)
    {
        $transient_permanent_check = get_transient('wpsr_twitter_pc_' . $transient_name);
        $transient_time_check = get_transient('wpsr_twitter_tc_' . $transient_name);
        if (true === $errored && false !== $transient_permanent_check) {
            return true;
        }
        if (true !== $errored && false !== $transient_permanent_check && false !== $transient_time_check) {
            return true;
        }
        return false;
    }

    /**
     * Delete permanent feed Cache
     *
     * @return string
     * @throws /Exception
     * @since 1.1.0
     */
    public function deletePermanentFeedCache($transient_name)
    {
        wpSocialReviewsDB()->table('options')->where('option_name', 'LIKE', '_transient_wpsr_twitter_pc_' . $transient_name)->delete();
        return __('Permanent feed cache cleared!', 'wpsocialreviews');
    }

    /**
     * Get Feed Cache
     *
     * @param string $transient_name Transient name.
     * @param boolean $errored Error Check.
     * @return mixed
     * @since 1.1.0
     */
    public function getFeedCache($transient_name, $errored = null)
    {
        if (true === $errored) {
            return get_transient('wpsr_twitter_pc_' . $transient_name);
        }
        return get_transient('wpsr_twitter_tc_' . $transient_name);
    }

    //clear cache on interval
    public function intervalCacheSettings()
    {
        $settings = get_option('twitter_global_settings', false);
        if (!$settings) {
            $settings = get_option('wpsr_twitter_global_settings', false);
        }
        $cron_clear_cache = isset($settings['global_settings']['auto_syncing']) ? $settings['global_settings']['auto_syncing'] : 'false';
        $recurrence = isset($settings['global_settings']['cache_recurrence']) ? $settings['global_settings']['cache_recurrence'] : '2weeks';
        if ($cron_clear_cache === 'false') {
            wp_clear_scheduled_hook('interval_cron_job');
        } else if ($cron_clear_cache === 'true') {
            wp_clear_scheduled_hook('interval_cron_job');
            wp_schedule_event(time(), $recurrence, 'interval_cron_job');
        }
    }

    public function twitter_deactivate()
    {
        $this->clear_interval_cache();
        wp_clear_scheduled_hook('interval_cron_job');
    }

    public function saveGlobalSettings()
    {
        $args = wp_unslash($_REQUEST['args']);
        update_option('wpsr_twitter_global_settings', $args, 'no');
        $settings = get_option('wpsr_twitter_global_settings', false);
        Helper::sendSuccess([
            'message' => __('Settings Saved Successfully', 'wpsocialreviews'),
            'settings' => $settings
        ]);
    }

    public function getGlobalSettings()
    {
        $settings = get_option('twitter_global_settings', false);
        if (!$settings) {
            $settings = get_option('wpsr_twitter_global_settings', false);
        }
        Helper::sendSuccess([
            'message' => __('Settings Saved Successfully', 'wpsocialreviews'),
            'settings' => $settings
        ]);
    }

}
