<?php

namespace WPSocialReviews\Classes;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Register and initialize Helper for getting advantage of a function or to use same function for multiple file
 * @since 1.0.0
 */
class Helper
{
    /**
     * Http Call for fetching api data
     *
     * @param $url
     * @return mixed
     * @since 1.0.0
     */
    public static function httpDataFetch($url)
    {
        $response = wp_remote_get($url);
        $data = json_decode(wp_remote_retrieve_body($response), true);
        return $data;
    }

    /**
     * Json Success Message
     *
     * @param $data
     * @return array
     * @since 1.0.0
     */
    public static function sendSuccess($data)
    {
        wp_send_json_success($data, 200);
    }

    /**
     * Json Error Message
     *
     * @param $data
     * @return json
     * @since 1.0.0
     */
    public static function sendError($data)
    {
        wp_send_json_error($data, 423);
    }

    /**
     * Generate rating SVG icon based on rating value
     *
     * @param $rating
     * @return string
     * @since 1.0.0
     */
    public static function reviewIcon($rating)
    {
        $icons = '';
        foreach (array(1, 2, 3, 4, 5) as $val) {
            $score = $rating - $val;

            if ($score >= 0) {
                $icons .= '<span class="wpsr-star"><svg xmlns="http://www.w3.org/2000/svg" version="1.1" viewBox="0 0 1792 1792"><path
                                d="M1728 647q0 22-26 48l-363 354 86 500q1 7 1 20 0 21-10.5 35.5t-30.5 14.5q-19 0-40-12l-449-236-449 236q-22 12-40 12-21 0-31.5-14.5t-10.5-35.5q0-6 2-20l86-500-364-354q-25-27-25-48 0-37 56-46l502-73 225-455q19-41 49-41t49 41l225 455 502 73q56 9 56 46z"></path></svg></span>';

            } else if ($score > -1 && $score < 0) {
                $icons .= '<span class="wpsr-star"><svg xmlns="http://www.w3.org/2000/svg" version="1.1" viewBox="0 0 1792 1792"><path
                                d="M1250 957l257-250-356-52-66-10-30-60-159-322v963l59 31 318 168-60-355-12-66zm452-262l-363 354 86 500q5 33-6 51.5t-34 18.5q-17 0-40-12l-449-236-449 236q-23 12-40 12-23 0-34-18.5t-6-51.5l86-500-364-354q-32-32-23-59.5t54-34.5l502-73 225-455q20-41 49-41 28 0 49 41l225 455 502 73q45 7 54 34.5t-24 59.5z"></path></svg></span>';
            } else {
                $icons .= '<span class="wpsr-star"><svg xmlns="http://www.w3.org/2000/svg" version="1.1" viewBox="0 0 1792 1792"><path
                                d="M1201 1004l306-297-422-62-189-382-189 382-422 62 306 297-73 421 378-199 377 199zm527-357q0 22-26 48l-363 354 86 500q1 7 1 20 0 50-41 50-19 0-40-12l-449-236-449 236q-22 12-40 12-21 0-31.5-14.5t-10.5-35.5q0-6 2-20l86-500-364-354q-25-27-25-48 0-37 56-46l502-73 225-455q19-41 49-41t49 41l225 455 502 73q56 9 56 46z"></path></svg></span>';
            }

        }
        return $icons;
    }

    /**
     * Get Meta PlatformName from meta values
     *
     * @param $post_id
     * @return array|string
     * @since 1.0.0
     */
    public static function getPlatformNameByPostId($post_id)
    {
        $reviews_template_config = get_post_meta($post_id, '_wpsr_template_config', true);

        if ($reviews_template_config) {

            $replacements = array(
                'google_my_business' => 'google',
            );

            foreach ($reviews_template_config['platform'] as $key => $value) {
                if (isset($replacements[$value])) {
                    $reviews_template_config['platform'][$key] = $replacements[$value];
                }
            }

            return $reviews_template_config ? implode(', ', $reviews_template_config['platform']) : '';
        }

        $template_config = get_post_meta($post_id, '_wpsr_twitter_template_config', true);

        if (!$template_config) {
            $template_config = get_post_meta($post_id, '_wpsr_youtube_template_config', true);
        }
        if (!$template_config) {
            $template_config = get_post_meta($post_id, '_wpsr_instagram_template_config', true);
        }

        return isset($template_config['feed_settings']['platform']) ? $template_config['feed_settings']['platform'] : '';
    }

    /**
     * Get all pages list
     *
     * @return array
     * @since 1.1.0
     */
    public static function getPagesList()
    {
        $pages = get_pages();
        $page_list = array(array('page_id' => '-1', 'page_title' => __('All Pages', 'wpsocialreviews')));
        if (!empty($pages) && !is_wp_error($pages)) {
            foreach ($pages as $page) {
                $page_list[] = array('page_id' => $page->ID . '', 'page_title' => $page->post_title ? $page->post_title : __('Untitled', 'wpsocialreviews'));
            }
        }
        return $page_list;
    }

    public static function getUrls($string)
    {
        $regex = '/https?\:\/\/[^\" \n]+/i';
        preg_match_all($regex, $string, $matches);
        //note below that we use $matches[0], this is because we have an array of arrays
        foreach ($matches[0] as $url) {
            $s1 = substr($url, 0, strlen($url) - 2);
            $s2 = '<a href="' . $s1 . '">' . $s1 . '</a>';
            echo "$s2<br />\n";
        }
    }

    public static function replaceTweetUrls($feed)
    {
        // actual tweet as a string
        $text = '';
        if (isset($feed['full_text'])) {

            $text = isset($feed['retweeted_status']) ? $feed['retweeted_status']['full_text'] : $feed['full_text'];

        }
        $tweetText = $text;
        // create an array to hold urls
        $tweetEntities = array();
        $urls = isset($feed['retweeted_status']['entities']['urls']) ? $feed['retweeted_status']['entities']['urls'] : $feed['entities']['urls'];
        $user_mentions = isset($feed['retweeted_status']['entities']['user_mentions']) ? $feed['retweeted_status']['entities']['user_mentions'] : $feed['entities']['user_mentions'];
        $hashtags = isset($feed['retweeted_status']['entities']['hashtags']) ? $feed['retweeted_status']['entities']['hashtags'] : $feed['entities']['hashtags'];

        // add each url to the array
        foreach ($urls as $url) {
            // hide twitter.com url from string
            $hide_link = strpos($url['display_url'], "twitter.com") !== false ? 'wpsr-hide-link' : '';

            $tweetEntities[] = array(
                'type' => 'url',
                'curText' => mb_substr($tweetText, $url['indices'][0], ($url['indices'][1] - $url['indices'][0]), "UTF-8"),
                'newText' => '<a class="wpsr-link-tweet ' . esc_attr($hide_link) . '" href="' . $url['expanded_url'] . '" target="_blank">' . $url['display_url'] . '</a>'
            );
        }  // end foreach

        // add each user mention to the array
        foreach ($user_mentions as $mention) {
            $string = mb_substr($tweetText, $mention['indices'][0], ($mention['indices'][1] - $mention['indices'][0]), "UTF-8");
            $tweetEntities[] = array(
                'type' => 'mention',
                'curText' => mb_substr($tweetText, $mention['indices'][0], ($mention['indices'][1] - $mention['indices'][0]), "UTF-8"),
                'newText' => "<a class='wpsr-link-mention' href='http://twitter.com/" . $mention['screen_name'] . "' target='_blank'>$string</a>"
            );
        }  // end foreach

        // add each hashtag to the array
        foreach ($hashtags as $tag) {
            $string = mb_substr($tweetText, $tag['indices'][0], ($tag['indices'][1] - $tag['indices'][0]), "UTF-8");

            $tweetEntities[] = array(
                'type' => 'hashtag',
                'curText' => mb_substr($tweetText, $tag['indices'][0], ($tag['indices'][1] - $tag['indices'][0]), "UTF-8"),
                'newText' => "<a class='wpsr-link-hashtag' href='http://twitter.com/search?q=%23" . $tag['text'] . "&src=hash' target='_blank'>" . $string . "</a>"
            );
        }  // end foreach


        // replace the old text with the new text for each entity
        foreach ($tweetEntities as $entity) {
            $tweetText = str_replace($entity['curText'], $entity['newText'], $tweetText);
        } // end foreach

        // remove t.com urls from string
        if (isset($feed['retweeted_status']['entities']['media'][0]['url'])) {
            $default_url = $feed['retweeted_status']['entities']['media'][0]['url'];
        } elseif (isset($feed['quoted_status']['entities']['media'][0]['url'])) {
            $default_url = $feed['quoted_status']['entities']['media'][0]['url'];
        } else {
            $default_url = isset($feed['entities']['media'][0]['url']) ? $feed['entities']['media'][0]['url'] : '';
        }
        $tweetText = str_replace($default_url, '', $tweetText);
        return nl2br($tweetText);
    }

    public static function get_twitter_high_quality_video($variants = array())
    {
        $max = null;
        $max_value_url = null;
        foreach ($variants as $key => $value) {
            if ((isset($value['bitrate']) && $value['content_type'] === 'video/mp4') && ($value['bitrate'] > $max || !$max)) {
                $max = $value['bitrate'];
                $max_value_url = $value['url'];
            }
        }
        return $max_value_url;
    }

    /**
     * Format the tweet text (links, hashtags, mentions)
     *
     * @return array
     * @since 1.1.0
     */
    public static function formatTweet($tweet)
    {
        $linkified = '@(https?://([-\w\.]+[-\w])+(:\d+)?(/([\w/_\.#-]*(\?\S+)?[^\.\s])?)?)@';
        $hashified = '/(^|[\n\s])#([^\s"\t\n\r<:]*)/is';
        $mentionified = '/(^|[\n\s])@([^\s"\t\n\r<:]*)/is';

        $prettyTweet = preg_replace(
            array(
                $linkified,
                $hashified,
                $mentionified
            ),
            array(
                '<a href="$1" class="wpsr-link-tweet" target="_blank" rel="nofollow">$1</a>',
                '$1<a class="wpsr-link-hashtag" href="https://twitter.com/hashtag/$2" target="_blank" rel="nofollow">#$2</a>',
                '$1<a class="wpsr-link-mention" href="http://twitter.com/$2" target="_blank" rel="nofollow">@$2</a>'
            ),
            $tweet
        );
        return $prettyTweet;
    }

    public static function formatYoutubeContent($content)
    {
        $linkified = '@(https?://([-\w\.]+[-\w])+(:\d+)?(/([\w/_\.#-]*(\?\S+)?[^\.\s])?)?)@';
        $hashified = '/(^|[\n\s])#([^\s"\t\n\r<:]*)/is';

        $prettyYt = preg_replace(
            array(
                $linkified,
                $hashified
            ),
            array(
                '<a href="$1" class="wpsr-yt-link" target="_blank" rel="nofollow">$1</a>',
                '$1<a class="wpsr-yt-hashtag" href="https://www.youtube.com/results?search_query=%23$2" target="_blank" rel="nofollow">#$2</a>'
            ),
            $content
        );
        return $prettyYt;
    }

    /**
     * Format the time(ago) and date of each tweet
     * @param $datetime
     * @param $allow_time_since
     * @return date
     * @throws /Exception
     * @since 1.1.0
     */
    public static function timeAgo($datetime, $allow_time_since)
    {
        $day = 60 * 60 * 24;
        $today = time();
        $timestamp = strtotime($datetime);
        $since = $today - $timestamp;

        $now = new \DateTime;
        $ago = new \DateTime($datetime);
        $diff = $now->diff($ago);
        $diff->w = floor($diff->d / 7);
        $diff->d -= $diff->w * 7;
        if (($since / $day) < 1 || $allow_time_since) {
            $since_chunks = array(
                'y' => 'year',
                'm' => 'month',
                'w' => 'week',
                'd' => 'day',
                'h' => 'hour',
                'i' => 'minute',
                's' => 'second',
            );
            foreach ($since_chunks as $key => &$value) {
                if ($diff->$key) {
                    $value = $diff->$key . ' ' . $value . ($diff->$key > 1 ? 's' : '');
                } else {
                    unset($since_chunks[$key]);
                }
            }

            $since_chunks = array_slice($since_chunks, 0, 1);

            return $since_chunks ? implode(', ', $since_chunks) . ' ago' : 'just now';

        } else {
            return date('j M', strtotime($datetime));
        }
    }

    public static function getMultiBusinessInfo($platforms = array())
    {
        $multi_business_info = [];
        $avg_rating = 0;
        $total_rating = 0;
        $platform_urls = [];

        if (!empty($platforms) && is_array($platforms)) {
            foreach ($platforms as $index => $platform) {
                $business_info = get_option('social_review_' . $platform . '_business_info', false);
                if ($business_info && isset($business_info['average_rating']) && $business_info['average_rating'] && $business_info['total_rating'] && isset($business_info['total_rating'])) {
                    $avg_rating += $business_info['average_rating'];
                    $total_rating += $business_info['total_rating'];
                    $platform_urls[$business_info['platform_name']] = isset($business_info['url']) ? $business_info['url'] : '';

                    $multi_business_info['average_rating'] = $platform_urls && $avg_rating ? $avg_rating / sizeof($platform_urls) : '';
                    $multi_business_info['total_rating'] = $total_rating;
                    $multi_business_info['platforms'] = $platform_urls;
                }
            }

        }
        return $multi_business_info;
    }

    public static function allowed_html_tags()
    {
        $allowed_tags = array(
            //formatting
            'strong' => array(),
            'strike' => array(),
            'dl' => array(),
            'dt' => array(),
            'em' => array(),
            'b' => array(),
            'i' => array(),

            //links
            'a' => array(
                'href' => array()
            ),

            'cite' => array(
                'title' => array(),
            ),
            'code' => array(),
            'del' => array(
                'datetime' => array(),
                'title' => array(),
            ),
            'blockquote' => array(
                'cite' => true,
            ),
            'p' => array(
                'class' => array(),
                'style' => array(),
            ),
            'span' => array(
                'class' => array(),
                'title' => array(),
                'style' => array(),
            ),
            'style' => array()
        );
        return $allowed_tags;
    }

    public static function getFirstWord($str = '')
    {
        $words = explode('_', $str);
        return $words[0];
    }

    public static function shortNumberFormat($number)
    {
        $units = ['', 'K', 'M', 'B', 'T'];
        for ($i = 0; $number >= 1000; $i++) {
            $number /= 1000;
        }
        return round($number, 1) . $units[$i];
    }

    public static function getVideoDuration($ytDuration)
    {
        $di = new \DateInterval($ytDuration);
        $hour = '';
        if ($di->h > 0) {
            $hour .= $di->h . ':';
        }
        return $hour . $di->i . ':' . sprintf('%02s', $di->s);
    }

}
