<?php

namespace WPSocialReviews\Classes;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Register Menu and Admin Pages
 * @since 1.0.0
 */
class Menu
{
    public function register()
    {
        add_action('admin_menu', array($this, 'addMenus'));
        add_action('admin_enqueue_scripts', array($this, 'enqueueAssets'));
    }

    /**
     *
     * Add Menu and sub menu for the admin page
     * @return string
     * @since 1.0.0
     *
     **/
    public function addMenus()
    {
        if (!current_user_can('manage_options')) {
            return;
        }

        $title = __('WP Social Ninja', 'wpsocialreviews');

        global $submenu;
        add_menu_page(
            $title,
            $title,
            'manage_options',
            'wpsocialninja.php',
            array($this, 'render'),
            $this->getIcon(),
            25
        );
        $submenu['wpsocialninja.php']['all-platforms'] = array(
            __('All Platforms', 'wpsocialreviews'),
            'manage_options',
            'admin.php?page=wpsocialninja.php#/',
        );
        $submenu['wpsocialninja.php']['all-reviews'] = array(
            __('All Reviews', 'wpsocialreviews'),
            'manage_options',
            'admin.php?page=wpsocialninja.php#/all-reviews',
        );
        $submenu['wpsocialninja.php']['review_templates'] = array(
            __('All Templates', 'wpsocialreviews'),
            'manage_options',
            'admin.php?page=wpsocialninja.php#/all-templates',
        );
        $submenu['wpsocialninja.php']['settings'] = array(
            __('Settings', 'wpsocialreviews'),
            'manage_options',
            'admin.php?page=wpsocialninja.php#/settings/google-settings',
        );
        $submenu['wpsocialninja.php']['support'] = array(
            __('Support', 'wpsocialreviews'),
            'manage_options',
            'admin.php?page=wpsocialninja.php#/support',
        );
    }

    /**
     *
     * 3rd party developer can render admin app from here
     * @return string
     * @since 1.0.0
     *
     **/
    public function render()
    {
        do_action('wpsocialreviews/render_admin_app');
    }

    /**
     *
     * SVG icon for menu
     * @return string
     * @since 1.0.0
     *
     **/
    public function getIcon()
    {
        $svg = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 65.69 68.73"><defs><style>.cls-1{fill:#fff;}</style></defs><g id="Layer_2" data-name="Layer 2"><g id="Layer_1-2" data-name="Layer 1"><path class="cls-1" d="M65.69,32.84A32.89,32.89,0,1,0,53.1,58.68l1.59.35c4.31.93,8.18,6.32,11,9.7V33.06h0C65.68,33,65.69,32.92,65.69,32.84ZM48.2,30.08l-5.83,6s0,.06,0,.11l1.41,8.43a3.3,3.3,0,0,1-.4,2.68,1.62,1.62,0,0,1-1.33.58,4,4,0,0,1-1.81-.55l-7.22-4a.14.14,0,0,0-.13,0l-7.23,4a3.89,3.89,0,0,1-1.83.56,1.65,1.65,0,0,1-1.34-.58A3.51,3.51,0,0,1,22,44.62l1.36-8.43s0-.08,0-.11l-5.84-5.89s0-.05-.05-.05h0c-.93-1-1.33-1.95-1.06-2.76a2.74,2.74,0,0,1,2.45-1.59l8.07-1.26a.35.35,0,0,0,.11-.08l3.6-7.67c.61-1.26,1.38-2,2.21-2s1.62.7,2.21,2l3.63,7.64c0,.06,0,.08.1.08l8.08,1.2a2.78,2.78,0,0,1,2.45,1.59A2.93,2.93,0,0,1,48.2,30.08Z"/></g></g></svg>';
        return 'data:image/svg+xml;base64,' . base64_encode($svg);
    }

    /**
     *
     * Enqueue all js file which are needed for admin side
     * @since 1.0.0
     *
     **/
    public function enqueueAssets()
    {
        if (isset($_GET['page']) && $_GET['page'] == 'wpsocialninja.php') {

            if (function_exists('wp_enqueue_editor')) {
                wp_enqueue_editor();
                wp_enqueue_script('thickbox');
            }

            wp_enqueue_script('wpsocialreviews_boot', WPSOCIALREVIEWS_URL . 'assets/js/social-review-boot.js', array('jquery'), WPSOCIALREVIEWS_VERSION, true);
            // 3rd party developers can now add their scripts here
            do_action('wpsocialreviews/booting_admin_app');
            wp_enqueue_script('wpsocialreviews_admin_app', WPSOCIALREVIEWS_URL . 'assets/js/social-review-admin.js', array('wpsocialreviews_boot'), WPSOCIALREVIEWS_VERSION, true);

            wp_enqueue_script('slick', WPSOCIALREVIEWS_URL . 'assets/libs/slick/slick.min.js', array('jquery', 'wpsocialreviews_boot'), '2.0', true);
            wp_enqueue_script('jquery-masonry');
            wp_enqueue_script('imagesloaded');

            wp_enqueue_style('slick', WPSOCIALREVIEWS_URL . 'assets/libs/slick/slick.css', array(), WPSOCIALREVIEWS_VERSION);
            wp_enqueue_style('slick-theme', WPSOCIALREVIEWS_URL . 'assets/libs/slick/slick-theme.css', array(), WPSOCIALREVIEWS_VERSION);

            wp_enqueue_style('wpsocialreviews_admin_app', WPSOCIALREVIEWS_URL . 'assets/css/social-review-admin.css', array(), WPSOCIALREVIEWS_VERSION);

            $wpsocialreviewsAdminVars = apply_filters('wpsocialreviews/admin_app_vars', array(

                'i18n' => array(
                    'All Collections' => __('All Collections', 'wpsocialreviews')
                ),
                'assets_url' => WPSOCIALREVIEWS_URL . 'assets',
                'has_pro' => defined('WPSOCIALREVIEWS_PRO') && WPSOCIALREVIEWS_PRO,
                'ajaxurl' => admin_url('admin-ajax.php'),
                'image_upload_url' => admin_url('admin-ajax.php?action=wpsocial_review_admin_ajax_chat&route=wpsr_upload_image'),
                'custom_image_upload_url' => admin_url('admin-ajax.php?action=wpsocial_review_admin_ajax&route=wpsr_upload_image'),
                'twitter_authorize_url' => 'https://wpsocialninja.com/api/twitter/process.php?return_url=' . admin_url('admin.php?page=wpsocialninja.php'),
                //'google_authorize_url'    => 'https://gutendev.com/wp-content/plugins/google-login/examples/index.php?return_url='.admin_url('admin.php?page=wpsocialninja.php'),
                'admin_url' => admin_url('admin.php?page=wpsocialninja.php'),
                'google_my_business_admin_url' => admin_url('admin.php')

            ));

            wp_localize_script('wpsocialreviews_boot', 'WPSocialReviewsAdmin', $wpsocialreviewsAdminVars);
        }
    }
}
