<?php

namespace WPSocialReviews\Classes\Reviews;

abstract class BaseReview
{
    public $platform;

    public function __construct($platform)
    {
        $this->platform = $platform;
    }

    public function registerHooks()
    {
        require_once(WPSOCIALREVIEWS_DIR . '/includes/Classes/wpsr_simple_html_dom.php');

        add_action('wpsocialreviews/verify_review_credential_' . $this->platform, array($this, 'handleCredentialSave'));
        add_action('wpsocialreviews/clear_review_credential_' . $this->platform, array($this, 'clearReviewCredential'));
        add_filter('wpsocialreviews/api_credential_' . $this->platform, array($this, 'getApiSettings'));
        add_filter('wpsocialreviews/business_info_' . $this->platform, array($this, 'getBusinessInfo'));
        add_filter('wpsocialreviews/additional_info_' . $this->platform, array($this, 'getAdditionalInfo'));
        add_filter('wpsocialreviews/available_valid_platforms', array($this, 'pushValidPlatform'));
        add_action('wpsocialreviews/get_user_data' . $this->platform, array($this, 'getUserData'));

        //for running the cron job      
        add_action('wpsr_daily_event_' . $this->platform, array($this, 'wpsrDoThisCronEvent'));
        add_action('wpsocialreviews/get_advance_settings_' . $this->platform, array($this, 'getAdvanceSettings'));
        add_action('wpsocialreviews/save_advance_settings_' . $this->platform, array($this, 'saveAdvanceSettings'));
    }

    public function syncRemoteReviews($reviews)
    {
        foreach ($reviews as $index => $review) {
            $exist = false;
            if ($this->platform === 'google_my_business' || $this->platform === 'airbnb') {
                $fieldName = 'reviewer_img';
            } elseif ($this->platform === 'tripadvisor' || $this->platform === 'booking.com') {
                $fieldName = 'reviewer_name';
            } else {
                $fieldName = 'reviewer_url';
            }
            $value = '';
            if ($this->platform === 'zomato') {
                $value = $review['review']['user']['profile_url'];
            } elseif ($this->platform === 'yelp') {
                $value = $review['user']['profile_url'];
            } elseif ($this->platform === 'amazon' || $this->platform === 'trustpilot' || $this->platform === 'aliexpress') {
                $value = $review['reviewer_url'];
            } elseif ($this->platform === 'tripadvisor' || $this->platform === 'booking.com') {
                $value = $review['reviewer_name'];
            } elseif ($this->platform === 'google_my_business') {
                $value = $review['reviewer']['profilePhotoUrl'];
            } elseif ($this->platform === 'facebook') {
                $value = isset($review['reviewer']['id']) ? 'https://facebook.com/' . $review['reviewer']['id'] : $review['open_graph_story']['id'];
            } elseif ($this->platform === 'airbnb') {
                $value = $review['reviewer']['picture_url'];
            }
            // check if a review already exists or not
            $exist = wpSocialReviewsDB()->table('wpsr_reviews')
                ->where('platform_name', $this->platform)
                ->where($fieldName, $value)
                ->first();

            // if exist update that
            if ($exist) {
                wpSocialReviewsDB()->table('wpsr_reviews')
                    ->where('id', $exist->id)
                    ->update($this->formatData($review, $index));
            } else {
                // if not exist insert that
                $newReview = $this->formatData($review, $index);
                wpSocialReviewsDB()->table('wpsr_reviews')
                    ->insert($newReview);
            }
        }
    }

    public function deletePlatformReviews()
    {
        return wpSocialReviewsDB()->table('wpsr_reviews')
            ->where('platform_name', $this->platform)
            ->delete();
    }

    abstract public function formatData($review, $index);

    public function getReviews($limit = false, $offset = false)
    {
        $query = wpSocialReviewsDB()->table('wpsr_reviews')
            ->where('platform_name', $this->platform);
        if ($limit) {
            $query = $query->limit($limit);
        }
        if ($offset) {
            $query = $query->offset($offset);
        }
        return $query->get();
    }

    public function clearReviewCredential()
    {
        $credential_settings = delete_option('social_review_' . $this->platform . '_settings');
        $business_info = delete_option('social_review_' . $this->platform . '_business_info');
        $location_list = delete_option('social_review_' . $this->platform . '_locations_list');

        delete_option($this->platform . '_global_settings');
        delete_option('wpsr_' . $this->platform . '_global_settings');
        delete_option('google_api_settings');
        delete_option('wpsr_google_api_settings');

        delete_option('wpsr-fb-pages-list');

        wpSocialReviewsDB()->table('wpsr_reviews')
            ->where('platform_name', $this->platform)
            ->delete();

        wp_send_json_success([
            'message' => __('Clear Configurations', 'wpsocialreviews'),
            'credentials_settings' => $credential_settings,
            'business_settings' => $business_info,
            'location_list' => $location_list,

        ], 200);

    }

    abstract public function getApiSettings();
}
