<?php

namespace WPSocialReviews\Classes\Reviews;

use WPSocialReviews\Classes\ArrayHelper;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Handle Google Reviews Place Id and Api Key
 * @since 1.0.0
 */
class GoogleMyBusiness extends BaseReview
{
    private $remoteBaseUrl = 'https://mybusiness.googleapis.com/v4/';

    private $optionKey = 'social_review_google_my_business_settings';

    private $redirect = 'urn:ietf:wg:oauth:2.0:oob';
    private $clientId = '1066221839285-ckecknkno31o1ma3ti37lv4fb3vlidhi.apps.googleusercontent.com';
    private $clientSecret = 'mkhMmZ-0T2VEYuwEkfn5umqm';

    public function __construct()
    {
        parent::__construct('google_my_business');
    }

    public function makeRequest($url, $bodyArgs, $type = 'GET', $headers = false)
    {
        if (!$headers) {
            $headers = array(
                'Content-Type' => 'application/http',
                'Content-Transfer-Encoding' => 'binary',
                'MIME-Version' => '1.0',
            );
        }

        $args = [
            'headers' => $headers
        ];
        if ($bodyArgs) {
            $args['body'] = json_encode($bodyArgs);
        }


        $args['method'] = $type;
        $request = wp_remote_request($url, $args);

        if (is_wp_error($request)) {
            $message = $request->get_error_message();
            return new \WP_Error(423, $message);
        }

        $body = json_decode(wp_remote_retrieve_body($request), true);

        if (!empty($body['error'])) {
            $error = 'Unknown Error';
            if (isset($body['error_description'])) {
                $error = $body['error_description'];
            } else if (!empty($body['error']['message'])) {
                $error = $body['error']['message'];
            }
            return new \WP_Error(423, $error);
        }

        return $body;
    }

    public function generateAccessKey($token)
    {
        $body = [
            'code' => $token,
            'grant_type' => 'authorization_code',
            'redirect_uri' => $this->redirect,
            'client_id' => $this->clientId,
            'client_secret' => $this->clientSecret
        ];
        return $this->makeRequest('https://accounts.google.com/o/oauth2/token', $body, 'POST');
    }

    public function getAccessToken()
    {
        $tokens = get_option('google_api_settings', false);
        if (!$tokens) {
            $tokens = get_option('wpsr_google_api_settings', false);
        }
        if (!$tokens) {
            return false;
        }
        if (($tokens['created_at'] + $tokens['expires_in'] - 30) < time()) {
            // It's expired so we have to re-issue again
            $refreshTokens = $this->refreshToken($tokens);
            if (!is_wp_error($refreshTokens)) {
                $tokens['access_token'] = $refreshTokens['access_token'];
                $tokens['expires_in'] = $refreshTokens['expires_in'];
                $tokens['created_at'] = time();
                update_option('wpsr_google_api_settings', $tokens, 'no');
            } else {
                return false;
            }
        }
        return $tokens['access_token'];
    }

    //cron job function
    public function wpsrDoThisCronEvent()
    {
        $settings = get_option($this->optionKey);
        //find api key and place id 
        $apiKey = $this->getAccessToken();
        $this->verifyCredential($apiKey, $settings['place_id']);
    }

    private function refreshToken($tokens)
    {
        $args = [
            'client_id' => $this->clientId,
            'client_secret' => $this->clientSecret,
            'refresh_token' => $tokens['refresh_token'],
            'grant_type' => 'refresh_token'
        ];
        return $this->makeRequest('https://accounts.google.com/o/oauth2/token', $args, 'POST');
    }

    public function handleCredentialSave()
    {
        $apiKey = sanitize_text_field($_REQUEST['api_key']);
        $placeId = sanitize_text_field($_REQUEST['source_id']);
        try {
            $businessInfo = $this->verifyCredential($apiKey, $placeId);
            wp_send_json_success([
                'message' => __('Google Business Reviews successfully saved', 'wpsocialreviews'),
                'business_info' => $businessInfo
            ], 200);
        } catch (\Exception $exception) {
            wp_send_json_error([
                'message' => $exception->getMessage()
            ], 423);
        }
    }

    public function pushValidPlatform($platforms)
    {
        $settings = $this->getApiSettings();
        if ($settings['api_key'] && $settings['place_id']) {
            $platforms['google_my_business'] = __('Google My Business', 'wpsocialreviews');
        }
        return $platforms;
    }

    public function verifyCredential($apiKey, $placeId)
    {
        $data = $this->fetchRemoteReviews($apiKey, $placeId);
        if (is_wp_error($data)) {
            throw new \Exception($data->get_error_message());
        }
        $oldSettings = $this->getApiSettings();
        if ($oldSettings['place_id'] != $placeId) {
            $this->deletePlatformReviews();
        }
        $this->saveApiSettings([
            'api_key' => $apiKey,
            'place_id' => $placeId
        ]);
        $business_info = $this->getBusinessInfo($data);
        update_option('social_review_google_my_business_business_info', $business_info, 'no');
        $this->doCronEvent();
        $this->syncRemoteReviews($data['reviews']);
        return $business_info;
    }

    public function fetchRemoteReviews($apiKey, $placeId)
    {
        $fetchUrl = $this->remoteBaseUrl . $placeId . '/reviews';
        $args = array(
            'headers' => array(
                'Authorization' => 'Bearer ' . $apiKey,
            ),
        );
        $response = wp_remote_get($fetchUrl, $args);
        if (is_wp_error($response)) {
            $response;
        }
        $data = json_decode(wp_remote_retrieve_body($response), true);
//         if (ArrayHelper::get($data, 'reviews') != 'OK') {
//             return new \WP_Error(423, ArrayHelper::get($data, 'error_message', 'Please enter your valid place id'));
//         }
        return $data;
    }

    public function converRating($ratingStrVal)
    {
        if ($ratingStrVal === 'FIVE') {
            return 5;
        } else if ($ratingStrVal === 'FOUR') {
            return 4;
        } else if ($ratingStrVal === 'THREE') {
            return 3;
        } else if ($ratingStrVal === 'TWO') {
            return 2;
        } else if ($ratingStrVal === 'ONE') {
            return 1;
        } else {
            return 0;
        }
    }

    public function placeIdSplit($placeId)
    {
        $place_id = explode('/', $placeId);
        return $place_id[3];
    }

    public function formatData($review, $index)
    {
        $apiSettings = $this->getApiSettings();
        $reviewDate = ArrayHelper::get($review, 'createTime');
        $placeId = $this->placeIdSplit(ArrayHelper::get($apiSettings, 'place_id'));
        $locationId = get_option('google-my-business-location-key');
        return [
            'platform_name' => $this->platform,
            'source_id' => $placeId,
            'reviewer_name' => ArrayHelper::get($review['reviewer'], 'displayName'),
            'review_title' => 'google_' . ($index + 1),
            'reviewer_url' => 'http://search.google.com/local/reviews?placeid=' . $locationId,
            'reviewer_img' => ArrayHelper::get($review['reviewer'], 'profilePhotoUrl'),
            'reviewer_text' => ArrayHelper::get($review, 'comment'),
            'rating' => $this->converRating(ArrayHelper::get($review, 'starRating')),
            'review_time' => date('Y-m-d H:i:s', strtotime($reviewDate)),
            'updated_at' => date('Y-m-d H:i:s'),
            'created_at' => date('Y-m-d H:i:s')
        ];
    }

    public function getBusinessInfo($data = array())
    {
        $info = get_option('social_review_google_my_business_business_info');
        $businessInfo = [
            'name' => '',
            'url' => '',
            'address' => '',
            'average_rating' => '',
            'total_rating' => '',
            'phone' => '',
            'platform_name' => '',
            'status' => false
        ];
        if ($info && is_array($info)) {
            $businessInfo = [

                'name' => ArrayHelper::get($info, 'name'),
                'url' => ArrayHelper::get($info, 'url'),
                'address' => ArrayHelper::get($info, 'address'),
                'average_rating' => ArrayHelper::get($info, 'average_rating'),
                'total_rating' => ArrayHelper::get($info, 'total_rating'),
                'phone' => ArrayHelper::get($info, 'phone'),
                'platform_name' => $this->platform,
                'status' => true
            ];
        } else {

            $settings = $this->getApiSettings();
            $apiKey = $settings['api_key'];
            $placeId = $settings['place_id'];
            $args = array(
                'headers' => array(
                    'Authorization' => 'Bearer ' . $apiKey,
                ),
            );
            $fetchUrl = "https://mybusiness.googleapis.com/v4/" . $placeId;
            $response = wp_remote_get($fetchUrl, $args);
            $locationInfo = json_decode(wp_remote_retrieve_body($response), true);

            if ($locationInfo && isset($locationInfo['locationKey'])) {
                update_option('google-my-business-location-key', $locationInfo['locationKey']['placeId']);
            }

            if (($data && is_array($data)) && (!empty($locationInfo) && is_array($locationInfo))) {
                $businessInfo = [
                    'name' => isset($locationInfo['locationName']) ? $locationInfo['locationName'] : '',
                    'url' => isset($locationInfo['metadata']) ? $locationInfo['metadata']['newReviewUrl'] : '',//$locationInfo['websiteUrl'],
                    'address' => isset($locationInfo['address']) ? $locationInfo['address'] : '',
                    'average_rating' => ArrayHelper::get($data, 'averageRating'),
                    'total_rating' => ArrayHelper::get($data, 'totalReviewCount'),
                    'phone' => isset($locationInfo['primaryPhone']) ? $locationInfo['primaryPhone'] : '',
                    'platform_name' => $this->platform,
                    'status' => true
                ];
            }
        }
        return $businessInfo;
    }

    public function saveApiSettings($settings)
    {
        return update_option($this->optionKey, $settings, 'no');
    }

    public function getApiSettings()
    {
        $settings = get_option($this->optionKey);
        if (!$settings || empty($settings['api_key'])) {
            $settings = [
                'api_key' => '',
                'place_id' => ''
            ];
        }
        return $settings;
    }

    public function getUserData()
    {
        try {

            $accessCode = sanitize_text_field($_REQUEST['verificationData']);

            if (empty($accessCode) || !$accessCode) {

                wp_send_json_error([

                    'message' => __('Access code should not be empty', 'wpsocialreviews')

                ], 423);

            }

            $body = $this->generateAccessKey($accessCode);

            if (is_wp_error($body)) {
                throw new \Exception($body->get_error_message());
            }

            $body['created_at'] = time();
            update_option('wpsr_google_api_settings', $body);

            $accessToken = $body['access_token'];

            $args = array(
                'headers' => array(
                    'Authorization' => 'Bearer ' . $accessToken,
                ),
            );

            //get account
            $fetchUrl = "https://mybusiness.googleapis.com/v4/accounts";
            $response = wp_remote_get($fetchUrl, $args);
            $data = json_decode(wp_remote_retrieve_body($response), true);
            $account = substr($data['accounts'][0]['name'], 9);

            if (!$account || empty($account)) {
                wp_send_json_error([
                    'message' => __('Account not found', 'wpsocialreviews')
                ], 423);
            }

            //get locations
            $fetchUrl = "https://mybusiness.googleapis.com/v4/accounts/" . $account . "/locations";
            $response = wp_remote_get($fetchUrl, $args);
            $data = json_decode(wp_remote_retrieve_body($response), true);
            $locations = $data['locations'];

            if (!$locations || empty($locations)) {
                wp_send_json_error([
                    'message' => __('We didn\'t find any business location from this email address', 'wpsocialreviews')
                ], 423);
            }

            update_option('social_review_google_my_business_locations_list', $locations, 'no');
            $locationsLists = get_option('social_review_google_my_business_locations_list');

            wp_send_json_success(
                [
                    'settings' => 'Successfully added user info',
                    'locations' => $locationsLists,
                    'access_token' => $accessToken
                ]
            );
        } catch (\Exception $exception) {
            wp_send_json_error([
                'message' => $exception->getMessage()
            ], 423);
        }
    }

    public function getAdditionalInfo()
    {
        $locationsLists = get_option('social_review_google_my_business_locations_list');
        return $locationsLists;
    }

    //for save settings like sync,
    public function getAdvanceSettings()
    {
        //if main settings is configured then do advance settings .. check url,api,place id exists
        $apiSettings = get_option($this->optionKey, false);
        $settings = false;
        if ($apiSettings || !empty($apiSettings['api_key'])) {
            $settings = get_option('google_global_settings', false);
            if (!$settings) {
                $settings = get_option('wpsr_google_global_settings', false);
            }
            if (!$settings) {
                $settings = array(
                    'global_settings' => array(
                        'auto_syncing' => 'false',
                        'fetch_review_recurrence' => 'daily'
                    )
                );
            }
        }
        wp_send_json_success([
            'message' => __('Settings Found Successfully', 'wpsocialreviews'),
            'settings' => $settings,
        ], 200);
    }

    public function saveAdvanceSettings()
    {
        $args = wp_unslash($_REQUEST['args']);
        update_option('wpsr_google_global_settings', $args);
        $this->doCronEvent();
        wp_send_json_success([
            'message' => __('Settings Saved Successfully', 'wpsocialreviews'),
        ], 200);
    }

    public function doCronEvent()
    {
        $settings = get_option('google_global_settings', false);
        if (!$settings) {
            $settings = get_option('wpsr_google_global_settings', false);
        }
        if ($settings) {
            //check sync is on or off, if off clear cron event
            $sync = isset($settings['global_settings']['auto_syncing']) ? $settings['global_settings']['auto_syncing'] : 'true';
            $recurrence = isset($settings['global_settings']['fetch_review_recurrence']) ? $settings['global_settings']['fetch_review_recurrence'] : 'daily';

            if ($sync === 'false') {
                // clear cron event
                wp_clear_scheduled_hook('wpsr_daily_event_' . $this->platform);
            } else if ($sync === 'true') {
                //clear the existing cron event
                wp_clear_scheduled_hook('wpsr_daily_event_' . $this->platform);
                wp_schedule_event(time(), $recurrence, 'wpsr_daily_event_' . $this->platform);
            }
        }
    }

}
