<?php
/**
 * WP Social Reviews Template
 *
 * Functions for the templating system.
 *
 * @since  1.0.0
 */

use WPSocialReviews\Classes\Helper;
use WPSocialReviews\Classes\Builder\Render;
use WPSocialReviews\Classes\Feeds\Youtube\YoutubeFeed;

if (!defined('ABSPATH')) {
    exit;
}

/**
 * WP Kses style tag support
 *
 * @see safe_style_css()
 * @since  1.2.2
 */
add_filter('safe_style_css', function ($styles) {
    $styles = array('color', 'text-align');
    return $styles;
}, 10, 1);

/**
 *
 * Render Reviewer Image HTML
 *
 * @param $reviewer_image_meta
 * @param $reviewer_url
 * @param $reviewer_img
 * @since 1.0.0
 *
 **/
if (!function_exists('wpsr_render_reviewer_image_html')) {
    function wpsr_render_reviewer_image_html($reviewer_image_meta, $reviewer_url, $reviewer_img)
    {
        if ($reviewer_image_meta === 'false') {
            return;
        }

        ?>
        <div class="wpsr-reviewer-image">
            <a itemprop="url" href="<?php echo esc_url($reviewer_url); ?>" target="_blank">
                <?php if ($reviewer_img) { ?>
                    <img itemprop="image" src="<?php echo esc_url($reviewer_img); ?>"/>
                <?php } else { ?>
                    <img itemprop="image"
                         src="<?php echo esc_url(WPSOCIALREVIEWS_URL . '/assets/images/template/review-template/placeholder-image.png'); ?>"/>
                <?php } ?>
            </a>
        </div>
        <?php
    }
}


/**
 *
 * Render Reviewer Platform HTML
 *
 * @param $display_platform_icon
 * @param $platform_name
 * @since 1.0.0
 *
 **/
if (!function_exists('wpsr_render_review_platform_html')) {
    function wpsr_render_review_platform_html($display_platform_icon, $platform_name)
    {

        if ($display_platform_icon === 'false' || $platform_name === 'custom' || $platform_name === 'fluent_forms') {
            return;
        }
        ?>
        <div class="wpsr-review-platform">
            <img itemprop="image"
                 src="<?php echo WPSOCIALREVIEWS_URL ?>assets/images/icon/icon-<?php echo esc_html($platform_name); ?>.png"
                 alt="<?php echo esc_attr($platform_name); ?>">
        </div>
        <?php

    }
}

/**
 *
 * Render Reviewer Name HTML
 *
 * @param $display_reviewer_name
 * @param $reviewer_url
 * @param $reviewer_name
 * @since 1.0.0
 *
 **/
if (!function_exists('wpsr_render_reviewer_name_html')) {
    function wpsr_render_reviewer_name_html($display_reviewer_name, $reviewer_url, $reviewer_name)
    {
        if ($display_reviewer_name === 'false') {
            return;
        }
        ?>
        <a itemprop="url" href="<?php echo esc_url($reviewer_url); ?>" target="_blank"><h4
                    itemprop="author"><?php echo esc_html($reviewer_name); ?></h4></a>
        <?php

    }
}

/**
 *
 * Render Reviewer Rating HTML
 *
 * @param $display_reviewer_rating
 * @param $rating_style
 * @param $rating
 * @since 1.0.0
 *
 **/
if (!function_exists('wpsr_render_reviewer_rating_html')) {
    function wpsr_render_reviewer_rating_html($display_reviewer_rating, $rating_style, $rating, $platform_name, $recommendation_type)
    {
        if ($display_reviewer_rating === 'false') {
            return;
        }
        ?>
        <div class="wpsr-rating-wrapper" itemprop="reviewRating" itemscope itemtype="http://schema.org/Rating">

            <?php if ($rating_style === 'default' && $platform_name !== 'facebook' && $platform_name !== 'booking.com') { ?>
                <div class="wpsr-rating"><?php echo Helper::reviewIcon($rating); ?></div>
            <?php } ?>

            <?php if ($rating_style === 'default' && $platform_name === 'booking.com' && $platform_name !== 'facebook') { ?>
                <div class="wpsr-booking-rating-style">
                    <span class="review-badge"><?php echo number_format(floatval($rating), 1); ?></span>
                </div>
            <?php } ?>

            <?php if ($rating_style === 'style1' && $platform_name !== 'facebook') { ?>
                <div class="wpsr-rating-style-1">
                    <?php echo __('Rated', 'wpsocialreviews'); ?>
                    <span itemprop="ratingValue"><?php echo number_format(floatval($rating), 1); ?></span>
                </div>
            <?php } ?>

            <?php if ($rating_style === 'style2' && $platform_name !== 'facebook') { ?>
                <div class="wpsr-rating-style-2">
						<span itemprop="ratingValue"
                              class="wpsr-rating-float"><?php echo number_format(floatval($rating),
                                1); ?></span>
                    <div class="wpsr-rating"><?php echo Helper::reviewIcon($rating); ?></div>
                </div>
            <?php } ?>

            <?php if ($platform_name === 'facebook') { ?>
                <div class="wpsr-recommends">
                    <svg width="18" height="18">
                        <path d="M9 14l-3.293 3.293A1 1 0 0 1 4 16.586V14h-.154c-1.337 0-1.822-.14-2.311-.4A2.726 2.726 0 0 1 .4 12.464c-.261-.488-.4-.973-.4-2.309v-6.31c0-1.336.14-1.821.4-2.31A2.726 2.726 0 0 1 1.536.4c.488-.261.973-.4 2.309-.4h10.31c1.336 0 1.821.14 2.31.4.49.262.873.646 1.134 1.135.262.489.401.974.401 2.31v6.31c0 1.336-.14 1.821-.4 2.31a2.726 2.726 0 0 1-1.135 1.134c-.489.262-.974.401-2.31.401H9zm0-5l1.454.765a.5.5 0 0 0 .726-.527l-.278-1.62 1.177-1.147a.5.5 0 0 0-.277-.853l-1.626-.236-.728-1.474a.5.5 0 0 0-.896 0l-.728 1.474-1.626.236a.5.5 0 0 0-.277.853l1.177 1.147-.278 1.62a.5.5 0 0 0 .726.527L9 9z"></path>
                    </svg>
                    <?php echo $recommendation_type === 'positive' ? '<span>' . __('recommends', 'wpsocialreviws') . '</span>' : '<span>' . __('doesn\'t recommend', 'wpsocialreviws') . '</span>'; ?>
                </div>
            <?php } ?>

        </div>
        <?php

    }
}


/**
 *
 * Render Review Date HTML
 *
 * @param $display_reviewer_name
 * @param $reviewer_url
 * @param $reviewer_name
 * @since 1.0.0
 *
 **/
if (!function_exists('wpsr_render_review_date_html')) {
    function wpsr_render_review_date_html($display_review_date, $review_time)
    {
        if ($display_review_date === 'false') {
            return;
        }
        ?>
        <span class="wpsr-review-date" itemprop="datePublished">
			 <?php $date = new \DateTime($review_time);
             echo $date->format('d-m-Y');
             ?>
        </span>
        <?php

    }
}


/**
 *
 * Render Review Content HTML
 *
 * @param $display_review_text
 * @param $content_length
 * @param $showContentLength
 * @param $reviewer_text
 * @param $reviewer_url
 * @since 1.0.0
 *
 **/
if (!function_exists('wpsr_render_review_content_html')) {
    function wpsr_render_review_content_html($display_review_text, $content_length, $showContentLength, $reviewer_text, $reviewer_url, $source_id)
    {

        if ($display_review_text === 'false' || (strlen($reviewer_text) === 0)) {
            return;
        }

        ?>
        <div class="wpsr-review-content">
            <?php if ($content_length && $showContentLength === 'true') { ?>
                <p class="wpsr_add_read_more wpsr_show_less_content"
                   itemprop="reviewBody"><?php echo esc_html($reviewer_text); ?></p>
            <?php } else { ?>
                <p itemprop="reviewBody"><?php echo esc_html($reviewer_text); ?></p>
            <?php } ?>
        </div>
        <?php

    }
}


/***********************
 * ***********
 * Twitter templates functions
 * **********
 **********************/

/**
 *
 * Render Author Avatar HTML
 *
 * @param $feed
 * @since 1.2.4
 *
 **/
if (!function_exists('wpsr_render_tweet_author_avatar_html')) {

    function wpsr_render_tweet_author_avatar_html($feed = array(), $template_meta = array())
    {

        if (isset($template_meta['advance_settings']) && $template_meta['advance_settings']['avatar_image'] === 'false') {
            return;
        }

        $has_retweet = isset($feed['retweeted_status']) ? 'wpsr-has-retweet' : '';

        $feed = isset($feed['retweeted_status']) ? $feed['retweeted_status'] : $feed;
        ?>
        <div class="wpsr-tweet-author-avatar <?php echo esc_attr($has_retweet); ?>">
            <a target="_blank" href="<?php echo esc_url('https://twitter.com/' . $feed['user']['screen_name']); ?>">
                <img src="<?php echo esc_url($feed['user']['profile_image_url']); ?>"
                     alt="<?php echo esc_attr($feed['user']['name']); ?>">
            </a>
        </div>
        <?php

    }
}


/**
 *
 * Render Tweet Retweeted Status
 *
 * @param $feed
 * @since 1.2.4
 *
 **/

if (!function_exists('wpsr_render_tweet_retweeted_status_html')) {

    function wpsr_render_tweet_retweeted_status_html($feed = array())
    {
        $retweeted_status = isset($feed['retweeted_status']) ? $feed['retweeted_status'] : '';

        if ($retweeted_status) {
            ?>

            <div class="wpsr-retweeted">
                <a target="_blank"
                   href="<?php echo esc_url('https://twitter.com/' . $feed['user']['screen_name'] . '/status/' . $feed['id_str']); ?>">
                    <svg viewBox="0 0 24 24"
                         class="r-1re7ezh r-4qtqp9 r-yyyyoo r-1xvli5t r-dnmrzs r-bnwqim r-1plcrui r-lrvibr r-1xzupcd">
                        <g>
                            <path d="M23.615 15.477c-.47-.47-1.23-.47-1.697 0l-1.326 1.326V7.4c0-2.178-1.772-3.95-3.95-3.95h-5.2c-.663 0-1.2.538-1.2 1.2s.537 1.2 1.2 1.2h5.2c.854 0 1.55.695 1.55 1.55v9.403l-1.326-1.326c-.47-.47-1.23-.47-1.697 0s-.47 1.23 0 1.697l3.374 3.375c.234.233.542.35.85.35s.613-.116.848-.35l3.375-3.376c.467-.47.467-1.23-.002-1.697zM12.562 18.5h-5.2c-.854 0-1.55-.695-1.55-1.55V7.547l1.326 1.326c.234.235.542.352.848.352s.614-.117.85-.352c.468-.47.468-1.23 0-1.697L5.46 3.8c-.47-.468-1.23-.468-1.697 0L.388 7.177c-.47.47-.47 1.23 0 1.697s1.23.47 1.697 0L3.41 7.547v9.403c0 2.178 1.773 3.95 3.95 3.95h5.2c.664 0 1.2-.538 1.2-1.2s-.535-1.2-1.198-1.2z"></path>
                        </g>
                    </svg>
                </a>
                <a target="_blank" href="<?php echo esc_url('https://twitter.com/' . $feed['user']['screen_name']); ?>"
                   class="wpsr-tweet-author-name"><span><?php echo esc_html($feed['user']['screen_name']); ?><?php echo __(' Retweeted', 'wp-blog-designer'); ?></span></a>
            </div>

            <?php
        }
    }
}

/**
 *
 * Render Author Info HTML
 *
 * @param $feed
 * @since 1.2.4
 *
 **/

if (!function_exists('wpsr_render_tweet_author_name_html')) {

    function wpsr_render_tweet_author_name_html($feed = array(), $template_meta = array())
    {
        if (isset($template_meta['advance_settings']) && $template_meta['advance_settings']['author_name'] === 'false') {
            return;
        }
        $feed = isset($feed['retweeted_status']) ? $feed['retweeted_status'] : $feed;
        ?>
        <a target="_blank" href="<?php echo esc_url('https://twitter.com/' . $feed['user']['screen_name']); ?>"
           class="wpsr-tweet-author-name"><span><?php echo esc_html($feed['user']['name']); ?></span></a>
        <?php
    }
}

/**
 *
 * Render Author Verified Icon HTML
 *
 * @param $feed
 * @since 1.2.4
 *
 **/

if (!function_exists('wpsr_render_tweet_author_verified_icon_html')) {

    function wpsr_render_tweet_author_verified_icon_html($feed = array(), $template_meta = array())
    {
        if (isset($template_meta['advance_settings']) && $template_meta['advance_settings']['author_name'] === 'false') {
            return;
        }

        $feed = isset($feed['retweeted_status']) ? $feed['retweeted_status'] : $feed;

        if ($feed['user']['verified']) { ?>
            <span class="wpsr-tweet-author-verified">
                    <svg viewBox="0 0 24 24" aria-label="Verified account">
                        <g><path d="M22.5 12.5c0-1.58-.875-2.95-2.148-3.6.154-.435.238-.905.238-1.4 0-2.21-1.71-3.998-3.818-3.998-.47 0-.92.084-1.336.25C14.818 2.415 13.51 1.5 12 1.5s-2.816.917-3.437 2.25c-.415-.165-.866-.25-1.336-.25-2.11 0-3.818 1.79-3.818 4 0 .494.083.964.237 1.4-1.272.65-2.147 2.018-2.147 3.6 0 1.495.782 2.798 1.942 3.486-.02.17-.032.34-.032.514 0 2.21 1.708 4 3.818 4 .47 0 .92-.086 1.335-.25.62 1.334 1.926 2.25 3.437 2.25 1.512 0 2.818-.916 3.437-2.25.415.163.865.248 1.336.248 2.11 0 3.818-1.79 3.818-4 0-.174-.012-.344-.033-.513 1.158-.687 1.943-1.99 1.943-3.484zm-6.616-3.334l-4.334 6.5c-.145.217-.382.334-.625.334-.143 0-.288-.04-.416-.126l-.115-.094-2.415-2.415c-.293-.293-.293-.768 0-1.06s.768-.294 1.06 0l1.77 1.767 3.825-5.74c.23-.345.696-.436 1.04-.207.346.23.44.696.21 1.04z">
                        </path></g>
                    </svg>
                </span>
            <?php
        }
    }
}

/**
 *
 * Render Author Username HTML
 *
 * @param $feed
 * @since 1.2.4
 *
 **/

if (!function_exists('wpsr_render_tweet_author_username_html')) {

    function wpsr_render_tweet_author_username_html($feed = array(), $template_meta = array())
    {

        if (isset($template_meta['advance_settings']) && $template_meta['advance_settings']['user_name'] === 'false') {
            return;
        }
        $feed = isset($feed['retweeted_status']) ? $feed['retweeted_status'] : $feed;

        ?>
        <a target="_blank" href="<?php echo esc_url('https://twitter.com/' . $feed['user']['screen_name']); ?>"
           class="wpsr-tweet-user-name"> @<?php echo esc_html($feed['user']['screen_name']); ?></a>
        <?php
    }
}

/**
 *
 * Render Tweet time HTML
 *
 * @param $feed
 * @since 1.2.4
 *
 **/

if (!function_exists('wpsr_render_tweet_time_html')) {

    function wpsr_render_tweet_time_html($feed = array(), $template_meta = array())
    {
        if (isset($template_meta['advance_settings']) && $template_meta['advance_settings']['date'] === 'false') {
            return;
        }

        $feed = isset($feed['retweeted_status']) ? $feed['retweeted_status'] : $feed;
        ?>
        <a target="_blank"
           href="<?php echo esc_url('https://twitter.com/' . $feed['user']['screen_name'] . '/status/' . $feed['id_str']); ?>"
           class="wpsr-tweet-time"><?php echo Helper::timeAgo($feed['created_at'], false); ?></a>
        <?php
    }
}

if (!function_exists('wpsr_render_tweet_quoted_status_html')) {

    function wpsr_render_tweet_quoted_status_html($feed = array(), $template_meta = array())
    {

        $permalink = 'https://twitter.com/' . $feed['user']['screen_name'] . '/status/' . $feed['id'];

        ?>
        <div class="wpsr-tweet-quoted-status">
            <a href="<?php echo $permalink; ?>" target="_blank" class="wpsr-tweet-quoted-status-link"></a>

            <div class="wpsr-tweet-author-info">
                <?php
                /**
                 * tweet_author_avatar hook.
                 *
                 * @hooked wpsr_render_tweet_author_avatar_html 10
                 * */
                do_action('wpsocialreviews/tweet_author_avatar', $feed, $template_meta);
                ?>
                <div class="wpsr-tweet-author-links">

                    <?php
                    /**
                     * tweet_author_info hook.
                     *
                     * @hooked wpsr_render_tweet_author_verified_icon_html 10
                     * @hooked wpsr_render_tweet_author_name_html 5
                     * */
                    do_action('wpsocialreviews/tweet_author_info', $feed, $template_meta);
                    ?>
                    <div class="wpsr-tweet-author-username-time">
                        <?php
                        /**
                         * tweet_author_info hook.
                         *
                         * @hooked wpsr_render_tweet_time_html 10
                         * @hooked wpsr_render_tweet_author_username_html 10
                         * */
                        do_action('wpsocialreviews/tweet_author_username', $feed, $template_meta);
                        do_action('wpsocialreviews/tweet_time', $feed, $template_meta);
                        ?>
                    </div>
                </div>
                <!-- end wpsr-tweet-author-links -->

            </div>

            <?php
            /**
             * tweet_content hook.
             *
             * @hooked wpsr_render_tweet_content_html 10
             * */
            do_action('wpsocialreviews/tweet_content', $feed, $template_meta);
            ?>

        </div>

        <?php

    }

}

/**
 *
 * Render Tweet Content HTML
 *
 * @param $feed
 * @since 1.2.4
 *
 **/

if (!function_exists('wpsr_render_tweet_content_html')) {

    function wpsr_render_tweet_content_html($feed = array(), $template_meta = array())
    {

        if (isset($feed['quoted_status']['entities']['media'][0]['type'])) {
            $external_media_type = isset($feed['quoted_status']['entities']['media'][0]['expanded_url']) && $feed['quoted_status']['entities']['media'][0]['expanded_url'] === 'video' ? $feed['quoted_status']['entities']['media'][0]['expanded_url'] : '';
        } else if (isset($feed['retweeted_status']['entities']['urls'][0]['expanded_url'])) {
            $external_media_type = isset($feed['retweeted_status']['entities']['urls'][0]['expanded_url']) ? $feed['retweeted_status']['entities']['urls'][0]['expanded_url'] : '';
        } else {
            $external_media_type = isset($feed['entities']['urls'][0]['expanded_url']) ? $feed['entities']['urls'][0]['expanded_url'] : '';
        }

        $default_media_type = isset($feed['extended_entities']['media'][0]['type']) ? $feed['extended_entities']['media'][0]['type'] : '';
        $retweeted_media_type = isset($feed['retweeted_status']['extended_entities']['media'][0]['type']) ? $feed['retweeted_status']['extended_entities']['media'][0]['type'] : '';
        $quoted_media_type = isset($feed['quoted_status']['extended_entities']['media'][0]['type']) ? $feed['quoted_status']['extended_entities']['media'][0]['type'] : '';
        $retweeted_quoted_media_type = isset($feed['retweeted_status']['quoted_status']['extended_entities']['media'][0]['type']) ? $feed['retweeted_status']['quoted_status']['extended_entities']['media'][0]['type'] : '';

        $youtu = strpos($external_media_type, 'youtu.be');
        $youtube = strpos($external_media_type, 'youtube.com/watch');
        $youtube_embed = strpos($external_media_type, 'youtube.com/embed');
        $vimeo = strpos($external_media_type, 'vimeo');
        $soundcloud = strpos($external_media_type, 'soundcloud.com');
        $spotify = strpos($external_media_type, 'open.spotify.com');

        $classes = array();
        $classes[] = $external_media_type === 'video' || $default_media_type === 'video' || $retweeted_media_type === 'video' || $quoted_media_type === 'video' || $retweeted_quoted_media_type === 'video' ? 'wpsr-feed-video' : '';
        $classes[] = $external_media_type === 'photo' || $default_media_type === 'photo' || $retweeted_media_type === 'photo' || $quoted_media_type === 'photo' || $retweeted_quoted_media_type === 'photo' ? 'wpsr-feed-photo' : '';
        $classes[] = ($external_media_type === 'animated_gif' || $default_media_type === 'animated_gif' || $retweeted_media_type === 'animated_gif' || $quoted_media_type === 'animated_gif' || $retweeted_quoted_media_type === 'animated_gif') && $template_meta['advance_settings']['show_tweet_gif'] === 'true' ? 'wpsr-feed-gif' : '';
        $classes[] = $youtu > 0 || $youtube > 0 || $youtube_embed > 0 || $vimeo > 0 || $soundcloud > 0 || $spotify > 0 ? 'wpsr-feed-iframe' : '';


        $twitter_card_data_att = '';

        if (isset($template_meta['advance_settings']) && (($template_meta['advance_settings']['show_twitter_card'] === 'true'))) {
            $twitter_card_url = '';

            if (isset($feed['entities']['urls'][0]['expanded_url']) && ($default_media_type !== 'video' && $retweeted_media_type !== 'video' && $quoted_media_type !== 'video')) {
                $twitter_card_url = $feed['entities']['urls'][0]['expanded_url'];
                $ssl_only = str_replace('http:', 'https:', $twitter_card_url);

                if (strpos($ssl_only, "https://bit.ly") === false) {
                    $url = str_replace('&', '038', $twitter_card_url);
                    $twitter_card_data_att = 'data-cardurl="' . esc_url_raw($url) . '" data-id="' . $feed['id'] . '"';
                    $classes[] = 'wpsr-has-card-url';
                    $classes[] = $template_meta['advance_settings']['show_card_for_third_party_url'] === 'true' ? 'wpsr-active-video-card' : '';
                }

            }

            if (isset($feed['retweeted_status']['entities']['urls'][0]['expanded_url']) && ($default_media_type !== 'video' && $retweeted_media_type !== 'video' && $quoted_media_type !== 'video')) {
                $twitter_card_url = $feed['retweeted_status']['entities']['urls'][0]['expanded_url'];
                $ssl_only = str_replace('http:', 'https:', $twitter_card_url);

                if (strpos($ssl_only, "https://bit.ly") === false) {
                    $url = str_replace('&', '038', $twitter_card_url);
                    $twitter_card_data_att = 'data-cardurl="' . esc_url_raw($url) . '" data-id="' . $feed['id'] . '"';
                    $classes[] = 'wpsr-has-card-url';
                    $classes[] = $template_meta['advance_settings']['show_card_for_third_party_url'] === 'true' ? 'wpsr-active-video-card' : '';
                }
            }

        }
        ?>
        <div class='wpsr-tweet-content <?php echo implode(' ', $classes); ?>' <?php echo $twitter_card_data_att; ?>>
            <?php if (isset($template_meta['advance_settings']) && $template_meta['advance_settings']['tweet_text'] === 'true') { ?>
                <p class="wpsr-tweet-text"><?php echo Helper::replaceTweetUrls($feed); ?></p>
            <?php } ?>
            <?php

            if (isset($feed['quoted_status'])) {

                /**
                 * tweet_quoted_status hook.
                 *
                 * @hooked wpsr_render_tweet_quoted_status_html 10
                 * */
                do_action('wpsocialreviews/tweet_quoted_status', $feed['quoted_status'], $template_meta);
            }

            if (isset($feed['retweeted_status']['quoted_status'])) {

                /**
                 * tweet_quoted_status hook.
                 *
                 * @hooked wpsr_render_tweet_quoted_status_html 10
                 * */
                do_action('wpsocialreviews/tweet_quoted_status', $feed['retweeted_status']['quoted_status'], $template_meta);
            }

            if (!isset($feed['quoted_status'])) {
                if (
                    $external_media_type === 'video' ||
                    $external_media_type === 'animated_gif' ||
                    $default_media_type === 'video' ||
                    $default_media_type === 'animated_gif' ||
                    $retweeted_media_type === 'video' ||
                    $retweeted_media_type === 'animated_gif' ||
                    $quoted_media_type === 'video' ||
                    $quoted_media_type === 'animated_gif' ||
                    $youtu > 0 ||
                    $youtube > 0 ||
                    $youtube_embed > 0 ||
                    $vimeo > 0 ||
                    $soundcloud > 0 ||
                    $spotify > 0
                ) {
                    /**
                     * tweet_video hook.
                     *
                     * @hooked wpsr_render_tweet_video_html 10
                     * */
                    do_action('wpsocialreviews/tweet_video', $feed, $template_meta);
                } else {

                    /**
                     * tweet_image hook.
                     *
                     * @hooked wpsr_render_tweet_image_html 10
                     * */
                    do_action('wpsocialreviews/tweet_image', $feed, $template_meta);

                }
            }
            ?>

        </div>
        <?php
    }
}

/**
 *
 * Render Tweet Media HTML
 *
 * @param $feed
 * @since 1.2.4
 *
 **/

if (!function_exists('wpsr_render_tweet_image_html')) {

    function wpsr_render_tweet_image_html($feed = array(), $template_meta = array())
    {

        $advanced_settings = isset($template_meta['advance_settings']) ? $template_meta['advance_settings'] : '';
        $show_image_video_popup = isset($advanced_settings['show_image_video_popup']) ? $advanced_settings['show_image_video_popup'] : '';

        if (isset($advanced_settings['show_tweet_image']) && $advanced_settings['show_tweet_image'] === 'false') {
            return;
        }

        $permalink = 'https://twitter.com/' . $feed['user']['screen_name'] . '/status/' . $feed['id'];
        $media_type = isset($feed['extended_entities']['media'][0]['type']) ? $feed['extended_entities']['media'][0]['type'] : '';

        if (!empty($feed['entities']['media'][0]['media_url_https']) && $media_type !== 'video') {
            $media_url = $feed['entities']['media'][0]['media_url_https'];
        } elseif (!empty($feed['retweeted_status']['entities']['media'][0]['media_url_https'])) {
            $media_url = $feed['retweeted_status']['entities']['media'][0]['media_url_https'];
        } elseif (!empty($feed['quoted_status']['entities']['media'][0]['media_url_https'])) {
            $media_url = $feed['quoted_status']['entities']['media'][0]['media_url_https'];
        } else {
            $media_url = '';
        }

        if (!empty($media_url) && !isset($feed['retweeted_status']['entities']['urls'][0]['expanded_url'])) {
            ?>
            <div class="wpsr-tweet-media">
                <?php if ($show_image_video_popup === 'true') { ?>
                <a href="<?php echo esc_url($media_url) ?>" target="_blank" rel="nofollow" class="wpsr-twitter-venobox">
                    <?php } else { ?>
                    <a href="<?php echo esc_url($permalink) ?>" target="_blank" rel="nofollow">
                        <?php } ?>
                        <img src="<?php echo esc_url($media_url) ?>" alt="Image">
                    </a>
            </div>
            <?php
        }
    }
}

/**
 *
 * Render Tweet Video HTML
 *
 * @param $feed
 * @since 1.2.4
 *
 **/

if (!function_exists('wpsr_render_tweet_video_html')) {

    function wpsr_render_tweet_video_html($feed = array(), $template_meta = array())
    {

        $advanced_settings = isset($template_meta['advance_settings']) ? $template_meta['advance_settings'] : '';

        $show_image_video_popup = isset($advanced_settings['show_image_video_popup']) ? $advanced_settings['show_image_video_popup'] : '';
        $show_tweet_video = isset($advanced_settings['show_tweet_video']) ? $advanced_settings['show_tweet_video'] : '';

        if (isset($feed['extended_entities']['media'][0]['media_url_https'])) {
            $preview_image = $feed['extended_entities']['media'][0]['media_url_https'];
        } elseif (isset($feed['quoted_status']['extended_entities']['media'][0]['media_url_https'])) {
            $preview_image = $feed['quoted_status']['extended_entities']['media'][0]['media_url_https'];
        } elseif (isset($feed['retweeted_status']['extended_entities']['media'][0]['media_url_https'])) {
            $preview_image = $feed['retweeted_status']['extended_entities']['media'][0]['media_url_https'];
        } else {
            $preview_image = '';
        }

        if (isset($feed['retweeted_status']['entities']['urls'][0]['expanded_url'])) {
            $expanded_url = isset($feed['retweeted_status']['entities']['urls'][0]['expanded_url']) ? $feed['retweeted_status']['entities']['urls'][0]['expanded_url'] : '';
        } else {
            $expanded_url = isset($feed['entities']['urls'][0]['expanded_url']) ? $feed['entities']['urls'][0]['expanded_url'] : '';
        }

        $youtu = strpos($expanded_url, 'youtu.be');
        $youtube = strpos($expanded_url, 'youtube.com/watch');
        $youtube_embed = strpos($expanded_url, 'youtube.com/embed');
        $vimeo = strpos($expanded_url, 'vimeo');
        $soundcloud = strpos($expanded_url, 'soundcloud.com');
        $spotify = strpos($expanded_url, 'open.spotify.com');

        $default_media_type = isset($feed['extended_entities']['media'][0]['type']) ? $feed['extended_entities']['media'][0]['type'] : '';
        $retweeted_media_type = isset($feed['retweeted_status']['extended_entities']['media'][0]['type']) ? $feed['retweeted_status']['extended_entities']['media'][0]['type'] : '';
        $quoted_media_type = isset($feed['quoted_status']['extended_entities']['media'][0]['type']) ? $feed['quoted_status']['extended_entities']['media'][0]['type'] : '';

        if ((isset($template_meta['advance_settings']) && $template_meta['advance_settings']['show_card_for_third_party_url'] === 'true') && ($youtu > 0 || $youtube > 0 || $youtube_embed > 0 || $vimeo > 0 || $soundcloud > 0)) {
            return;
        }

        if (($youtu > 0 || $youtube > 0 || $youtube_embed > 0) && $show_tweet_video === 'true') {

            $pattern = '#^(?:https?://)?(?:www\.)?(?:youtu\.be/|youtube\.com(?:/embed/|/v/|/watch\?v=|/watch\?.+&v=))([\w-]{11})(?:.+)?$#x';
            preg_match($pattern, $expanded_url, $matches);

            $video_id = $matches[1];

            $iframe_video_url = 'https://www.youtube.com/embed/' . $video_id . '?autoplay=0';


            if (isset($iframe_video_url)) { ?>
                <div class="wpsr-tweet-media">
                <?php if ($show_image_video_popup === 'true') { ?>
                <a href="<?php echo esc_url($iframe_video_url) ?>" class="wpsr-tweet-video-frame wpsr-twitter-venobox"
                   data-autoplay="true" data-vbtype="iframe">
                <svg viewBox="0 0 24 24">
                    <g>
                        <circle cx="12" cy="12" r="10"></circle>
                        <path d="M16.036 11.58l-6-3.82a.5.5 0 0 0-.77.42v7.64a.498.498 0 0 0 .77.419l6-3.817c.145-.092.23-.25.23-.422s-.085-.33-.23-.42z"></path>
                        <path d="M12 22.75C6.072 22.75 1.25 17.928 1.25 12S6.072 1.25 12 1.25 22.75 6.072 22.75 12 17.928 22.75 12 22.75zm0-20C6.9 2.75 2.75 6.9 2.75 12S6.9 21.25 12 21.25s9.25-4.15 9.25-9.25S17.1 2.75 12 2.75z"></path>
                    </g>
                </svg>
                <?php } else { ?>
                <div class="wpsr-tweet-video-frame">
            <?php } ?>
                <iframe type="text/html" src="<?php echo esc_url($iframe_video_url); ?>" frameborder="0"
                        ebkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>
                <?php if ($show_image_video_popup === 'true') { ?>
                    </a>
                <?php } else { ?>
                    </div>
                <?php } ?>

                </div>
            <?php }

            //  echo '<div class="wpsr-tweet-video-frame"><iframe type="text/html" src="https://www.youtube.com/embed/' . $video_id . '?autoplay=0" frameborder="0" allowfullscreen></iframe></div>';

        } elseif (($vimeo > 0) && $show_tweet_video === 'true') {
            if (strpos($expanded_url, 'staffpicks') > 0) {
                $parsed_url = $expanded_url;
                $parsed_url = parse_url($parsed_url);
                $video_id = preg_replace('/\D/', '', $parsed_url['path']);
            } else {
                $video_id = (int)substr(parse_url($expanded_url, PHP_URL_PATH), 1);
            }
            $iframe_video_url = 'https://player.vimeo.com/video/' . $video_id . '?autoplay=0';

            if (isset($iframe_video_url)) { ?>
                <div class="wpsr-tweet-media">
                <?php if ($show_image_video_popup === 'true') { ?>
                <a href="<?php echo esc_url($iframe_video_url) ?>" class="wpsr-tweet-video-frame wpsr-twitter-venobox"
                   data-autoplay="true" data-vbtype="iframe">
                <svg viewBox="0 0 24 24">
                    <g>
                        <circle cx="12" cy="12" r="10"></circle>
                        <path d="M16.036 11.58l-6-3.82a.5.5 0 0 0-.77.42v7.64a.498.498 0 0 0 .77.419l6-3.817c.145-.092.23-.25.23-.422s-.085-.33-.23-.42z"></path>
                        <path d="M12 22.75C6.072 22.75 1.25 17.928 1.25 12S6.072 1.25 12 1.25 22.75 6.072 22.75 12 17.928 22.75 12 22.75zm0-20C6.9 2.75 2.75 6.9 2.75 12S6.9 21.25 12 21.25s9.25-4.15 9.25-9.25S17.1 2.75 12 2.75z"></path>
                    </g>
                </svg>
                <?php } else { ?>
                <div class="wpsr-tweet-video-frame">
            <?php } ?>
                <iframe type="text/html" src="<?php echo esc_url($iframe_video_url); ?>" frameborder="0"
                        ebkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>
                <?php if ($show_image_video_popup === 'true') { ?>
                    </a>
                <?php } else { ?>
                    </div>
                <?php } ?>

                </div>
            <?php }
            //echo '<div class="wpsr-tweet-video-frame"><iframe type="text/html" src="https://player.vimeo.com/video/' . $video_id . '?autoplay=0" frameborder="0" ebkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe></div>';
        } elseif ($soundcloud > 0) {
            $soundcloud_url = explode("?", $expanded_url);

            $iframe_src = 'https://w.soundcloud.com/player/?url=' . $soundcloud_url[0] . '&amp;auto_play=false&amp;hide_related=true&amp;show_comments=false&amp;show_user=true&amp;show_reposts=false&amp;visual=false';

            echo '<div class="wpsr-tweet-mp3-frame"><iframe src="' . esc_url($iframe_src) . '" type="text/html"  frameborder="0" width="100%" webkitAllowFullScreen mozallowfullscreen allowfullscreen></iframe></div>';
        } else {

            $extended_entities_variants = isset($feed['extended_entities']['media'][0]['video_info']['variants']) ? $feed['extended_entities']['media'][0]['video_info']['variants'] : '';
            $retweeted_status_variants = isset($feed['retweeted_status']['extended_entities']['media'][0]['video_info']['variants']) ? $feed['retweeted_status']['extended_entities']['media'][0]['video_info']['variants'] : '';
            $quoted_status_variants = isset($feed['quoted_status']['extended_entities']['media'][0]['video_info']['variants']) ? $feed['quoted_status']['extended_entities']['media'][0]['video_info']['variants'] : '';


            if (!empty($extended_entities_variants)) {
                $video_url = Helper::get_twitter_high_quality_video($extended_entities_variants);
            } else if (!empty($retweeted_status_variants)) {
                $video_url = Helper::get_twitter_high_quality_video($retweeted_status_variants);
            } else if (!empty($quoted_status_variants)) {
                $video_url = Helper::get_twitter_high_quality_video($quoted_status_variants);
            }
            ?>


            <?php if (isset($video_url)) { ?>
                <div class="wpsr-tweet-media">

                    <?php if ((($default_media_type === 'animated_gif' || $retweeted_media_type === 'animated_gif' || $quoted_media_type === 'animated_gif')) && ($advanced_settings['show_tweet_gif'] === 'true')) { ?>
                        <?php if ($show_image_video_popup === 'true') { ?>
                            <a href="<?php echo esc_url($video_url) ?>" class="wpsr-twitter-venobox" data-autoplay="true" data-vbtype="iframe">
                        <?php } ?>
                        <video loop muted="muted" autoplay="" poster="<?php echo $preview_image; ?>" width="100%;">
                            <source src="<?php echo $video_url; ?>" type="video/mp4">
                        </video>
                        <?php if ($show_image_video_popup === 'true') { ?>
                            </a>
                        <?php } ?>
                    <?php } else { ?>

                        <?php if ((($default_media_type === 'video' || $retweeted_media_type === 'video' || $quoted_media_type === 'video')) && $show_tweet_video === 'true') { ?>

                            <?php if ($show_image_video_popup === 'true') { ?>
                                <a href="<?php echo esc_url($video_url); ?>" class="wpsr-twitter-venobox"
                                   data-autoplay="true" data-vbtype="iframe">
                                    <img src="<?php echo esc_url($preview_image); ?>" alt="">
                                    <svg viewBox="0 0 24 24">
                                        <g>
                                            <circle cx="12" cy="12" r="10"></circle>
                                            <path d="M16.036 11.58l-6-3.82a.5.5 0 0 0-.77.42v7.64a.498.498 0 0 0 .77.419l6-3.817c.145-.092.23-.25.23-.422s-.085-.33-.23-.42z"></path>
                                            <path d="M12 22.75C6.072 22.75 1.25 17.928 1.25 12S6.072 1.25 12 1.25 22.75 6.072 22.75 12 17.928 22.75 12 22.75zm0-20C6.9 2.75 2.75 6.9 2.75 12S6.9 21.25 12 21.25s9.25-4.15 9.25-9.25S17.1 2.75 12 2.75z"></path>
                                        </g>
                                    </svg>
                                </a>
                            <?php } else { ?>
                                <video playsinline controls poster="<?php echo esc_url($preview_image); ?>"
                                       width="100%;">
                                    <source src="<?php echo esc_url($video_url); ?>" type="video/mp4">
                                </video>
                            <?php } ?>

                        <?php }
                    } ?>

                </div>
                <?php
            }
        }
    }
}

/**
 *
 * Render Tweet Action Reply HTML
 *
 * @param $feed
 * @since 1.2.4
 *
 **/

if (!function_exists('wpsr_render_tweet_action_reply')) {

    function wpsr_render_tweet_action_reply($feed = array(), $template_meta = array())
    {

        if (isset($template_meta['advance_settings']) && $template_meta['advance_settings']['show_reply_action'] === 'false') {
            return;
        }
        $feed = isset($feed['retweeted_status']) ? $feed['retweeted_status'] : $feed;
        ?>
        <a target="_blank"
           href="<?php echo esc_url('https://twitter.com/intent/tweet?in_reply_to=' . $feed['id_str'] . '&related=' . $feed['user']['screen_name']); ?>"
           class="wpsr-tweet-reply">
            <svg viewBox="0 0 24 24">
                <g>
                    <path d="M14.046 2.242l-4.148-.01h-.002c-4.374 0-7.8 3.427-7.8 7.802 0 4.098 3.186 7.206 7.465 7.37v3.828c0 .108.044.286.12.403.142.225.384.347.632.347.138 0 .277-.038.402-.118.264-.168 6.473-4.14 8.088-5.506 1.902-1.61 3.04-3.97 3.043-6.312v-.017c-.006-4.367-3.43-7.787-7.8-7.788zm3.787 12.972c-1.134.96-4.862 3.405-6.772 4.643V16.67c0-.414-.335-.75-.75-.75h-.396c-3.66 0-6.318-2.476-6.318-5.886 0-3.534 2.768-6.302 6.3-6.302l4.147.01h.002c3.532 0 6.3 2.766 6.302 6.296-.003 1.91-.942 3.844-2.514 5.176z"></path>
                </g>
            </svg>
        </a>
        <?php
    }
}

/**
 *
 * Render Tweet Action Retweet Count HTML
 *
 * @param $feed
 * @since 1.2.4
 *
 **/

if (!function_exists('wpsr_render_tweet_action_retweet_count')) {

    function wpsr_render_tweet_action_retweet_count($feed = array(), $template_meta = array())
    {
        if (isset($template_meta['advance_settings']) && $template_meta['advance_settings']['show_retweet_action'] === 'false') {
            return;
        }
        $feed = isset($feed['retweeted_status']) ? $feed['retweeted_status'] : $feed;
        ?>
        <a target="_blank"
           href="<?php echo esc_url('https://twitter.com/intent/retweet?tweet_id=' . $feed['id_str'] . '&related=' . $feed['user']['screen_name']); ?>"
           class="wpsr-tweet-retweet">
            <svg viewBox="0 0 24 24">
                <g>
                    <path
                            d="M23.77 15.67c-.292-.293-.767-.293-1.06 0l-2.22 2.22V7.65c0-2.068-1.683-3.75-3.75-3.75h-5.85c-.414 0-.75.336-.75.75s.336.75.75.75h5.85c1.24 0 2.25 1.01 2.25 2.25v10.24l-2.22-2.22c-.293-.293-.768-.293-1.06 0s-.294.768 0 1.06l3.5 3.5c.145.147.337.22.53.22s.383-.072.53-.22l3.5-3.5c.294-.292.294-.767 0-1.06zm-10.66 3.28H7.26c-1.24 0-2.25-1.01-2.25-2.25V6.46l2.22 2.22c.148.147.34.22.532.22s.384-.073.53-.22c.293-.293.293-.768 0-1.06l-3.5-3.5c-.293-.294-.768-.294-1.06 0l-3.5 3.5c-.294.292-.294.767 0 1.06s.767.293 1.06 0l2.22-2.22V16.7c0 2.068 1.683 3.75 3.75 3.75h5.85c.414 0 .75-.336.75-.75s-.337-.75-.75-.75z"></path>
                </g>
            </svg>
            <span><?php echo esc_html(Helper::shortNumberFormat($feed['retweet_count'])); ?></span>
        </a>
        <?php
    }
}

/**
 *
 * Render Tweet Action Favorite Count HTML
 *
 * @param $feed
 * @since 1.2.4
 *
 **/

if (!function_exists('wpsr_render_tweet_action_favorite_count')) {

    function wpsr_render_tweet_action_favorite_count($feed = array(), $template_meta = array())
    {

        if (isset($template_meta['advance_settings']) && $template_meta['advance_settings']['show_like_action'] === 'false') {
            return;
        }

        $feed = isset($feed['retweeted_status']) ? $feed['retweeted_status'] : $feed;
        ?>

        <a target="_blank"
           href="<?php echo esc_url('https://twitter.com/intent/like?tweet_id=' . $feed['id_str'] . '&related=' . $feed['user']['screen_name']); ?>"
           class="wpsr-tweet-like">
            <svg viewBox="0 0 24 24">
                <g>
                    <path
                            d="M12 21.638h-.014C9.403 21.59 1.95 14.856 1.95 8.478c0-3.064 2.525-5.754 5.403-5.754 2.29 0 3.83 1.58 4.646 2.73.814-1.148 2.354-2.73 4.645-2.73 2.88 0 5.404 2.69 5.404 5.755 0 6.376-7.454 13.11-10.037 13.157H12zM7.354 4.225c-2.08 0-3.903 1.988-3.903 4.255 0 5.74 7.034 11.596 8.55 11.658 1.518-.062 8.55-5.917 8.55-11.658 0-2.267-1.823-4.255-3.903-4.255-2.528 0-3.94 2.936-3.952 2.965-.23.562-1.156.562-1.387 0-.014-.03-1.425-2.965-3.954-2.965z"></path>
                </g>
            </svg>

            <span><?php echo esc_html(Helper::shortNumberFormat($feed['favorite_count'])); ?></span>

        </a>

        <?php
    }
}

/**
 *
 * Render YouTube Feed Video Preview Image HTML
 *
 * @param $feed
 * @param $template_meta
 * @param $index
 * @since 1.2.5
 *
 **/
if (!function_exists('wpsr_render_youtube_feed_preview_image_html')) {
    function wpsr_render_youtube_feed_preview_image_html($feed = array(), $template_meta = array(), $index, $templateId, $feed_info = array())
    {

        $videoId = isset($feed['snippet']['resourceId']['videoId']) ? $feed['snippet']['resourceId']['videoId'] : $feed['id'];
        //$feed['video_statistics']['items'][0]['id']
//        var_dump($videoId);
//        die();
        ?>
        <div>
            <span class="wpsr-yt-video-player" id="<?php echo esc_attr('wpsr-video-play-' . $index); ?>"></span>

            <a data-videoid="<?php echo esc_attr($videoId); ?>" data-index="<?php echo esc_attr($index); ?>"
               data-playmode="<?php echo isset($template_meta['video_settings']['play_mode']) ? esc_attr($template_meta['video_settings']['play_mode']) : 'inline'; ?>"
               data-template-id="<?php echo esc_attr($templateId); ?>"
               class="wpsr-yt-video-preview wpsr-yt-video-playmode"
               title="<?php echo esc_attr($feed['snippet']['title']); ?>">

                <img src="<?php echo esc_url($feed['snippet']['thumbnails']['high']['url']); ?>"
                     alt="<?php echo esc_attr($feed['snippet']['title']); ?>">

                <?php if (isset($template_meta['video_settings']['display_play_icon']) && $template_meta['video_settings']['display_play_icon'] === 'true') { ?>
                    <svg class="wpsr-yt-play-icon" viewBox="0 0 68 48">
                        <g fill-rule="evenodd">
                            <path class="wpsr-yt-play-icon-color-1"
                                  d="M31.386 0h5.873c2.423.06 4.849.08 7.273.153 3.306.094 6.614.219 9.914.46 1.23.092 2.46.2 3.684.35.936.121 1.875.253 2.79.491a8.56 8.56 0 0 1 4.23 2.623 8.597 8.597 0 0 1 1.9 3.66c.52 2.09.755 4.24.95 6.382v19.415c-.193 2.209-.424 4.424-.932 6.586a8.575 8.575 0 0 1-6.352 6.415c-.918.211-1.854.334-2.788.445-2.585.29-5.185.436-7.782.56a367.25 367.25 0 0 1-11.351.307c-.449.014-.9-.017-1.345.036h-4.26c-5.366-.045-10.733-.139-16.094-.417-2.57-.145-5.145-.305-7.696-.666-.912-.138-1.83-.294-2.697-.616a8.596 8.596 0 0 1-4.698-4.222c-.388-.764-.628-1.592-.802-2.428-.423-2.006-.64-4.047-.813-6.087-.242-2.984-.348-5.978-.39-8.971v-1.06c.037-2.699.129-5.397.323-8.09.17-2.245.386-4.493.825-6.704.138-.67.289-1.342.54-1.98.92-2.382 2.935-4.322 5.365-5.117.517-.172 1.052-.275 1.588-.368C9.988.93 11.348.802 12.708.684 14.985.5 17.267.382 19.55.29c2.926-.116 5.854-.187 8.782-.233C29.349.03 30.369.042 31.386 0"></path>
                            <path class="wpsr-yt-play-icon-color-2" fill="#fff"
                                  d="M27.381 13.692c5.937 3.412 11.869 6.832 17.802 10.25-5.934 3.416-11.865 6.837-17.802 10.25-.002-6.834-.002-13.667 0-20.5z">
                            </path>
                        </g>
                    </svg>
                <?php } ?>

                <?php if (isset($template_meta['video_settings']['display_duration']) && $template_meta['video_settings']['display_duration'] === 'true') { ?>
                    <?php if (isset($feed_info['event_type']) && $feed_info['event_type'] === 'upcoming') {
                        ?>
                        <span class="wpsr-yt-video-duration"><?php echo __('LIVE', 'wpsocialreviews'); ?></span>
                    <?php } ?>
                    <?php if (isset($feed_info['event_type']) && $feed_info['event_type'] !== 'live' && $feed_info['event_type'] !== 'upcoming' && isset($feed['contentDetails']['duration'])) { ?>
                        <span class="wpsr-yt-video-duration">
                        <?php echo Helper::getVideoDuration($feed['contentDetails']['duration']); ?>
                    </span>
                    <?php } ?>
                <?php } ?>

            </a>
        </div>
        <?php
    }
}

/**
 *
 * Render YouTube Feed Title HTML
 *
 * @param $feed
 * @param $template_meta
 * @since 1.2.5
 *
 **/
if (!function_exists('wpsr_render_youtube_feed_title_html')) {
    function wpsr_render_youtube_feed_title_html($feed = array(), $template_meta = array(), $index, $templateId)
    {

        if (isset($template_meta['video_settings']['display_title']) && $template_meta['video_settings']['display_title'] === 'false') {
            return;
        }

        $trim_title_words = isset($template_meta['video_settings']['trim_title_words']) && $template_meta['video_settings']['trim_title_words'] > 0 ? $template_meta['video_settings']['trim_title_words'] : null;

        $videoId = isset($feed['snippet']['resourceId']) && isset($feed['snippet']['resourceId']['videoId']) ? $feed['snippet']['resourceId']['videoId'] : $feed['id'];

        ?>
        <h3>
            <a class="wpsr-yt-video-playmode" data-videoid="<?php echo esc_attr($videoId); ?>"
               data-index="<?php echo esc_attr($index); ?>"
               data-playmode="<?php echo isset($template_meta['video_settings']['play_mode']) ? esc_attr($template_meta['video_settings']['play_mode']) : 'inline'; ?>"
               data-template-id="<?php echo esc_attr($templateId); ?>" target="_blank">
                <?php
                if ($trim_title_words) {
                    echo wp_trim_words($feed['snippet']['title'], $trim_title_words, '...');
                } else {
                    echo esc_html($feed['snippet']['title']);
                }
                ?>
            </a>
        </h3>


        <?php
    }
}

if (!function_exists('wpsr_youtube_popup_feed')) {
    function wpsr_youtube_popup_feed()
    {

        check_ajax_referer('wpsr-ajax-nonce', 'security');

        $feedId = intval($_POST['feedId']);
        $templateId = intval($_POST['templateId']);

        $youtube_feed_template_meta = get_post_meta($templateId, '_wpsr_youtube_template_config', true);

        $youtube_feed = new YoutubeFeed();

        $apiSettings = isset($youtube_feed_template_meta['feed_settings']['source_settings']) ? $youtube_feed_template_meta['feed_settings']['source_settings'] : array();

        $response = $youtube_feed->apiConnection($apiSettings, $templateId);

        $configs = isset($youtube_feed_template_meta['feed_settings']) ? $youtube_feed_template_meta['feed_settings'] : array();

        $formatted_youtube_feed_template_meta = $youtube_feed->formatYoutubeConfig($configs, $response);

        $feeds = isset($formatted_youtube_feed_template_meta['dynamic']['items']) ? $formatted_youtube_feed_template_meta['dynamic']['items'] : array();
        $header = isset($formatted_youtube_feed_template_meta['dynamic']['channel_info']) ? $formatted_youtube_feed_template_meta['dynamic']['channel_info'] : array();

        $html = '';

        $html .= Render::loadView('feed-templates/youtube/popup', array(
            'header' => $header,
            'feed' => $feeds[$feedId],
            'template_meta' => $formatted_youtube_feed_template_meta['feed_settings'],
        ));

        echo $html;

        die();
    }
}

/**
 *
 * Render YouTube Channel Banner HTML
 *
 * @param $header
 * @param $template_header_meta
 * @since 1.2.5
 *
 **/
function wpsr_render_youtube_channel_banner_html($header = array(), $template_header_meta = array())
{
    if (isset($template_header_meta['display_banner']) && $template_header_meta['display_banner'] === 'false') {
        return;
    }

    if (isset($header['items'][0]['brandingSettings']['image']['bannerTabletImageUrl'])) {
        ?>
        <div class="wpsr-yt-header-banner">
            <img class="wpsr-yt-header-banner-desktop"
                 src="<?php echo esc_url($header['items'][0]['brandingSettings']['image']['bannerImageUrl']); ?>"
                 alt="<?php echo esc_attr($header['items'][0]['snippet']['title']); ?>">
            <img class="wpsr-yt-header-banner-tablet"
                 src="<?php echo esc_url($header['items'][0]['brandingSettings']['image']['bannerTabletImageUrl']); ?>"
                 alt="<?php echo esc_attr($header['items'][0]['snippet']['title']); ?>">
            <img class="wpsr-yt-header-banner-mobile"
                 src="<?php echo esc_url($header['items'][0]['brandingSettings']['image']['bannerMobileImageUrl']); ?>"
                 alt="<?php echo esc_attr($header['items'][0]['snippet']['title']); ?>">
        </div>
        <?php
    }
}

/**
 *
 * Render YouTube Channel Name HTML
 *
 * @param $header
 * @param $template_header_meta
 * @since 1.2.5
 *
 **/
function wpsr_render_channel_name_html($header = array(), $template_header_meta = array())
{

    if ((isset($template_header_meta['display_name']) && $template_header_meta['display_name'] === 'false')) {
        return;
    }

    ?>
    <div class="wpsr-yt-header-channel-name">
        <a target="_blank" href="<?php echo esc_url('https://www.youtube.com/channel/' . $header['items'][0]['id']); ?>"
           title="<?php echo esc_attr($header['items'][0]['snippet']['title']); ?>"><?php echo esc_html($header['items'][0]['snippet']['title']); ?>
        </a>
    </div>
    <?php
}

/**
 *
 * Render YouTube Channel Logo HTML
 *
 * @param $header
 * @param $template_header_meta
 * @since 1.2.5
 *
 **/
function wpsr_render_channel_logo_html($header = array(), $template_header_meta = array())
{

    if ((isset($template_header_meta['display_logo']) && $template_header_meta['display_logo'] === 'false')) {
        return;
    }

    ?>
    <div class="wpsr-yt-header-logo">
        <a target="_blank"
           href="<?php echo esc_url('https://www.youtube.com/channel/' . $header['items'][0]['id']); ?>">
            <img src="<?php echo esc_url($header['items'][0]['snippet']['thumbnails']['high']['url']); ?>"
                 :alt="<?php echo esc_attr($header['items'][0]['snippet']['title']); ?>">
        </a>
    </div>
    <?php
}

/**
 *
 * Render Instagram Post Media HTML
 *
 * @param $feed
 * @since 1.3.0
 *
 **/
function wpsr_render_instagram_media_html($feed = array(), $template_meta = array())
{

    ?>

    <div class="wpsr-ig-post-media">

        <?php if (isset($template_meta['source_settings']['feed_type']) && $template_meta['source_settings']['feed_type'] === 'hashtag_feed' && isset($feed['media_url'])) { ?>
            <video src="<?php echo esc_url($feed['media_url']); ?>">
                <source src="<?php echo esc_url($feed['media_url']); ?>" type="video/mp4">
            </video>
        <?php } ?>

        <?php if (isset($template_meta['source_settings']['feed_type']) && $template_meta['source_settings']['feed_type'] === 'hashtag_feed' && isset($feed['media_type']) && $feed['media_type'] === 'IMAGE' && isset($feed['media_url'])) { ?>
            <img src="<?php echo esc_url($feed['media_url']); ?>"
                 alt="<?php echo isset($feed['caption']) ? esc_attr($feed['caption']) : ''; ?>">
        <?php } ?>

        <?php if (isset($feed['media_type']) && $feed['media_type'] === 'CAROUSEL_ALBUM' && isset($feed['children']['data'][0]['media_url'])) { ?>
            <img src="<?php echo esc_url($feed['children']['data'][0]['media_url']); ?>">
        <?php } ?>

        <?php if (isset($template_meta['source_settings']['feed_type']) && $template_meta['source_settings']['feed_type'] !== 'hashtag_feed' && isset($feed['media_url'])) { ?>
            <img src="<?php echo esc_url(isset($feed['media_type']) && $feed['media_type'] === 'VIDEO' && isset($feed['thumbnail_url']) ? $feed['thumbnail_url'] : $feed['media_url']); ?>"
                 alt="<?php echo isset($feed['caption']) ? esc_attr($feed['caption']) : ''; ?>">
        <?php } ?>

        <?php if (isset($feed['media_type']) && $feed['media_type'] !== 'IMAGE') { ?>
            <div class="wpsr-ig-post-type-icon wpsr-ig-post-type-<?php echo esc_attr($feed['media_type']); ?>"></div>
        <?php } ?>
    </div>

    <?php
}

/**
 *
 * Render Instagram Post Media HTML
 *
 * @param $feed
 * @param $template_meta
 * @since 1.3.0
 *
 **/
function wpsr_render_instagram_caption_html($feed = array(), $template_meta = array())
{
    if (isset($template_meta['post_settings']['display_caption']) && $template_meta['post_settings']['display_caption'] === 'false') {
        return false;
    }

    $trim_words_count = isset($template_meta['post_settings']['trim_caption_words']) && $template_meta['post_settings']['trim_caption_words'] > 0 ? $template_meta['post_settings']['trim_caption_words'] : 0;

    if (isset($feed['caption']) && $trim_words_count) {
        $caption = apply_filters('wpsocialreviews/instagram_trim_caption_words', $feed['caption'], $trim_words_count);
    } else {
        $caption = isset($feed['caption']) ? $feed['caption'] : '';
    }

    ?>

    <?php if ($caption && isset($template_meta['template']) && $template_meta['template'] === 'template2') { ?>
    <div class="wpsr-ig-post-caption">
        <p><?php echo preg_replace("/#(\w+)/", '<a href="https://www.instagram.com/explore/tags/$1" target="_blank">#$1</a>', nl2br($caption)); ?></p>
    </div>
<?php } elseif ($caption) { ?>
    <div class="wpsr-ig-post-caption">
        <p><?php echo isset($feed['caption']) ? nl2br($caption) : ''; ?></p>
    </div>
<?php }

}

/**
 *
 * Render Instagram Icon HTML
 *
 * @since 1.3.0
 *
 **/
function wpsr_render_instagram_icon_html()
{
    ?>

    <div class="wpsr-ig-icon">
        <svg viewBox="0 0 24 24" width="24" height="24">
            <path d="M17.1,1H6.9C3.7,1,1,3.7,1,6.9v10.1C1,20.3,3.7,23,6.9,23h10.1c3.3,0,5.9-2.7,5.9-5.9V6.9C23,3.7,20.3,1,17.1,1z
                                    M21.5,17.1c0,2.4-2,4.4-4.4,4.4H6.9c-2.4,0-4.4-2-4.4-4.4V6.9c0-2.4,2-4.4,4.4-4.4h10.3c2.4,0,4.4,2,4.4,4.4V17.1z"></path>
            <path d="M16.9,11.2c-0.2-1.1-0.6-2-1.4-2.8c-0.8-0.8-1.7-1.2-2.8-1.4c-0.5-0.1-1-0.1-1.4,0C10,7.3,8.9,8,8.1,9S7,11.4,7.2,12.7
                                    C7.4,14,8,15.1,9.1,15.9c0.9,0.6,1.9,1,2.9,1c0.2,0,0.5,0,0.7-0.1c1.3-0.2,2.5-0.9,3.2-1.9C16.8,13.8,17.1,12.5,16.9,11.2z
                                        M12.6,15.4c-0.9,0.1-1.8-0.1-2.6-0.6c-0.7-0.6-1.2-1.4-1.4-2.3c-0.1-0.9,0.1-1.8,0.6-2.6c0.6-0.7,1.4-1.2,2.3-1.4
                                    c0.2,0,0.3,0,0.5,0s0.3,0,0.5,0c1.5,0.2,2.7,1.4,2.9,2.9C15.8,13.3,14.5,15.1,12.6,15.4z"></path>
            <path d="M18.4,5.6c-0.2-0.2-0.4-0.3-0.6-0.3s-0.5,0.1-0.6,0.3c-0.2,0.2-0.3,0.4-0.3,0.6s0.1,0.5,0.3,0.6c0.2,0.2,0.4,0.3,0.6,0.3
                                    s0.5-0.1,0.6-0.3c0.2-0.2,0.3-0.4,0.3-0.6C18.7,5.9,18.6,5.7,18.4,5.6z"></path>
        </svg>
    </div>

    <?php
}
