<?php
/**
 * WP Social Reviews Template Hooks
 *
 * Action/filter hooks used for WP Social Reviews functions/templates.
 *
 * @since  1.0.0
 */

if (!defined('ABSPATH')) {
    exit;
}

// Register the widget
add_action('widgets_init', function () {
    register_widget('WPSocialReviews\Classes\Widget');
});

// Allow shortcode in widget text
add_filter('widget_text', 'do_shortcode');

/**
 * Reviewer Image
 *
 * @see wpsr_render_reviewer_image_html()
 * @since  1.0.0
 */
add_action('wpsocialreviews/reviewer_image', 'wpsr_render_reviewer_image_html', 10, 3);


/**
 * Review Platform
 *
 * @see wpsr_render_review_platform_html()
 * @since  1.0.0
 */
add_action('wpsocialreviews/review_platform', 'wpsr_render_review_platform_html', 10, 2);

/**
 * Reviewer Name
 *
 * @see wpsr_render_review_platform_html()
 * @since  1.0.0
 */
add_action('wpsocialreviews/reviewer_name', 'wpsr_render_reviewer_name_html', 10, 3);


/**
 * Reviewer Rating
 *
 * @see wpsr_render_reviewer_rating_html()
 * @since  1.0.0
 */
add_action('wpsocialreviews/reviewer_rating', 'wpsr_render_reviewer_rating_html', 10, 5);


/**
 * Review Date
 *
 * @see wpsr_render_review_date_html()
 * @since  1.0.0
 */
add_action('wpsocialreviews/review_date', 'wpsr_render_review_date_html', 10, 2);

/**
 * Review Content
 *
 * @see wpsr_render_review_content_html()
 * @since  1.0.0
 */
add_action('wpsocialreviews/review_content', 'wpsr_render_review_content_html', 10, 6);


/***********************
 * ***********
 * Twitter templates hooks
 * **********
 **********************/

/**
 * Author info
 *
 * @see wpsr_render_tweet_time_html()
 * @see wpsr_render_tweet_author_username_html()
 * @see wpsr_render_tweet_author_verified_icon_html()
 * @see wpsr_render_tweet_author_name_html()
 * @since  1.2.4
 */
add_action('wpsocialreviews/tweet_author_info', 'wpsr_render_tweet_author_name_html', 5, 2);
add_action('wpsocialreviews/tweet_author_info', 'wpsr_render_tweet_author_verified_icon_html', 10, 2);
add_action('wpsocialreviews/tweet_author_username', 'wpsr_render_tweet_author_username_html', 10, 2);
add_action('wpsocialreviews/tweet_time', 'wpsr_render_tweet_time_html', 10, 2);


/**
 * Tweet Author Avatar
 *
 * @see wpsr_render_tweet_author_avatar_html()
 * @since  1.2.4
 */
add_action('wpsocialreviews/tweet_author_avatar', 'wpsr_render_tweet_author_avatar_html', 10, 2);

/**
 * Tweet Retweeted Status
 *
 * @see wpsr_render_tweet_retweeted_status_html()
 * @since  1.2.4
 */
add_action('wpsocialreviews/tweet_retweeted_status', 'wpsr_render_tweet_retweeted_status_html', 10);


/**
 * Tweet Content
 *
 * @see wpsr_render_tweet_content_html()
 * @see wpsr_render_tweet_quoted_status_html()
 * @since  1.2.4
 */
add_action('wpsocialreviews/tweet_content', 'wpsr_render_tweet_content_html', 10, 2);
add_action('wpsocialreviews/tweet_quoted_status', 'wpsr_render_tweet_quoted_status_html', 10, 2);

/**
 * Tweet Image
 *
 * @see wpsr_render_tweet_image_html()
 * @since  1.2.4
 */
add_action('wpsocialreviews/tweet_image', 'wpsr_render_tweet_image_html', 10, 2);

/**
 * Tweet Video
 *
 * @see wpsr_render_tweet_media_video_html()
 * @since  1.2.4
 */
add_action('wpsocialreviews/tweet_video', 'wpsr_render_tweet_video_html', 10, 2);

/**
 * Tweet actions
 *
 * @see wpsr_render_tweet_action_favorite_count()
 * @see wpsr_render_tweet_action_retweet_count()
 * @see wpsr_render_tweet_action_reply()
 * @since  1.2.4
 */
add_action('wpsocialreviews/tweet_actions', 'wpsr_render_tweet_action_reply', 5, 2);
add_action('wpsocialreviews/tweet_actions', 'wpsr_render_tweet_action_retweet_count', 10, 2);
add_action('wpsocialreviews/tweet_actions', 'wpsr_render_tweet_action_favorite_count', 15, 2);


/***********************
 * ***********
 * YouTube templates hooks
 * **********
 **********************/

/**
 * Youtube Feed Preview Image
 *
 * @see wpsr_render_youtube_feed_preview_image_html()
 * @since  1.2.5
 */
add_action('wpsocialreviews/youtube_feed_preview_image', 'wpsr_render_youtube_feed_preview_image_html', 10, 5);

/**
 * Youtube Feed Title
 *
 * @see wpsr_render_youtube_feed_title_html()
 * @since  1.2.5
 */
add_action('wpsocialreviews/youtube_feed_title', 'wpsr_render_youtube_feed_title_html', 10, 4);

/**
 * Retrieve youtube popupbox data
 *
 * @since  1.2.5
 */
add_action('wp_ajax_nopriv_wpsr_youtube_popup_feed', 'wpsr_youtube_popup_feed');
add_action('wp_ajax_wpsr_youtube_popup_feed', 'wpsr_youtube_popup_feed');

/**
 * Youtube Channel Banner
 *
 * @see wpsr_render_channel_logo_html()
 * @since  1.2.5
 */
add_action('wpsocialreviews/youtube_channel_banner', 'wpsr_render_youtube_channel_banner_html', 10, 2);

/**
 * Youtube Channel Name
 *
 * @see wpsr_render_channel_name_html()
 * @since  1.2.5
 */
add_action('wpsocialreviews/youtube_channel_name', 'wpsr_render_channel_name_html', 10, 2);

/**
 * Youtube Channel Logo
 *
 * @see wpsr_render_channel_logo_html()
 * @since  1.2.5
 */
add_action('wpsocialreviews/youtube_channel_logo', 'wpsr_render_channel_logo_html', 10, 2);

/**
 * Instagram Post Media
 *
 * @see wpsr_render_instagram_media_html()
 * @since  1.3.0
 */
add_action('wpsocialreviews/instagram_post_media', 'wpsr_render_instagram_media_html', 10, 2);

/**
 * Instagram Post Caption
 *
 * @see wpsr_render_instagram_caption_html()
 * @since  1.3.0
 */
add_action('wpsocialreviews/instagram_post_caption', 'wpsr_render_instagram_caption_html', 10, 2);

/**
 * Instagram Icon
 *
 * @see wpsr_render_instagram_icon_html()
 * @since  1.3.0
 */
add_action('wpsocialreviews/instagram_icon', 'wpsr_render_instagram_icon_html');