<?php
/**
 * Plugin Name: WP Social Ninja
 * Plugin URI: https://wordpress.org/plugins/wp-social-reviews/
 * Description: WP Social Ninja - is an all-in-one WordPress Social plugin to automatically integrate your social media reviews, news feeds, and chat functionalities on your website.
 * Author: WPManageNinja LLC
 * Author URI: https://wpsocialninja.com/
 * License: GPLv2 or later
 * Version: 1.3.1
 * Text Domain: wpsocialreviews
 */

if (!defined('ABSPATH')) {
    exit;
}

if (!defined('WPSOCIALREVIEWS_VERSION')) {
    define('WPSOCIALREVIEWS_VERSION', '1.3.1');
    define('WPSOCIALREVIEWS_DB_VERSION', 120);
    define('WPSOCIALREVIEWS_MAIN_FILE', __FILE__);
    define('WPSOCIALREVIEWS_BASENAME', plugin_basename(__FILE__));
    define('WPSOCIALREVIEWS_URL', plugin_dir_url(__FILE__));
    define('WPSOCIALREVIEWS_DIR', plugin_dir_path(__FILE__));

    class WPSocialReviews
    {
        public function boot()
        {
            $this->textDomain();
            $this->loadDependencies();

            $this->commonActions();

            $this->registerShortcodes();
            $this->registerPlatforms();

            add_action('save_post', function ($postId, $post) {

                if (has_shortcode($post->post_content, 'wp_social_ninja')) {
                    update_post_meta($postId, '_has_wp_social_ninja_shortcode', true);
                } else {
                    update_post_meta($postId, '_has_wp_social_ninja_shortcode', false);
                }
            }, 10, 2);

            add_action('wp_enqueue_scripts', array($this, 'registerScripts'));

            if (is_admin()) {
                $this->adminHooks();
            }

        }

        public function commonActions()
        {
            // Front Emd Ajax Handler
            $frontEndAjaxHandler = new \WPSocialReviews\Classes\FrontEndAjaxHandler();

            //reviews load more
            add_action('wp_ajax_load_more_reviews_ajax_handler',
                array($frontEndAjaxHandler, 'loadMoreReviewsAjaxHandler'));
            add_action('wp_ajax_nopriv_load_more_reviews_ajax_handler',
                array($frontEndAjaxHandler, 'loadMoreReviewsAjaxHandler'));

            //youtube load more
            add_action('wp_ajax_load_more_youtube_ajax_handler',
                array($frontEndAjaxHandler, 'loadMoreYouTubeAjaxHandler'));
            add_action('wp_ajax_nopriv_load_more_youtube_ajax_handler',
                array($frontEndAjaxHandler, 'loadMoreYouTubeAjaxHandler'));

            //twitter load more
            add_action('wp_ajax_load_more_twitter_ajax_handler',
                array($frontEndAjaxHandler, 'loadMoreTwitterAjaxHandler'));
            add_action('wp_ajax_nopriv_load_more_twitter_ajax_handler',
                array($frontEndAjaxHandler, 'loadMoreTwitterAjaxHandler'));
        }

        public function textDomain()
        {
            load_plugin_textdomain('wpsocialreviews', false, basename(dirname(__FILE__)) . '/languages');
        }

        public function loadDependencies()
        {
            require_once(WPSOCIALREVIEWS_DIR . 'includes/autoload.php');
        }

        public function registerShortcodes()
        {
            // register shortcode
            add_shortcode('wp_social_ninja', function ($args) {

                $args = shortcode_atts(array(
                    'id' => '',
                    'platform' => ''
                ), $args);

                if (!$args['id']) {
                    return;
                }

                $builder = new \WPSocialReviews\Classes\Builder\Render();

                return $builder->render($args['id'], $args['platform']);
            });
        }

        public function adminHooks()
        {
            // Register Admin menu
            $menu = new \WPSocialReviews\Classes\Menu();
            $menu->register();

            // Top Level Ajax Handlers for reviews
            $ajaxHandler = new \WPSocialReviews\Classes\AdminAjaxHandler();
            $ajaxHandler->registerEndpoints();

            // Top Level Ajax Handlers for chat
            $ajaxChatHandler = new \WPSocialReviews\Classes\AdminAjaxChatHandler();
            $ajaxChatHandler->registerEndpoints();

            // Top Level Ajax Handlers for chat
            $ajaxFeedHandler = new \WPSocialReviews\Classes\AdminAjaxFeedHandler();
            $ajaxFeedHandler->registerEndpoints();

            add_action('wpsocialreviews/render_admin_app', function () {
                $adminApp = new \WPSocialReviews\Classes\AdminApp();
                $adminApp->bootView();
            });

            //remove all admin notice
            add_action('admin_init', function () {
                $disablePages = [
                    'wpsocialninja.php',
                ];
                if (isset($_GET['page']) && in_array($_GET['page'], $disablePages)) {
                    remove_all_actions('admin_notices');
                }
            });

            add_filter('plugin_action_links_' . WPSOCIALREVIEWS_BASENAME, function ($links) {
                $links[] = sprintf('<a href="%1$s">%2$s</a>', 'admin.php?page=wpsocialninja.php#/',
                    __('Settings', 'wpsocialreviews'));
                return $links;
            });

        }

        /**
         *  Enqueue All Front-End Assets
         *
         * @param
         */
        public function registerScripts()
        {
            global $post;

            if ( (is_a($post, 'WP_Post') && get_post_meta($post->ID, '_has_wp_social_ninja_shortcode', true) ) || is_active_widget(false, false, 'wpsn-widget', true) ) {

                wp_enqueue_style(
                    'slick',
                    WPSOCIALREVIEWS_URL . 'assets/libs/slick/slick.css',
                    array(),
                    WPSOCIALREVIEWS_VERSION
                );
                wp_enqueue_style(
                    'slick-theme',
                    WPSOCIALREVIEWS_URL . 'assets/libs/slick/slick-theme.css',
                    array(),
                    WPSOCIALREVIEWS_VERSION
                );

                wp_enqueue_style(
                    'wpsocialreviews_public',
                    WPSOCIALREVIEWS_URL . 'assets/css/social-review-public.css',
                    array(),
                    WPSOCIALREVIEWS_VERSION
                );

                wp_enqueue_style(
                    'wpsocialreviews_feeds',
                    WPSOCIALREVIEWS_URL . 'assets/css/social-review-feeds.css',
                    array(),
                    WPSOCIALREVIEWS_VERSION
                );

                wp_enqueue_script('slick', WPSOCIALREVIEWS_URL . 'assets/libs/slick/slick.min.js', array('jquery'),
                    '2.0', true);
                wp_enqueue_script('wp-social-review', WPSOCIALREVIEWS_URL . 'assets/js/wp-social-review.js',
                    array('jquery'), WPSOCIALREVIEWS_VERSION, true);

                $params = array(
                    'ajax_url' => site_url() . '/wp-admin/admin-ajax.php',
                    'wpsr_nonce' => wp_create_nonce('wpsr-ajax-nonce'),
                );

                wp_localize_script('wp-social-review', 'wpsr_ajax_params', $params);
            }
        }

        public function registerPlatforms()
        {
            //add reviews
            (new \WPSocialReviews\Classes\Reviews\GoogleMyBusiness())->registerHooks();
            (new \WPSocialReviews\Classes\Reviews\Airbnb())->registerHooks();

            if (defined('WPSOCIALREVIEWS_PRO')) {
                (new \WPSocialReviewsPro\Classes\Reviews\Zomato())->registerHooks();
                (new \WPSocialReviewsPro\Classes\Reviews\YelpBusiness())->registerHooks();
                (new \WPSocialReviewsPro\Classes\Reviews\FacebookBusiness())->registerHooks();

                (new \WPSocialReviewsPro\Classes\Reviews\Tripadvisor())->registerHooks();
                (new \WPSocialReviewsPro\Classes\Reviews\Amazon())->registerHooks();
                (new \WPSocialReviewsPro\Classes\Reviews\Trustpilot())->registerHooks();
                (new \WPSocialReviewsPro\Classes\Reviews\Aliexpress())->registerHooks();
                (new \WPSocialReviewsPro\Classes\Reviews\Booking())->registerHooks();

                (new \WPSocialReviewsPro\Classes\Chats\WhatsappChat())->registerHooks();
                (new \WPSocialReviewsPro\Classes\Chats\TelegramChat())->registerHooks();
            }

            if (defined('WPSOCIALREVIEWS_PRO') && (defined('FLUENTFORM') && function_exists('wpFluentForm'))) {
                new \WPSocialReviewsPro\Classes\Reviews\Fluentform(wpFluentForm());
            }

            //add feeds
            (new \WPSocialReviews\Classes\Feeds\Twitter\TwitterFeed())->registerHooks();
            (new \WPSocialReviews\Classes\Feeds\Instagram\InstagramFeed())->registerHooks();
            (new \WPSocialReviews\Classes\Feeds\Youtube\YoutubeFeed())->registerHooks();

            //add chats
            (new \WPSocialReviews\Classes\Chats\MessengerChat())->registerHooks();

            $chatHandler = new \WPSocialReviews\Classes\Builder\Chat();
            $chatHandler->chatRegister();
        }
    }

    add_action('plugins_loaded', function () {
        (new WPSocialReviews())->boot();
    });

    register_activation_hook(WPSOCIALREVIEWS_MAIN_FILE, function ($netWorkWide) {
        require_once(WPSOCIALREVIEWS_DIR . 'includes/Classes/Activator.php');
        $activator = new \WPSocialReviews\Classes\Activator();
        $activator->migrateDatabases($netWorkWide);
    });

} else {
    add_action('admin_init', function () {
        deactivate_plugins(plugin_basename(__FILE__));
    });
}